<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kiss: person, person, Fair skin, medium-fair skin',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kiss: person, person, Fair skin, medium skin',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kiss: person, person, Fair skin, medium-dark skin',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kiss: person, person, Fair skin, dark skin',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kiss: person, person, medium-fair skin, Fair skin',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kiss: person, person, medium-fair skin, medium skin',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kiss: person, person, medium-fair skin, medium-dark skin',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kiss: person, person, medium-fair skin, dark skin',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kiss: person, person, medium skin, Fair skin',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kiss: person, person, medium skin, medium-fair skin',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kiss: person, person, medium skin, medium-dark skin',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kiss: person, person, medium skin, dark skin',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kiss: person, person, medium-dark skin, Fair skin',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kiss: person, person, medium-dark skin, medium-fair skin',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kiss: person, person, medium-dark skin, medium skin',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kiss: person, person, medium-dark skin, dark skin',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kiss: person, person, dark skin, Fair skin',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kiss: person, person, dark skin, medium-fair skin',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kiss: person, person, dark skin, medium skin',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kiss: person, person, dark skin, medium-dark skin',
    '👨🏻‍❤‍💋‍👨🏻' => 'kiss: man, man, Fair skin',
    '👨🏻‍❤‍💋‍👨🏼' => 'kiss: man, man, Fair skin, medium-fair skin',
    '👨🏻‍❤‍💋‍👨🏽' => 'kiss: man, man, Fair skin, medium skin',
    '👨🏻‍❤‍💋‍👨🏾' => 'kiss: man, man, Fair skin, medium-dark skin',
    '👨🏻‍❤‍💋‍👨🏿' => 'kiss: man, man, Fair skin, dark skin',
    '👨🏼‍❤‍💋‍👨🏻' => 'kiss: man, man, medium-fair skin, Fair skin',
    '👨🏼‍❤‍💋‍👨🏼' => 'kiss: man, man, medium-fair skin',
    '👨🏼‍❤‍💋‍👨🏽' => 'kiss: man, man, medium-fair skin, medium skin',
    '👨🏼‍❤‍💋‍👨🏾' => 'kiss: man, man, medium-fair skin, medium-dark skin',
    '👨🏼‍❤‍💋‍👨🏿' => 'kiss: man, man, medium-fair skin, dark skin',
    '👨🏽‍❤‍💋‍👨🏻' => 'kiss: man, man, medium skin, Fair skin',
    '👨🏽‍❤‍💋‍👨🏼' => 'kiss: man, man, medium skin, medium-fair skin',
    '👨🏽‍❤‍💋‍👨🏽' => 'kiss: man, man, medium skin',
    '👨🏽‍❤‍💋‍👨🏾' => 'kiss: man, man, medium skin, medium-dark skin',
    '👨🏽‍❤‍💋‍👨🏿' => 'kiss: man, man, medium skin, dark skin',
    '👨🏾‍❤‍💋‍👨🏻' => 'kiss: man, man, medium-dark skin, Fair skin',
    '👨🏾‍❤‍💋‍👨🏼' => 'kiss: man, man, medium-dark skin, medium-fair skin',
    '👨🏾‍❤‍💋‍👨🏽' => 'kiss: man, man, medium-dark skin, medium skin',
    '👨🏾‍❤‍💋‍👨🏾' => 'kiss: man, man, medium-dark skin',
    '👨🏾‍❤‍💋‍👨🏿' => 'kiss: man, man, medium-dark skin, dark skin',
    '👨🏿‍❤‍💋‍👨🏻' => 'kiss: man, man, dark skin, Fair skin',
    '👨🏿‍❤‍💋‍👨🏼' => 'kiss: man, man, dark skin, medium-fair skin',
    '👨🏿‍❤‍💋‍👨🏽' => 'kiss: man, man, dark skin, medium skin',
    '👨🏿‍❤‍💋‍👨🏾' => 'kiss: man, man, dark skin, medium-dark skin',
    '👨🏿‍❤‍💋‍👨🏿' => 'kiss: man, man, dark skin',
    '👩🏻‍❤‍💋‍👨🏻' => 'kiss: woman, man, Fair skin',
    '👩🏻‍❤‍💋‍👨🏼' => 'kiss: woman, man, Fair skin, medium-fair skin',
    '👩🏻‍❤‍💋‍👨🏽' => 'kiss: woman, man, Fair skin, medium skin',
    '👩🏻‍❤‍💋‍👨🏾' => 'kiss: woman, man, Fair skin, medium-dark skin',
    '👩🏻‍❤‍💋‍👨🏿' => 'kiss: woman, man, Fair skin, dark skin',
    '👩🏼‍❤‍💋‍👨🏻' => 'kiss: woman, man, medium-fair skin, Fair skin',
    '👩🏼‍❤‍💋‍👨🏼' => 'kiss: woman, man, medium-fair skin',
    '👩🏼‍❤‍💋‍👨🏽' => 'kiss: woman, man, medium-fair skin, medium skin',
    '👩🏼‍❤‍💋‍👨🏾' => 'kiss: woman, man, medium-fair skin, medium-dark skin',
    '👩🏼‍❤‍💋‍👨🏿' => 'kiss: woman, man, medium-fair skin, dark skin',
    '👩🏽‍❤‍💋‍👨🏻' => 'kiss: woman, man, medium skin, Fair skin',
    '👩🏽‍❤‍💋‍👨🏼' => 'kiss: woman, man, medium skin, medium-fair skin',
    '👩🏽‍❤‍💋‍👨🏽' => 'kiss: woman, man, medium skin',
    '👩🏽‍❤‍💋‍👨🏾' => 'kiss: woman, man, medium skin, medium-dark skin',
    '👩🏽‍❤‍💋‍👨🏿' => 'kiss: woman, man, medium skin, dark skin',
    '👩🏾‍❤‍💋‍👨🏻' => 'kiss: woman, man, medium-dark skin, Fair skin',
    '👩🏾‍❤‍💋‍👨🏼' => 'kiss: woman, man, medium-dark skin, medium-fair skin',
    '👩🏾‍❤‍💋‍👨🏽' => 'kiss: woman, man, medium-dark skin, medium skin',
    '👩🏾‍❤‍💋‍👨🏾' => 'kiss: woman, man, medium-dark skin',
    '👩🏾‍❤‍💋‍👨🏿' => 'kiss: woman, man, medium-dark skin, dark skin',
    '👩🏿‍❤‍💋‍👨🏻' => 'kiss: woman, man, dark skin, Fair skin',
    '👩🏿‍❤‍💋‍👨🏼' => 'kiss: woman, man, dark skin, medium-fair skin',
    '👩🏿‍❤‍💋‍👨🏽' => 'kiss: woman, man, dark skin, medium skin',
    '👩🏿‍❤‍💋‍👨🏾' => 'kiss: woman, man, dark skin, medium-dark skin',
    '👩🏿‍❤‍💋‍👨🏿' => 'kiss: woman, man, dark skin',
    '👩🏻‍❤‍💋‍👩🏻' => 'kiss: woman, woman, Fair skin',
    '👩🏻‍❤‍💋‍👩🏼' => 'kiss: woman, woman, Fair skin, medium-fair skin',
    '👩🏻‍❤‍💋‍👩🏽' => 'kiss: woman, woman, Fair skin, medium skin',
    '👩🏻‍❤‍💋‍👩🏾' => 'kiss: woman, woman, Fair skin, medium-dark skin',
    '👩🏻‍❤‍💋‍👩🏿' => 'kiss: woman, woman, Fair skin, dark skin',
    '👩🏼‍❤‍💋‍👩🏻' => 'kiss: woman, woman, medium-fair skin, Fair skin',
    '👩🏼‍❤‍💋‍👩🏼' => 'kiss: woman, woman, medium-fair skin',
    '👩🏼‍❤‍💋‍👩🏽' => 'kiss: woman, woman, medium-fair skin, medium skin',
    '👩🏼‍❤‍💋‍👩🏾' => 'kiss: woman, woman, medium-fair skin, medium-dark skin',
    '👩🏼‍❤‍💋‍👩🏿' => 'kiss: woman, woman, medium-fair skin, dark skin',
    '👩🏽‍❤‍💋‍👩🏻' => 'kiss: woman, woman, medium skin, Fair skin',
    '👩🏽‍❤‍💋‍👩🏼' => 'kiss: woman, woman, medium skin, medium-fair skin',
    '👩🏽‍❤‍💋‍👩🏽' => 'kiss: woman, woman, medium skin',
    '👩🏽‍❤‍💋‍👩🏾' => 'kiss: woman, woman, medium skin, medium-dark skin',
    '👩🏽‍❤‍💋‍👩🏿' => 'kiss: woman, woman, medium skin, dark skin',
    '👩🏾‍❤‍💋‍👩🏻' => 'kiss: woman, woman, medium-dark skin, Fair skin',
    '👩🏾‍❤‍💋‍👩🏼' => 'kiss: woman, woman, medium-dark skin, medium-fair skin',
    '👩🏾‍❤‍💋‍👩🏽' => 'kiss: woman, woman, medium-dark skin, medium skin',
    '👩🏾‍❤‍💋‍👩🏾' => 'kiss: woman, woman, medium-dark skin',
    '👩🏾‍❤‍💋‍👩🏿' => 'kiss: woman, woman, medium-dark skin, dark skin',
    '👩🏿‍❤‍💋‍👩🏻' => 'kiss: woman, woman, dark skin, Fair skin',
    '👩🏿‍❤‍💋‍👩🏼' => 'kiss: woman, woman, dark skin, medium-fair skin',
    '👩🏿‍❤‍💋‍👩🏽' => 'kiss: woman, woman, dark skin, medium skin',
    '👩🏿‍❤‍💋‍👩🏾' => 'kiss: woman, woman, dark skin, medium-dark skin',
    '👩🏿‍❤‍💋‍👩🏿' => 'kiss: woman, woman, dark skin',
    '🧑🏻‍🫯‍🧑🏼' => 'wrestling karte log: Fair skin, medium-fair skin',
    '🧑🏻‍🫯‍🧑🏽' => 'wrestling karte log: Fair skin, medium skin',
    '🧑🏻‍🫯‍🧑🏾' => 'wrestling karte log: Fair skin, medium-dark skin',
    '🧑🏻‍🫯‍🧑🏿' => 'wrestling karte log: Fair skin, dark skin',
    '🧑🏼‍🫯‍🧑🏻' => 'wrestling karte log: medium-fair skin, Fair skin',
    '🧑🏼‍🫯‍🧑🏽' => 'wrestling karte log: medium-fair skin, medium skin',
    '🧑🏼‍🫯‍🧑🏾' => 'wrestling karte log: medium-fair skin, medium-dark skin',
    '🧑🏼‍🫯‍🧑🏿' => 'wrestling karte log: medium-fair skin, dark skin',
    '🧑🏽‍🫯‍🧑🏻' => 'wrestling karte log: medium skin, Fair skin',
    '🧑🏽‍🫯‍🧑🏼' => 'wrestling karte log: medium skin, medium-fair skin',
    '🧑🏽‍🫯‍🧑🏾' => 'wrestling karte log: medium skin, medium-dark skin',
    '🧑🏽‍🫯‍🧑🏿' => 'wrestling karte log: medium skin, dark skin',
    '🧑🏾‍🫯‍🧑🏻' => 'wrestling karte log: medium-dark skin, Fair skin',
    '🧑🏾‍🫯‍🧑🏼' => 'wrestling karte log: medium-dark skin, medium-fair skin',
    '🧑🏾‍🫯‍🧑🏽' => 'wrestling karte log: medium-dark skin, medium skin',
    '🧑🏾‍🫯‍🧑🏿' => 'wrestling karte log: medium-dark skin, dark skin',
    '🧑🏿‍🫯‍🧑🏻' => 'wrestling karte log: dark skin, Fair skin',
    '🧑🏿‍🫯‍🧑🏼' => 'wrestling karte log: dark skin, medium-fair skin',
    '🧑🏿‍🫯‍🧑🏽' => 'wrestling karte log: dark skin, medium skin',
    '🧑🏿‍🫯‍🧑🏾' => 'wrestling karte log: dark skin, medium-dark skin',
    '🧑🏻‍❤‍🧑🏼' => 'heart symbol ke saath couple: person, person, Fair skin, medium-fair skin',
    '🧑🏻‍❤‍🧑🏽' => 'heart symbol ke saath couple: person, person, Fair skin, medium skin',
    '🧑🏻‍❤‍🧑🏾' => 'heart symbol ke saath couple: person, person, Fair skin, medium-dark skin',
    '🧑🏻‍❤‍🧑🏿' => 'heart symbol ke saath couple: person, person, Fair skin, dark skin',
    '🧑🏼‍❤‍🧑🏻' => 'heart symbol ke saath couple: person, person, medium-fair skin, Fair skin',
    '🧑🏼‍❤‍🧑🏽' => 'heart symbol ke saath couple: person, person, medium-fair skin, medium skin',
    '🧑🏼‍❤‍🧑🏾' => 'heart symbol ke saath couple: person, person, medium-fair skin, medium-dark skin',
    '🧑🏼‍❤‍🧑🏿' => 'heart symbol ke saath couple: person, person, medium-fair skin, dark skin',
    '🧑🏽‍❤‍🧑🏻' => 'heart symbol ke saath couple: person, person, medium skin, Fair skin',
    '🧑🏽‍❤‍🧑🏼' => 'heart symbol ke saath couple: person, person, medium skin, medium-fair skin',
    '🧑🏽‍❤‍🧑🏾' => 'heart symbol ke saath couple: person, person, medium skin, medium-dark skin',
    '🧑🏽‍❤‍🧑🏿' => 'heart symbol ke saath couple: person, person, medium skin, dark skin',
    '🧑🏾‍❤‍🧑🏻' => 'heart symbol ke saath couple: person, person, medium-dark skin, Fair skin',
    '🧑🏾‍❤‍🧑🏼' => 'heart symbol ke saath couple: person, person, medium-dark skin, medium-fair skin',
    '🧑🏾‍❤‍🧑🏽' => 'heart symbol ke saath couple: person, person, medium-dark skin, medium skin',
    '🧑🏾‍❤‍🧑🏿' => 'heart symbol ke saath couple: person, person, medium-dark skin, dark skin',
    '🧑🏿‍❤‍🧑🏻' => 'heart symbol ke saath couple: person, person, dark skin, Fair skin',
    '🧑🏿‍❤‍🧑🏼' => 'heart symbol ke saath couple: person, person, dark skin, medium-fair skin',
    '🧑🏿‍❤‍🧑🏽' => 'heart symbol ke saath couple: person, person, dark skin, medium skin',
    '🧑🏿‍❤‍🧑🏾' => 'heart symbol ke saath couple: person, person, dark skin, medium-dark skin',
    '🧑🏻‍🐰‍🧑🏼' => 'khargosh ke kaan wale log: Fair skin, medium-fair skin',
    '🧑🏻‍🐰‍🧑🏽' => 'khargosh ke kaan wale log: Fair skin, medium skin',
    '🧑🏻‍🐰‍🧑🏾' => 'khargosh ke kaan wale log: Fair skin, medium-dark skin',
    '🧑🏻‍🐰‍🧑🏿' => 'khargosh ke kaan wale log: Fair skin, dark skin',
    '🧑🏼‍🐰‍🧑🏻' => 'khargosh ke kaan wale log: medium-fair skin, Fair skin',
    '🧑🏼‍🐰‍🧑🏽' => 'khargosh ke kaan wale log: medium-fair skin, medium skin',
    '🧑🏼‍🐰‍🧑🏾' => 'khargosh ke kaan wale log: medium-fair skin, medium-dark skin',
    '🧑🏼‍🐰‍🧑🏿' => 'khargosh ke kaan wale log: medium-fair skin, dark skin',
    '🧑🏽‍🐰‍🧑🏻' => 'khargosh ke kaan wale log: medium skin, Fair skin',
    '🧑🏽‍🐰‍🧑🏼' => 'khargosh ke kaan wale log: medium skin, medium-fair skin',
    '🧑🏽‍🐰‍🧑🏾' => 'khargosh ke kaan wale log: medium skin, medium-dark skin',
    '🧑🏽‍🐰‍🧑🏿' => 'khargosh ke kaan wale log: medium skin, dark skin',
    '🧑🏾‍🐰‍🧑🏻' => 'khargosh ke kaan wale log: medium-dark skin, Fair skin',
    '🧑🏾‍🐰‍🧑🏼' => 'khargosh ke kaan wale log: medium-dark skin, medium-fair skin',
    '🧑🏾‍🐰‍🧑🏽' => 'khargosh ke kaan wale log: medium-dark skin, medium skin',
    '🧑🏾‍🐰‍🧑🏿' => 'khargosh ke kaan wale log: medium-dark skin, dark skin',
    '🧑🏿‍🐰‍🧑🏻' => 'khargosh ke kaan wale log: dark skin, Fair skin',
    '🧑🏿‍🐰‍🧑🏼' => 'khargosh ke kaan wale log: dark skin, medium-fair skin',
    '🧑🏿‍🐰‍🧑🏽' => 'khargosh ke kaan wale log: dark skin, medium skin',
    '🧑🏿‍🐰‍🧑🏾' => 'khargosh ke kaan wale log: dark skin, medium-dark skin',
    '👨🏻‍🫯‍👨🏼' => 'wrestling karte aadmi: Fair skin, medium-fair skin',
    '👨🏻‍🫯‍👨🏽' => 'wrestling karte aadmi: Fair skin, medium skin',
    '👨🏻‍🫯‍👨🏾' => 'wrestling karte aadmi: Fair skin, medium-dark skin',
    '👨🏻‍🫯‍👨🏿' => 'wrestling karte aadmi: Fair skin, dark skin',
    '👨🏼‍🫯‍👨🏻' => 'wrestling karte aadmi: medium-fair skin, Fair skin',
    '👨🏼‍🫯‍👨🏽' => 'wrestling karte aadmi: medium-fair skin, medium skin',
    '👨🏼‍🫯‍👨🏾' => 'wrestling karte aadmi: medium-fair skin, medium-dark skin',
    '👨🏼‍🫯‍👨🏿' => 'wrestling karte aadmi: medium-fair skin, dark skin',
    '👨🏽‍🫯‍👨🏻' => 'wrestling karte aadmi: medium skin, Fair skin',
    '👨🏽‍🫯‍👨🏼' => 'wrestling karte aadmi: medium skin, medium-fair skin',
    '👨🏽‍🫯‍👨🏾' => 'wrestling karte aadmi: medium skin, medium-dark skin',
    '👨🏽‍🫯‍👨🏿' => 'wrestling karte aadmi: medium skin, dark skin',
    '👨🏾‍🫯‍👨🏻' => 'wrestling karte aadmi: medium-dark skin, Fair skin',
    '👨🏾‍🫯‍👨🏼' => 'wrestling karte aadmi: medium-dark skin, medium-fair skin',
    '👨🏾‍🫯‍👨🏽' => 'wrestling karte aadmi: medium-dark skin, medium skin',
    '👨🏾‍🫯‍👨🏿' => 'wrestling karte aadmi: medium-dark skin, dark skin',
    '👨🏿‍🫯‍👨🏻' => 'wrestling karte aadmi: dark skin, Fair skin',
    '👨🏿‍🫯‍👨🏼' => 'wrestling karte aadmi: dark skin, medium-fair skin',
    '👨🏿‍🫯‍👨🏽' => 'wrestling karte aadmi: dark skin, medium skin',
    '👨🏿‍🫯‍👨🏾' => 'wrestling karte aadmi: dark skin, medium-dark skin',
    '👨🏻‍❤‍👨🏻' => 'heart symbol ke saath couple: man, man, Fair skin',
    '👨🏻‍❤‍👨🏼' => 'heart symbol ke saath couple: man, man, Fair skin, medium-fair skin',
    '👨🏻‍❤‍👨🏽' => 'heart symbol ke saath couple: man, man, Fair skin, medium skin',
    '👨🏻‍❤‍👨🏾' => 'heart symbol ke saath couple: man, man, Fair skin, medium-dark skin',
    '👨🏻‍❤‍👨🏿' => 'heart symbol ke saath couple: man, man, Fair skin, dark skin',
    '👨🏼‍❤‍👨🏻' => 'heart symbol ke saath couple: man, man, medium-fair skin, Fair skin',
    '👨🏼‍❤‍👨🏼' => 'heart symbol ke saath couple: man, man, medium-fair skin',
    '👨🏼‍❤‍👨🏽' => 'heart symbol ke saath couple: man, man, medium-fair skin, medium skin',
    '👨🏼‍❤‍👨🏾' => 'heart symbol ke saath couple: man, man, medium-fair skin, medium-dark skin',
    '👨🏼‍❤‍👨🏿' => 'heart symbol ke saath couple: man, man, medium-fair skin, dark skin',
    '👨🏽‍❤‍👨🏻' => 'heart symbol ke saath couple: man, man, medium skin, Fair skin',
    '👨🏽‍❤‍👨🏼' => 'heart symbol ke saath couple: man, man, medium skin, medium-fair skin',
    '👨🏽‍❤‍👨🏽' => 'heart symbol ke saath couple: man, man, medium skin',
    '👨🏽‍❤‍👨🏾' => 'heart symbol ke saath couple: man, man, medium skin, medium-dark skin',
    '👨🏽‍❤‍👨🏿' => 'heart symbol ke saath couple: man, man, medium skin, dark skin',
    '👨🏾‍❤‍👨🏻' => 'heart symbol ke saath couple: man, man, medium-dark skin, Fair skin',
    '👨🏾‍❤‍👨🏼' => 'heart symbol ke saath couple: man, man, medium-dark skin, medium-fair skin',
    '👨🏾‍❤‍👨🏽' => 'heart symbol ke saath couple: man, man, medium-dark skin, medium skin',
    '👨🏾‍❤‍👨🏾' => 'heart symbol ke saath couple: man, man, medium-dark skin',
    '👨🏾‍❤‍👨🏿' => 'heart symbol ke saath couple: man, man, medium-dark skin, dark skin',
    '👨🏿‍❤‍👨🏻' => 'heart symbol ke saath couple: man, man, dark skin, Fair skin',
    '👨🏿‍❤‍👨🏼' => 'heart symbol ke saath couple: man, man, dark skin, medium-fair skin',
    '👨🏿‍❤‍👨🏽' => 'heart symbol ke saath couple: man, man, dark skin, medium skin',
    '👨🏿‍❤‍👨🏾' => 'heart symbol ke saath couple: man, man, dark skin, medium-dark skin',
    '👨🏿‍❤‍👨🏿' => 'heart symbol ke saath couple: man, man, dark skin',
    '👨🏻‍🐰‍👨🏼' => 'khargosh ke kaan wale aadmi: Fair skin, medium-fair skin',
    '👨🏻‍🐰‍👨🏽' => 'khargosh ke kaan wale aadmi: Fair skin, medium skin',
    '👨🏻‍🐰‍👨🏾' => 'khargosh ke kaan wale aadmi: Fair skin, medium-dark skin',
    '👨🏻‍🐰‍👨🏿' => 'khargosh ke kaan wale aadmi: Fair skin, dark skin',
    '👨🏼‍🐰‍👨🏻' => 'khargosh ke kaan wale aadmi: medium-fair skin, Fair skin',
    '👨🏼‍🐰‍👨🏽' => 'khargosh ke kaan wale aadmi: medium-fair skin, medium skin',
    '👨🏼‍🐰‍👨🏾' => 'khargosh ke kaan wale aadmi: medium-fair skin, medium-dark skin',
    '👨🏼‍🐰‍👨🏿' => 'khargosh ke kaan wale aadmi: medium-fair skin, dark skin',
    '👨🏽‍🐰‍👨🏻' => 'khargosh ke kaan wale aadmi: medium skin, Fair skin',
    '👨🏽‍🐰‍👨🏼' => 'khargosh ke kaan wale aadmi: medium skin, medium-fair skin',
    '👨🏽‍🐰‍👨🏾' => 'khargosh ke kaan wale aadmi: medium skin, medium-dark skin',
    '👨🏽‍🐰‍👨🏿' => 'khargosh ke kaan wale aadmi: medium skin, dark skin',
    '👨🏾‍🐰‍👨🏻' => 'khargosh ke kaan wale aadmi: medium-dark skin, Fair skin',
    '👨🏾‍🐰‍👨🏼' => 'khargosh ke kaan wale aadmi: medium-dark skin, medium-fair skin',
    '👨🏾‍🐰‍👨🏽' => 'khargosh ke kaan wale aadmi: medium-dark skin, medium skin',
    '👨🏾‍🐰‍👨🏿' => 'khargosh ke kaan wale aadmi: medium-dark skin, dark skin',
    '👨🏿‍🐰‍👨🏻' => 'khargosh ke kaan wale aadmi: dark skin, Fair skin',
    '👨🏿‍🐰‍👨🏼' => 'khargosh ke kaan wale aadmi: dark skin, medium-fair skin',
    '👨🏿‍🐰‍👨🏽' => 'khargosh ke kaan wale aadmi: dark skin, medium skin',
    '👨🏿‍🐰‍👨🏾' => 'khargosh ke kaan wale aadmi: dark skin, medium-dark skin',
    '👩🏻‍🫯‍👩🏼' => 'wrestling karti mahilaayein: Fair skin, medium-fair skin',
    '👩🏻‍🫯‍👩🏽' => 'wrestling karti mahilaayein: Fair skin, medium skin',
    '👩🏻‍🫯‍👩🏾' => 'wrestling karti mahilaayein: Fair skin, medium-dark skin',
    '👩🏻‍🫯‍👩🏿' => 'wrestling karti mahilaayein: Fair skin, dark skin',
    '👩🏼‍🫯‍👩🏻' => 'wrestling karti mahilaayein: medium-fair skin, Fair skin',
    '👩🏼‍🫯‍👩🏽' => 'wrestling karti mahilaayein: medium-fair skin, medium skin',
    '👩🏼‍🫯‍👩🏾' => 'wrestling karti mahilaayein: medium-fair skin, medium-dark skin',
    '👩🏼‍🫯‍👩🏿' => 'wrestling karti mahilaayein: medium-fair skin, dark skin',
    '👩🏽‍🫯‍👩🏻' => 'wrestling karti mahilaayein: medium skin, Fair skin',
    '👩🏽‍🫯‍👩🏼' => 'wrestling karti mahilaayein: medium skin, medium-fair skin',
    '👩🏽‍🫯‍👩🏾' => 'wrestling karti mahilaayein: medium skin, medium-dark skin',
    '👩🏽‍🫯‍👩🏿' => 'wrestling karti mahilaayein: medium skin, dark skin',
    '👩🏾‍🫯‍👩🏻' => 'wrestling karti mahilaayein: medium-dark skin, Fair skin',
    '👩🏾‍🫯‍👩🏼' => 'wrestling karti mahilaayein: medium-dark skin, medium-fair skin',
    '👩🏾‍🫯‍👩🏽' => 'wrestling karti mahilaayein: medium-dark skin, medium skin',
    '👩🏾‍🫯‍👩🏿' => 'wrestling karti mahilaayein: medium-dark skin, dark skin',
    '👩🏿‍🫯‍👩🏻' => 'wrestling karti mahilaayein: dark skin, Fair skin',
    '👩🏿‍🫯‍👩🏼' => 'wrestling karti mahilaayein: dark skin, medium-fair skin',
    '👩🏿‍🫯‍👩🏽' => 'wrestling karti mahilaayein: dark skin, medium skin',
    '👩🏿‍🫯‍👩🏾' => 'wrestling karti mahilaayein: dark skin, medium-dark skin',
    '👩🏻‍❤‍👨🏻' => 'heart symbol ke saath couple: woman, man, Fair skin',
    '👩🏻‍❤‍👨🏼' => 'heart symbol ke saath couple: woman, man, Fair skin, medium-fair skin',
    '👩🏻‍❤‍👨🏽' => 'heart symbol ke saath couple: woman, man, Fair skin, medium skin',
    '👩🏻‍❤‍👨🏾' => 'heart symbol ke saath couple: woman, man, Fair skin, medium-dark skin',
    '👩🏻‍❤‍👨🏿' => 'heart symbol ke saath couple: woman, man, Fair skin, dark skin',
    '👩🏼‍❤‍👨🏻' => 'heart symbol ke saath couple: woman, man, medium-fair skin, Fair skin',
    '👩🏼‍❤‍👨🏼' => 'heart symbol ke saath couple: woman, man, medium-fair skin',
    '👩🏼‍❤‍👨🏽' => 'heart symbol ke saath couple: woman, man, medium-fair skin, medium skin',
    '👩🏼‍❤‍👨🏾' => 'heart symbol ke saath couple: woman, man, medium-fair skin, medium-dark skin',
    '👩🏼‍❤‍👨🏿' => 'heart symbol ke saath couple: woman, man, medium-fair skin, dark skin',
    '👩🏽‍❤‍👨🏻' => 'heart symbol ke saath couple: woman, man, medium skin, Fair skin',
    '👩🏽‍❤‍👨🏼' => 'heart symbol ke saath couple: woman, man, medium skin, medium-fair skin',
    '👩🏽‍❤‍👨🏽' => 'heart symbol ke saath couple: woman, man, medium skin',
    '👩🏽‍❤‍👨🏾' => 'heart symbol ke saath couple: woman, man, medium skin, medium-dark skin',
    '👩🏽‍❤‍👨🏿' => 'heart symbol ke saath couple: woman, man, medium skin, dark skin',
    '👩🏾‍❤‍👨🏻' => 'heart symbol ke saath couple: woman, man, medium-dark skin, Fair skin',
    '👩🏾‍❤‍👨🏼' => 'heart symbol ke saath couple: woman, man, medium-dark skin, medium-fair skin',
    '👩🏾‍❤‍👨🏽' => 'heart symbol ke saath couple: woman, man, medium-dark skin, medium skin',
    '👩🏾‍❤‍👨🏾' => 'heart symbol ke saath couple: woman, man, medium-dark skin',
    '👩🏾‍❤‍👨🏿' => 'heart symbol ke saath couple: woman, man, medium-dark skin, dark skin',
    '👩🏿‍❤‍👨🏻' => 'heart symbol ke saath couple: woman, man, dark skin, Fair skin',
    '👩🏿‍❤‍👨🏼' => 'heart symbol ke saath couple: woman, man, dark skin, medium-fair skin',
    '👩🏿‍❤‍👨🏽' => 'heart symbol ke saath couple: woman, man, dark skin, medium skin',
    '👩🏿‍❤‍👨🏾' => 'heart symbol ke saath couple: woman, man, dark skin, medium-dark skin',
    '👩🏿‍❤‍👨🏿' => 'heart symbol ke saath couple: woman, man, dark skin',
    '👩🏻‍❤‍👩🏻' => 'heart symbol ke saath couple: woman, woman, Fair skin',
    '👩🏻‍❤‍👩🏼' => 'heart symbol ke saath couple: woman, woman, Fair skin, medium-fair skin',
    '👩🏻‍❤‍👩🏽' => 'heart symbol ke saath couple: woman, woman, Fair skin, medium skin',
    '👩🏻‍❤‍👩🏾' => 'heart symbol ke saath couple: woman, woman, Fair skin, medium-dark skin',
    '👩🏻‍❤‍👩🏿' => 'heart symbol ke saath couple: woman, woman, Fair skin, dark skin',
    '👩🏼‍❤‍👩🏻' => 'heart symbol ke saath couple: woman, woman, medium-fair skin, Fair skin',
    '👩🏼‍❤‍👩🏼' => 'heart symbol ke saath couple: woman, woman, medium-fair skin',
    '👩🏼‍❤‍👩🏽' => 'heart symbol ke saath couple: woman, woman, medium-fair skin, medium skin',
    '👩🏼‍❤‍👩🏾' => 'heart symbol ke saath couple: woman, woman, medium-fair skin, medium-dark skin',
    '👩🏼‍❤‍👩🏿' => 'heart symbol ke saath couple: woman, woman, medium-fair skin, dark skin',
    '👩🏽‍❤‍👩🏻' => 'heart symbol ke saath couple: woman, woman, medium skin, Fair skin',
    '👩🏽‍❤‍👩🏼' => 'heart symbol ke saath couple: woman, woman, medium skin, medium-fair skin',
    '👩🏽‍❤‍👩🏽' => 'heart symbol ke saath couple: woman, woman, medium skin',
    '👩🏽‍❤‍👩🏾' => 'heart symbol ke saath couple: woman, woman, medium skin, medium-dark skin',
    '👩🏽‍❤‍👩🏿' => 'heart symbol ke saath couple: woman, woman, medium skin, dark skin',
    '👩🏾‍❤‍👩🏻' => 'heart symbol ke saath couple: woman, woman, medium-dark skin, Fair skin',
    '👩🏾‍❤‍👩🏼' => 'heart symbol ke saath couple: woman, woman, medium-dark skin, medium-fair skin',
    '👩🏾‍❤‍👩🏽' => 'heart symbol ke saath couple: woman, woman, medium-dark skin, medium skin',
    '👩🏾‍❤‍👩🏾' => 'heart symbol ke saath couple: woman, woman, medium-dark skin',
    '👩🏾‍❤‍👩🏿' => 'heart symbol ke saath couple: woman, woman, medium-dark skin, dark skin',
    '👩🏿‍❤‍👩🏻' => 'heart symbol ke saath couple: woman, woman, dark skin, Fair skin',
    '👩🏿‍❤‍👩🏼' => 'heart symbol ke saath couple: woman, woman, dark skin, medium-fair skin',
    '👩🏿‍❤‍👩🏽' => 'heart symbol ke saath couple: woman, woman, dark skin, medium skin',
    '👩🏿‍❤‍👩🏾' => 'heart symbol ke saath couple: woman, woman, dark skin, medium-dark skin',
    '👩🏿‍❤‍👩🏿' => 'heart symbol ke saath couple: woman, woman, dark skin',
    '👩🏻‍🐰‍👩🏼' => 'khargosh ke kaan wali mahilaayein: Fair skin, medium-fair skin',
    '👩🏻‍🐰‍👩🏽' => 'khargosh ke kaan wali mahilaayein: Fair skin, medium skin',
    '👩🏻‍🐰‍👩🏾' => 'khargosh ke kaan wali mahilaayein: Fair skin, medium-dark skin',
    '👩🏻‍🐰‍👩🏿' => 'khargosh ke kaan wali mahilaayein: Fair skin, dark skin',
    '👩🏼‍🐰‍👩🏻' => 'khargosh ke kaan wali mahilaayein: medium-fair skin, Fair skin',
    '👩🏼‍🐰‍👩🏽' => 'khargosh ke kaan wali mahilaayein: medium-fair skin, medium skin',
    '👩🏼‍🐰‍👩🏾' => 'khargosh ke kaan wali mahilaayein: medium-fair skin, medium-dark skin',
    '👩🏼‍🐰‍👩🏿' => 'khargosh ke kaan wali mahilaayein: medium-fair skin, dark skin',
    '👩🏽‍🐰‍👩🏻' => 'khargosh ke kaan wali mahilaayein: medium skin, Fair skin',
    '👩🏽‍🐰‍👩🏼' => 'khargosh ke kaan wali mahilaayein: medium skin, medium-fair skin',
    '👩🏽‍🐰‍👩🏾' => 'khargosh ke kaan wali mahilaayein: medium skin, medium-dark skin',
    '👩🏽‍🐰‍👩🏿' => 'khargosh ke kaan wali mahilaayein: medium skin, dark skin',
    '👩🏾‍🐰‍👩🏻' => 'khargosh ke kaan wali mahilaayein: medium-dark skin, Fair skin',
    '👩🏾‍🐰‍👩🏼' => 'khargosh ke kaan wali mahilaayein: medium-dark skin, medium-fair skin',
    '👩🏾‍🐰‍👩🏽' => 'khargosh ke kaan wali mahilaayein: medium-dark skin, medium skin',
    '👩🏾‍🐰‍👩🏿' => 'khargosh ke kaan wali mahilaayein: medium-dark skin, dark skin',
    '👩🏿‍🐰‍👩🏻' => 'khargosh ke kaan wali mahilaayein: dark skin, Fair skin',
    '👩🏿‍🐰‍👩🏼' => 'khargosh ke kaan wali mahilaayein: dark skin, medium-fair skin',
    '👩🏿‍🐰‍👩🏽' => 'khargosh ke kaan wali mahilaayein: dark skin, medium skin',
    '👩🏿‍🐰‍👩🏾' => 'khargosh ke kaan wali mahilaayein: dark skin, medium-dark skin',
    '🧑🏻‍🤝‍🧑🏻' => 'haath pakde huye log: Fair skin',
    '🧑🏻‍🤝‍🧑🏼' => 'haath pakde huye log: Fair skin, medium-fair skin',
    '🧑🏻‍🤝‍🧑🏽' => 'haath pakde huye log: Fair skin, medium skin',
    '🧑🏻‍🤝‍🧑🏾' => 'haath pakde huye log: Fair skin, medium-dark skin',
    '🧑🏻‍🤝‍🧑🏿' => 'haath pakde huye log: Fair skin, dark skin',
    '🧑🏼‍🤝‍🧑🏻' => 'haath pakde huye log: medium-fair skin, Fair skin',
    '🧑🏼‍🤝‍🧑🏼' => 'haath pakde huye log: medium-fair skin',
    '🧑🏼‍🤝‍🧑🏽' => 'haath pakde huye log: medium-fair skin, medium skin',
    '🧑🏼‍🤝‍🧑🏾' => 'haath pakde huye log: medium-fair skin, medium-dark skin',
    '🧑🏼‍🤝‍🧑🏿' => 'haath pakde huye log: medium-fair skin, dark skin',
    '🧑🏽‍🤝‍🧑🏻' => 'haath pakde huye log: medium skin, Fair skin',
    '🧑🏽‍🤝‍🧑🏼' => 'haath pakde huye log: medium skin, medium-fair skin',
    '🧑🏽‍🤝‍🧑🏽' => 'haath pakde huye log: medium skin',
    '🧑🏽‍🤝‍🧑🏾' => 'haath pakde huye log: medium skin, medium-dark skin',
    '🧑🏽‍🤝‍🧑🏿' => 'haath pakde huye log: medium skin, dark skin',
    '🧑🏾‍🤝‍🧑🏻' => 'haath pakde huye log: medium-dark skin, Fair skin',
    '🧑🏾‍🤝‍🧑🏼' => 'haath pakde huye log: medium-dark skin, medium-fair skin',
    '🧑🏾‍🤝‍🧑🏽' => 'haath pakde huye log: medium-dark skin, medium skin',
    '🧑🏾‍🤝‍🧑🏾' => 'haath pakde huye log: medium-dark skin',
    '🧑🏾‍🤝‍🧑🏿' => 'haath pakde huye log: medium-dark skin, dark skin',
    '🧑🏿‍🤝‍🧑🏻' => 'haath pakde huye log: dark skin, Fair skin',
    '🧑🏿‍🤝‍🧑🏼' => 'haath pakde huye log: dark skin, medium-fair skin',
    '🧑🏿‍🤝‍🧑🏽' => 'haath pakde huye log: dark skin, medium skin',
    '🧑🏿‍🤝‍🧑🏾' => 'haath pakde huye log: dark skin, medium-dark skin',
    '🧑🏿‍🤝‍🧑🏿' => 'haath pakde huye log: dark skin',
    '👩🏻‍🤝‍👩🏼' => 'haath pakde do mahilaayein: Fair skin, medium-fair skin',
    '👩🏻‍🤝‍👩🏽' => 'haath pakde do mahilaayein: Fair skin, medium skin',
    '👩🏻‍🤝‍👩🏾' => 'haath pakde do mahilaayein: Fair skin, medium-dark skin',
    '👩🏻‍🤝‍👩🏿' => 'haath pakde do mahilaayein: Fair skin, dark skin',
    '👩🏼‍🤝‍👩🏻' => 'haath pakde do mahilaayein: medium-fair skin, Fair skin',
    '👩🏼‍🤝‍👩🏽' => 'haath pakde do mahilaayein: medium-fair skin, medium skin',
    '👩🏼‍🤝‍👩🏾' => 'haath pakde do mahilaayein: medium-fair skin, medium-dark skin',
    '👩🏼‍🤝‍👩🏿' => 'haath pakde do mahilaayein: medium-fair skin, dark skin',
    '👩🏽‍🤝‍👩🏻' => 'haath pakde do mahilaayein: medium skin, Fair skin',
    '👩🏽‍🤝‍👩🏼' => 'haath pakde do mahilaayein: medium skin, medium-fair skin',
    '👩🏽‍🤝‍👩🏾' => 'haath pakde do mahilaayein: medium skin, medium-dark skin',
    '👩🏽‍🤝‍👩🏿' => 'haath pakde do mahilaayein: medium skin, dark skin',
    '👩🏾‍🤝‍👩🏻' => 'haath pakde do mahilaayein: medium-dark skin, Fair skin',
    '👩🏾‍🤝‍👩🏼' => 'haath pakde do mahilaayein: medium-dark skin, medium-fair skin',
    '👩🏾‍🤝‍👩🏽' => 'haath pakde do mahilaayein: medium-dark skin, medium skin',
    '👩🏾‍🤝‍👩🏿' => 'haath pakde do mahilaayein: medium-dark skin, dark skin',
    '👩🏿‍🤝‍👩🏻' => 'haath pakde do mahilaayein: dark skin, Fair skin',
    '👩🏿‍🤝‍👩🏼' => 'haath pakde do mahilaayein: dark skin, medium-fair skin',
    '👩🏿‍🤝‍👩🏽' => 'haath pakde do mahilaayein: dark skin, medium skin',
    '👩🏿‍🤝‍👩🏾' => 'haath pakde do mahilaayein: dark skin, medium-dark skin',
    '👩🏻‍🤝‍👨🏼' => 'haath mein haath liye aurat-aadmi: Fair skin, medium-fair skin',
    '👩🏻‍🤝‍👨🏽' => 'haath mein haath liye aurat-aadmi: Fair skin, medium skin',
    '👩🏻‍🤝‍👨🏾' => 'haath mein haath liye aurat-aadmi: Fair skin, medium-dark skin',
    '👩🏻‍🤝‍👨🏿' => 'haath mein haath liye aurat-aadmi: Fair skin, dark skin',
    '👩🏼‍🤝‍👨🏻' => 'haath mein haath liye aurat-aadmi: medium-fair skin, Fair skin',
    '👩🏼‍🤝‍👨🏽' => 'haath mein haath liye aurat-aadmi: medium-fair skin, medium skin',
    '👩🏼‍🤝‍👨🏾' => 'haath mein haath liye aurat-aadmi: medium-fair skin, medium-dark skin',
    '👩🏼‍🤝‍👨🏿' => 'haath mein haath liye aurat-aadmi: medium-fair skin, dark skin',
    '👩🏽‍🤝‍👨🏻' => 'haath mein haath liye aurat-aadmi: medium skin, Fair skin',
    '👩🏽‍🤝‍👨🏼' => 'haath mein haath liye aurat-aadmi: medium skin, medium-fair skin',
    '👩🏽‍🤝‍👨🏾' => 'haath mein haath liye aurat-aadmi: medium skin, medium-dark skin',
    '👩🏽‍🤝‍👨🏿' => 'haath mein haath liye aurat-aadmi: medium skin, dark skin',
    '👩🏾‍🤝‍👨🏻' => 'haath mein haath liye aurat-aadmi: medium-dark skin, Fair skin',
    '👩🏾‍🤝‍👨🏼' => 'haath mein haath liye aurat-aadmi: medium-dark skin, medium-fair skin',
    '👩🏾‍🤝‍👨🏽' => 'haath mein haath liye aurat-aadmi: medium-dark skin, medium skin',
    '👩🏾‍🤝‍👨🏿' => 'haath mein haath liye aurat-aadmi: medium-dark skin, dark skin',
    '👩🏿‍🤝‍👨🏻' => 'haath mein haath liye aurat-aadmi: dark skin, Fair skin',
    '👩🏿‍🤝‍👨🏼' => 'haath mein haath liye aurat-aadmi: dark skin, medium-fair skin',
    '👩🏿‍🤝‍👨🏽' => 'haath mein haath liye aurat-aadmi: dark skin, medium skin',
    '👩🏿‍🤝‍👨🏾' => 'haath mein haath liye aurat-aadmi: dark skin, medium-dark skin',
    '👨🏻‍🤝‍👨🏼' => 'haath pakde do aadmi: Fair skin, medium-fair skin',
    '👨🏻‍🤝‍👨🏽' => 'haath pakde do aadmi: Fair skin, medium skin',
    '👨🏻‍🤝‍👨🏾' => 'haath pakde do aadmi: Fair skin, medium-dark skin',
    '👨🏻‍🤝‍👨🏿' => 'haath pakde do aadmi: Fair skin, dark skin',
    '👨🏼‍🤝‍👨🏻' => 'haath pakde do aadmi: medium-fair skin, Fair skin',
    '👨🏼‍🤝‍👨🏽' => 'haath pakde do aadmi: medium-fair skin, medium skin',
    '👨🏼‍🤝‍👨🏾' => 'haath pakde do aadmi: medium-fair skin, medium-dark skin',
    '👨🏼‍🤝‍👨🏿' => 'haath pakde do aadmi: medium-fair skin, dark skin',
    '👨🏽‍🤝‍👨🏻' => 'haath pakde do aadmi: medium skin, Fair skin',
    '👨🏽‍🤝‍👨🏼' => 'haath pakde do aadmi: medium skin, medium-fair skin',
    '👨🏽‍🤝‍👨🏾' => 'haath pakde do aadmi: medium skin, medium-dark skin',
    '👨🏽‍🤝‍👨🏿' => 'haath pakde do aadmi: medium skin, dark skin',
    '👨🏾‍🤝‍👨🏻' => 'haath pakde do aadmi: medium-dark skin, Fair skin',
    '👨🏾‍🤝‍👨🏼' => 'haath pakde do aadmi: medium-dark skin, medium-fair skin',
    '👨🏾‍🤝‍👨🏽' => 'haath pakde do aadmi: medium-dark skin, medium skin',
    '👨🏾‍🤝‍👨🏿' => 'haath pakde do aadmi: medium-dark skin, dark skin',
    '👨🏿‍🤝‍👨🏻' => 'haath pakde do aadmi: dark skin, Fair skin',
    '👨🏿‍🤝‍👨🏼' => 'haath pakde do aadmi: dark skin, medium-fair skin',
    '👨🏿‍🤝‍👨🏽' => 'haath pakde do aadmi: dark skin, medium skin',
    '👨🏿‍🤝‍👨🏾' => 'haath pakde do aadmi: dark skin, medium-dark skin',
    '👩‍❤‍💋‍👨' => 'चुंबन: महिला, पुरुष',
    '👨‍❤‍💋‍👨' => 'चुंबन: पुरुष, पुरुष',
    '👩‍❤‍💋‍👩' => 'चुंबन: महिला, महिला',
    '👨‍👩‍👧‍👦' => 'परिवार: पुरुष, महिला, लड़की, लड़का',
    '👨‍👩‍👦‍👦' => 'परिवार: पुरुष, महिला, लड़का, लड़का',
    '👨‍👩‍👧‍👧' => 'परिवार: पुरुष, महिला, लड़की, लड़की',
    '👨‍👨‍👧‍👦' => 'परिवार: पुरुष, पुरुष, लड़की, लड़का',
    '👨‍👨‍👦‍👦' => 'परिवार: पुरुष, पुरुष, लड़का, लड़का',
    '👨‍👨‍👧‍👧' => 'परिवार: पुरुष, पुरुष, लड़की, लड़की',
    '👩‍👩‍👧‍👦' => 'परिवार: महिला, महिला, लड़की, लड़का',
    '👩‍👩‍👦‍👦' => 'परिवार: महिला, महिला, लड़का, लड़का',
    '👩‍👩‍👧‍👧' => 'परिवार: महिला, महिला, लड़की, लड़की',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'झंडा: इंग्लैंड',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'झंडा: स्कॉटलैंड',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'झंडा: वेल्स',
    '🧑‍🧑‍🧒‍🧒' => 'परिवार: वयस्क, वयस्क, बच्चा, बच्चा',
    '🚶🏻‍♀‍➡' => 'walk karti mahila: Fair skin, facing right',
    '🚶🏼‍♀‍➡' => 'walk karti mahila: medium-fair skin, facing right',
    '🚶🏽‍♀‍➡' => 'walk karti mahila: medium skin, facing right',
    '🚶🏾‍♀‍➡' => 'walk karti mahila: medium-dark skin, facing right',
    '🚶🏿‍♀‍➡' => 'walk karti mahila: dark skin, facing right',
    '🚶🏻‍♂‍➡' => 'walk karta aadmi: Fair skin, facing right',
    '🚶🏼‍♂‍➡' => 'walk karta aadmi: medium-fair skin, facing right',
    '🚶🏽‍♂‍➡' => 'walk karta aadmi: medium skin, facing right',
    '🚶🏾‍♂‍➡' => 'walk karta aadmi: medium-dark skin, facing right',
    '🚶🏿‍♂‍➡' => 'walk karta aadmi: dark skin, facing right',
    '🧎🏻‍♀‍➡' => 'knees par baithi mahila: Fair skin, facing right',
    '🧎🏼‍♀‍➡' => 'knees par baithi mahila: medium-fair skin, facing right',
    '🧎🏽‍♀‍➡' => 'knees par baithi mahila: medium skin, facing right',
    '🧎🏾‍♀‍➡' => 'knees par baithi mahila: medium-dark skin, facing right',
    '🧎🏿‍♀‍➡' => 'knees par baithi mahila: dark skin, facing right',
    '🧎🏻‍♂‍➡' => 'knees par baitha aadmi: Fair skin, facing right',
    '🧎🏼‍♂‍➡' => 'knees par baitha aadmi: medium-fair skin, facing right',
    '🧎🏽‍♂‍➡' => 'knees par baitha aadmi: medium skin, facing right',
    '🧎🏾‍♂‍➡' => 'knees par baitha aadmi: medium-dark skin, facing right',
    '🧎🏿‍♂‍➡' => 'knees par baitha aadmi: dark skin, facing right',
    '🧑🏻‍🦯‍➡' => 'white cane pakda hua vyakti: Fair skin, facing right',
    '🧑🏼‍🦯‍➡' => 'white cane pakda hua vyakti: medium-fair skin, facing right',
    '🧑🏽‍🦯‍➡' => 'white cane pakda hua vyakti: medium skin, facing right',
    '🧑🏾‍🦯‍➡' => 'white cane pakda hua vyakti: medium-dark skin, facing right',
    '🧑🏿‍🦯‍➡' => 'white cane pakda hua vyakti: dark skin, facing right',
    '👨🏻‍🦯‍➡' => 'white cane pakda hua aadmi: Fair skin, facing right',
    '👨🏼‍🦯‍➡' => 'white cane pakda hua aadmi: medium-fair skin, facing right',
    '👨🏽‍🦯‍➡' => 'white cane pakda hua aadmi: medium skin, facing right',
    '👨🏾‍🦯‍➡' => 'white cane pakda hua aadmi: medium-dark skin, facing right',
    '👨🏿‍🦯‍➡' => 'white cane pakda hua aadmi: dark skin, facing right',
    '👩🏻‍🦯‍➡' => 'white cane pakde hui mahila: Fair skin, facing right',
    '👩🏼‍🦯‍➡' => 'white cane pakde hui mahila: medium-fair skin, facing right',
    '👩🏽‍🦯‍➡' => 'white cane pakde hui mahila: medium skin, facing right',
    '👩🏾‍🦯‍➡' => 'white cane pakde hui mahila: medium-dark skin, facing right',
    '👩🏿‍🦯‍➡' => 'white cane pakde hui mahila: dark skin, facing right',
    '🧑🏻‍🦼‍➡' => 'motor wheelchair par baitha vyakti: Fair skin, facing right',
    '🧑🏼‍🦼‍➡' => 'motor wheelchair par baitha vyakti: medium-fair skin, facing right',
    '🧑🏽‍🦼‍➡' => 'motor wheelchair par baitha vyakti: medium skin, facing right',
    '🧑🏾‍🦼‍➡' => 'motor wheelchair par baitha vyakti: medium-dark skin, facing right',
    '🧑🏿‍🦼‍➡' => 'motor wheelchair par baitha vyakti: dark skin, facing right',
    '👨🏻‍🦼‍➡' => 'motor wheelchair par baitha aadmi: Fair skin, facing right',
    '👨🏼‍🦼‍➡' => 'motor wheelchair par baitha aadmi: medium-fair skin, facing right',
    '👨🏽‍🦼‍➡' => 'motor wheelchair par baitha aadmi: medium skin, facing right',
    '👨🏾‍🦼‍➡' => 'motor wheelchair par baitha aadmi: medium-dark skin, facing right',
    '👨🏿‍🦼‍➡' => 'motor wheelchair par baitha aadmi: dark skin, facing right',
    '👩🏻‍🦼‍➡' => 'motor wheelchair par baithi aurat: Fair skin, facing right',
    '👩🏼‍🦼‍➡' => 'motor wheelchair par baithi aurat: medium-fair skin, facing right',
    '👩🏽‍🦼‍➡' => 'motor wheelchair par baithi aurat: medium skin, facing right',
    '👩🏾‍🦼‍➡' => 'motor wheelchair par baithi aurat: medium-dark skin, facing right',
    '👩🏿‍🦼‍➡' => 'motor wheelchair par baithi aurat: dark skin, facing right',
    '🧑🏻‍🦽‍➡' => 'manual wheelchair par baitha vyakti: Fair skin, facing right',
    '🧑🏼‍🦽‍➡' => 'manual wheelchair par baitha vyakti: medium-fair skin, facing right',
    '🧑🏽‍🦽‍➡' => 'manual wheelchair par baitha vyakti: medium skin, facing right',
    '🧑🏾‍🦽‍➡' => 'manual wheelchair par baitha vyakti: medium-dark skin, facing right',
    '🧑🏿‍🦽‍➡' => 'manual wheelchair par baitha vyakti: dark skin, facing right',
    '👨🏻‍🦽‍➡' => 'manual wheelchair par baitha aadmi: Fair skin, facing right',
    '👨🏼‍🦽‍➡' => 'manual wheelchair par baitha aadmi: medium-fair skin, facing right',
    '👨🏽‍🦽‍➡' => 'manual wheelchair par baitha aadmi: medium skin, facing right',
    '👨🏾‍🦽‍➡' => 'manual wheelchair par baitha aadmi: medium-dark skin, facing right',
    '👨🏿‍🦽‍➡' => 'manual wheelchair par baitha aadmi: dark skin, facing right',
    '👩🏻‍🦽‍➡' => 'manual wheelchair par baithi mahila: Fair skin, facing right',
    '👩🏼‍🦽‍➡' => 'manual wheelchair par baithi mahila: medium-fair skin, facing right',
    '👩🏽‍🦽‍➡' => 'manual wheelchair par baithi mahila: medium skin, facing right',
    '👩🏾‍🦽‍➡' => 'manual wheelchair par baithi mahila: medium-dark skin, facing right',
    '👩🏿‍🦽‍➡' => 'manual wheelchair par baithi mahila: dark skin, facing right',
    '🏃🏻‍♀‍➡' => 'run karti mahila: Fair skin, facing right',
    '🏃🏼‍♀‍➡' => 'run karti mahila: medium-fair skin, facing right',
    '🏃🏽‍♀‍➡' => 'run karti mahila: medium skin, facing right',
    '🏃🏾‍♀‍➡' => 'run karti mahila: medium-dark skin, facing right',
    '🏃🏿‍♀‍➡' => 'run karti mahila: dark skin, facing right',
    '🏃🏻‍♂‍➡' => 'run karta aadmi: Fair skin, facing right',
    '🏃🏼‍♂‍➡' => 'run karta aadmi: medium-fair skin, facing right',
    '🏃🏽‍♂‍➡' => 'run karta aadmi: medium skin, facing right',
    '🏃🏾‍♂‍➡' => 'run karta aadmi: medium-dark skin, facing right',
    '🏃🏿‍♂‍➡' => 'run karta aadmi: dark skin, facing right',
    '🫱🏻‍🫲🏼' => 'handshake: Fair skin, medium-fair skin',
    '🫱🏻‍🫲🏽' => 'handshake: Fair skin, medium skin',
    '🫱🏻‍🫲🏾' => 'handshake: Fair skin, medium-dark skin',
    '🫱🏻‍🫲🏿' => 'handshake: Fair skin, dark skin',
    '🫱🏼‍🫲🏻' => 'handshake: medium-fair skin, Fair skin',
    '🫱🏼‍🫲🏽' => 'handshake: medium-fair skin, medium skin',
    '🫱🏼‍🫲🏾' => 'handshake: medium-fair skin, medium-dark skin',
    '🫱🏼‍🫲🏿' => 'handshake: medium-fair skin, dark skin',
    '🫱🏽‍🫲🏻' => 'handshake: medium skin, Fair skin',
    '🫱🏽‍🫲🏼' => 'handshake: medium skin, medium-fair skin',
    '🫱🏽‍🫲🏾' => 'handshake: medium skin, medium-dark skin',
    '🫱🏽‍🫲🏿' => 'handshake: medium skin, dark skin',
    '🫱🏾‍🫲🏻' => 'handshake: medium-dark skin, Fair skin',
    '🫱🏾‍🫲🏼' => 'handshake: medium-dark skin, medium-fair skin',
    '🫱🏾‍🫲🏽' => 'handshake: medium-dark skin, medium skin',
    '🫱🏾‍🫲🏿' => 'handshake: medium-dark skin, dark skin',
    '🫱🏿‍🫲🏻' => 'handshake: dark skin, Fair skin',
    '🫱🏿‍🫲🏼' => 'handshake: dark skin, medium-fair skin',
    '🫱🏿‍🫲🏽' => 'handshake: dark skin, medium skin',
    '🫱🏿‍🫲🏾' => 'handshake: dark skin, medium-dark skin',
    '🚶‍♀‍➡' => 'walk karti mahila: facing right',
    '🚶‍♂‍➡' => 'walk karta aadmi: facing right',
    '🧎‍♀‍➡' => 'knees par baithi mahila: facing right',
    '🧎‍♂‍➡' => 'knees par baitha aadmi: facing right',
    '🧑‍🦯‍➡' => 'white cane pakda hua vyakti: facing right',
    '👨‍🦯‍➡' => 'white cane pakda hua aadmi: facing right',
    '👩‍🦯‍➡' => 'white cane pakde hui mahila: facing right',
    '🧑‍🦼‍➡' => 'motor wheelchair par baitha vyakti: facing right',
    '👨‍🦼‍➡' => 'motor wheelchair par baitha aadmi: facing right',
    '👩‍🦼‍➡' => 'motor wheelchair par baithi aurat: facing right',
    '🧑‍🦽‍➡' => 'manual wheelchair par baitha vyakti: facing right',
    '👨‍🦽‍➡' => 'manual wheelchair par baitha aadmi: facing right',
    '👩‍🦽‍➡' => 'manual wheelchair par baithi mahila: facing right',
    '🏃‍♀‍➡' => 'run karti mahila: facing right',
    '🏃‍♂‍➡' => 'run karta aadmi: facing right',
    '👩‍❤‍👨' => 'heart symbol ke saath couple: woman, man',
    '👨‍❤‍👨' => 'heart symbol ke saath couple: man, man',
    '👩‍❤‍👩' => 'heart symbol ke saath couple: woman, woman',
    '👨‍👩‍👦' => 'परिवार: पुरुष, महिला, लड़का',
    '👨‍👩‍👧' => 'परिवार: पुरुष, महिला, लड़की',
    '👨‍👨‍👦' => 'परिवार: पुरुष, पुरुष, लड़का',
    '👨‍👨‍👧' => 'परिवार: पुरुष, पुरुष, लड़की',
    '👩‍👩‍👦' => 'परिवार: महिला, महिला, लड़का',
    '👩‍👩‍👧' => 'परिवार: महिला, महिला, लड़की',
    '👨‍👦‍👦' => 'परिवार: पुरुष, लड़का, लड़का',
    '👨‍👧‍👦' => 'परिवार: पुरुष, लड़की, लड़का',
    '👨‍👧‍👧' => 'परिवार: पुरुष, लड़की, लड़की',
    '👩‍👦‍👦' => 'परिवार: महिला, लड़का, लड़का',
    '👩‍👧‍👦' => 'परिवार: महिला, लड़की, लड़का',
    '👩‍👧‍👧' => 'परिवार: महिला, लड़की, लड़की',
    '🧑‍🤝‍🧑' => 'haath pakde huye log',
    '🧑‍🧑‍🧒' => 'परिवार: वयस्क, वयस्क, बच्चा',
    '🧑‍🧒‍🧒' => 'परिवार: वयस्क, बच्चा, बच्चा',
    '🧑🏻‍🦰' => 'person: Fair skin, red hair',
    '🧑🏼‍🦰' => 'person: medium-fair skin, red hair',
    '🧑🏽‍🦰' => 'person: medium skin, red hair',
    '🧑🏾‍🦰' => 'person: medium-dark skin, red hair',
    '🧑🏿‍🦰' => 'person: dark skin, red hair',
    '🧑🏻‍🦱' => 'person: Fair skin, curly hair',
    '🧑🏼‍🦱' => 'person: medium-fair skin, curly hair',
    '🧑🏽‍🦱' => 'person: medium skin, curly hair',
    '🧑🏾‍🦱' => 'person: medium-dark skin, curly hair',
    '🧑🏿‍🦱' => 'person: dark skin, curly hair',
    '🧑🏻‍🦳' => 'person: Fair skin, white hair',
    '🧑🏼‍🦳' => 'person: medium-fair skin, white hair',
    '🧑🏽‍🦳' => 'person: medium skin, white hair',
    '🧑🏾‍🦳' => 'person: medium-dark skin, white hair',
    '🧑🏿‍🦳' => 'person: dark skin, white hair',
    '🧑🏻‍🦲' => 'person: Fair skin, bald',
    '🧑🏼‍🦲' => 'person: medium-fair skin, bald',
    '🧑🏽‍🦲' => 'person: medium skin, bald',
    '🧑🏾‍🦲' => 'person: medium-dark skin, bald',
    '🧑🏿‍🦲' => 'person: dark skin, bald',
    '🧑🏻‍🩰' => 'ballet dancer: Fair skin',
    '🧑🏼‍🩰' => 'ballet dancer: medium-fair skin',
    '🧑🏽‍🩰' => 'ballet dancer: medium skin',
    '🧑🏾‍🩰' => 'ballet dancer: medium-dark skin',
    '🧑🏿‍🩰' => 'ballet dancer: dark skin',
    '🧔🏻‍♂' => 'male: Fair skin, beard',
    '🧔🏼‍♂' => 'male: medium-fair skin, beard',
    '🧔🏽‍♂' => 'male: medium skin, beard',
    '🧔🏾‍♂' => 'male: medium-dark skin, beard',
    '🧔🏿‍♂' => 'male: dark skin, beard',
    '👱🏻‍♂' => 'male: Fair skin, blond hair',
    '👱🏼‍♂' => 'male: medium-fair skin, blond hair',
    '👱🏽‍♂' => 'male: medium skin, blond hair',
    '👱🏾‍♂' => 'male: medium-dark skin, blond hair',
    '👱🏿‍♂' => 'male: dark skin, blond hair',
    '👨🏻‍🦰' => 'man: Fair skin, red hair',
    '👨🏼‍🦰' => 'man: medium-fair skin, red hair',
    '👨🏽‍🦰' => 'man: medium skin, red hair',
    '👨🏾‍🦰' => 'man: medium-dark skin, red hair',
    '👨🏿‍🦰' => 'man: dark skin, red hair',
    '👨🏻‍🦱' => 'man: Fair skin, curly hair',
    '👨🏼‍🦱' => 'man: medium-fair skin, curly hair',
    '👨🏽‍🦱' => 'man: medium skin, curly hair',
    '👨🏾‍🦱' => 'man: medium-dark skin, curly hair',
    '👨🏿‍🦱' => 'man: dark skin, curly hair',
    '👨🏻‍🦳' => 'man: Fair skin, white hair',
    '👨🏼‍🦳' => 'man: medium-fair skin, white hair',
    '👨🏽‍🦳' => 'man: medium skin, white hair',
    '👨🏾‍🦳' => 'man: medium-dark skin, white hair',
    '👨🏿‍🦳' => 'man: dark skin, white hair',
    '👨🏻‍🦲' => 'man: Fair skin, bald',
    '👨🏼‍🦲' => 'man: medium-fair skin, bald',
    '👨🏽‍🦲' => 'man: medium skin, bald',
    '👨🏾‍🦲' => 'man: medium-dark skin, bald',
    '👨🏿‍🦲' => 'man: dark skin, bald',
    '🧔🏻‍♀' => 'female: Fair skin, beard',
    '🧔🏼‍♀' => 'female: medium-fair skin, beard',
    '🧔🏽‍♀' => 'female: medium skin, beard',
    '🧔🏾‍♀' => 'female: medium-dark skin, beard',
    '🧔🏿‍♀' => 'female: dark skin, beard',
    '👱🏻‍♀' => 'female: Fair skin, blond hair',
    '👱🏼‍♀' => 'female: medium-fair skin, blond hair',
    '👱🏽‍♀' => 'female: medium skin, blond hair',
    '👱🏾‍♀' => 'female: medium-dark skin, blond hair',
    '👱🏿‍♀' => 'female: dark skin, blond hair',
    '👩🏻‍🦰' => 'woman: Fair skin, red hair',
    '👩🏼‍🦰' => 'woman: medium-fair skin, red hair',
    '👩🏽‍🦰' => 'woman: medium skin, red hair',
    '👩🏾‍🦰' => 'woman: medium-dark skin, red hair',
    '👩🏿‍🦰' => 'woman: dark skin, red hair',
    '👩🏻‍🦱' => 'woman: Fair skin, curly hair',
    '👩🏼‍🦱' => 'woman: medium-fair skin, curly hair',
    '👩🏽‍🦱' => 'woman: medium skin, curly hair',
    '👩🏾‍🦱' => 'woman: medium-dark skin, curly hair',
    '👩🏿‍🦱' => 'woman: dark skin, curly hair',
    '👩🏻‍🦳' => 'woman: Fair skin, white hair',
    '👩🏼‍🦳' => 'woman: medium-fair skin, white hair',
    '👩🏽‍🦳' => 'woman: medium skin, white hair',
    '👩🏾‍🦳' => 'woman: medium-dark skin, white hair',
    '👩🏿‍🦳' => 'woman: dark skin, white hair',
    '👩🏻‍🦲' => 'woman: Fair skin, bald',
    '👩🏼‍🦲' => 'woman: medium-fair skin, bald',
    '👩🏽‍🦲' => 'woman: medium skin, bald',
    '👩🏾‍🦲' => 'woman: medium-dark skin, bald',
    '👩🏿‍🦲' => 'woman: dark skin, bald',
    '🙍🏻‍♂' => 'frown karta aadmi: Fair skin',
    '🙍🏼‍♂' => 'frown karta aadmi: medium-fair skin',
    '🙍🏽‍♂' => 'frown karta aadmi: medium skin',
    '🙍🏾‍♂' => 'frown karta aadmi: medium-dark skin',
    '🙍🏿‍♂' => 'frown karta aadmi: dark skin',
    '🙍🏻‍♀' => 'frown karti mahila: Fair skin',
    '🙍🏼‍♀' => 'frown karti mahila: medium-fair skin',
    '🙍🏽‍♀' => 'frown karti mahila: medium skin',
    '🙍🏾‍♀' => 'frown karti mahila: medium-dark skin',
    '🙍🏿‍♀' => 'frown karti mahila: dark skin',
    '🙎🏻‍♂' => 'pout banaata aadmi: Fair skin',
    '🙎🏼‍♂' => 'pout banaata aadmi: medium-fair skin',
    '🙎🏽‍♂' => 'pout banaata aadmi: medium skin',
    '🙎🏾‍♂' => 'pout banaata aadmi: medium-dark skin',
    '🙎🏿‍♂' => 'pout banaata aadmi: dark skin',
    '🙎🏻‍♀' => 'pout banaati mahila: Fair skin',
    '🙎🏼‍♀' => 'pout banaati mahila: medium-fair skin',
    '🙎🏽‍♀' => 'pout banaati mahila: medium skin',
    '🙎🏾‍♀' => 'pout banaati mahila: medium-dark skin',
    '🙎🏿‍♀' => 'pout banaati mahila: dark skin',
    '🙅🏻‍♂' => 'NO kaa gesture deta aadmi: Fair skin',
    '🙅🏼‍♂' => 'NO kaa gesture deta aadmi: medium-fair skin',
    '🙅🏽‍♂' => 'NO kaa gesture deta aadmi: medium skin',
    '🙅🏾‍♂' => 'NO kaa gesture deta aadmi: medium-dark skin',
    '🙅🏿‍♂' => 'NO kaa gesture deta aadmi: dark skin',
    '🙅🏻‍♀' => 'NO kaa gesture deti mahila: Fair skin',
    '🙅🏼‍♀' => 'NO kaa gesture deti mahila: medium-fair skin',
    '🙅🏽‍♀' => 'NO kaa gesture deti mahila: medium skin',
    '🙅🏾‍♀' => 'NO kaa gesture deti mahila: medium-dark skin',
    '🙅🏿‍♀' => 'NO kaa gesture deti mahila: dark skin',
    '🙆🏻‍♂' => 'OK kaa gesture deta aadmi: Fair skin',
    '🙆🏼‍♂' => 'OK kaa gesture deta aadmi: medium-fair skin',
    '🙆🏽‍♂' => 'OK kaa gesture deta aadmi: medium skin',
    '🙆🏾‍♂' => 'OK kaa gesture deta aadmi: medium-dark skin',
    '🙆🏿‍♂' => 'OK kaa gesture deta aadmi: dark skin',
    '🙆🏻‍♀' => 'OK kaa gesture deti mahila: Fair skin',
    '🙆🏼‍♀' => 'OK kaa gesture deti mahila: medium-fair skin',
    '🙆🏽‍♀' => 'OK kaa gesture deti mahila: medium skin',
    '🙆🏾‍♀' => 'OK kaa gesture deti mahila: medium-dark skin',
    '🙆🏿‍♀' => 'OK kaa gesture deti mahila: dark skin',
    '💁🏻‍♂' => 'information desk kaa aadmi: Fair skin',
    '💁🏼‍♂' => 'information desk kaa aadmi: medium-fair skin',
    '💁🏽‍♂' => 'information desk kaa aadmi: medium skin',
    '💁🏾‍♂' => 'information desk kaa aadmi: medium-dark skin',
    '💁🏿‍♂' => 'information desk kaa aadmi: dark skin',
    '💁🏻‍♀' => 'information desk ki mahila: Fair skin',
    '💁🏼‍♀' => 'information desk ki mahila: medium-fair skin',
    '💁🏽‍♀' => 'information desk ki mahila: medium skin',
    '💁🏾‍♀' => 'information desk ki mahila: medium-dark skin',
    '💁🏿‍♀' => 'information desk ki mahila: dark skin',
    '🙋🏻‍♂' => 'haath uthaata aadmi: Fair skin',
    '🙋🏼‍♂' => 'haath uthaata aadmi: medium-fair skin',
    '🙋🏽‍♂' => 'haath uthaata aadmi: medium skin',
    '🙋🏾‍♂' => 'haath uthaata aadmi: medium-dark skin',
    '🙋🏿‍♂' => 'haath uthaata aadmi: dark skin',
    '🙋🏻‍♀' => 'haath uthaati mahila: Fair skin',
    '🙋🏼‍♀' => 'haath uthaati mahila: medium-fair skin',
    '🙋🏽‍♀' => 'haath uthaati mahila: medium skin',
    '🙋🏾‍♀' => 'haath uthaati mahila: medium-dark skin',
    '🙋🏿‍♀' => 'haath uthaati mahila: dark skin',
    '🧏🏻‍♂' => 'sun na paane wala aadmi: Fair skin',
    '🧏🏼‍♂' => 'sun na paane wala aadmi: medium-fair skin',
    '🧏🏽‍♂' => 'sun na paane wala aadmi: medium skin',
    '🧏🏾‍♂' => 'sun na paane wala aadmi: medium-dark skin',
    '🧏🏿‍♂' => 'sun na paane wala aadmi: dark skin',
    '🧏🏻‍♀' => 'sun na paane wali mahila: Fair skin',
    '🧏🏼‍♀' => 'sun na paane wali mahila: medium-fair skin',
    '🧏🏽‍♀' => 'sun na paane wali mahila: medium skin',
    '🧏🏾‍♀' => 'sun na paane wali mahila: medium-dark skin',
    '🧏🏿‍♀' => 'sun na paane wali mahila: dark skin',
    '🙇🏻‍♂' => 'bow karta aadmi: Fair skin',
    '🙇🏼‍♂' => 'bow karta aadmi: medium-fair skin',
    '🙇🏽‍♂' => 'bow karta aadmi: medium skin',
    '🙇🏾‍♂' => 'bow karta aadmi: medium-dark skin',
    '🙇🏿‍♂' => 'bow karta aadmi: dark skin',
    '🙇🏻‍♀' => 'bow karti mahila: Fair skin',
    '🙇🏼‍♀' => 'bow karti mahila: medium-fair skin',
    '🙇🏽‍♀' => 'bow karti mahila: medium skin',
    '🙇🏾‍♀' => 'bow karti mahila: medium-dark skin',
    '🙇🏿‍♀' => 'bow karti mahila: dark skin',
    '🤦🏻‍♂' => 'face par palm rakhe hua aadmi: Fair skin',
    '🤦🏼‍♂' => 'face par palm rakhe hua aadmi: medium-fair skin',
    '🤦🏽‍♂' => 'face par palm rakhe hua aadmi: medium skin',
    '🤦🏾‍♂' => 'face par palm rakhe hua aadmi: medium-dark skin',
    '🤦🏿‍♂' => 'face par palm rakhe hua aadmi: dark skin',
    '🤦🏻‍♀' => 'face par palm rakhe huye mahila: Fair skin',
    '🤦🏼‍♀' => 'face par palm rakhe huye mahila: medium-fair skin',
    '🤦🏽‍♀' => 'face par palm rakhe huye mahila: medium skin',
    '🤦🏾‍♀' => 'face par palm rakhe huye mahila: medium-dark skin',
    '🤦🏿‍♀' => 'face par palm rakhe huye mahila: dark skin',
    '🤷🏻‍♂' => 'shrug karta aadmi: Fair skin',
    '🤷🏼‍♂' => 'shrug karta aadmi: medium-fair skin',
    '🤷🏽‍♂' => 'shrug karta aadmi: medium skin',
    '🤷🏾‍♂' => 'shrug karta aadmi: medium-dark skin',
    '🤷🏿‍♂' => 'shrug karta aadmi: dark skin',
    '🤷🏻‍♀' => 'shrug karti mahila: Fair skin',
    '🤷🏼‍♀' => 'shrug karti mahila: medium-fair skin',
    '🤷🏽‍♀' => 'shrug karti mahila: medium skin',
    '🤷🏾‍♀' => 'shrug karti mahila: medium-dark skin',
    '🤷🏿‍♀' => 'shrug karti mahila: dark skin',
    '🧑🏻‍⚕' => 'health worker: Fair skin',
    '🧑🏼‍⚕' => 'health worker: medium-fair skin',
    '🧑🏽‍⚕' => 'health worker: medium skin',
    '🧑🏾‍⚕' => 'health worker: medium-dark skin',
    '🧑🏿‍⚕' => 'health worker: dark skin',
    '👨🏻‍⚕' => 'man health worker: Fair skin',
    '👨🏼‍⚕' => 'man health worker: medium-fair skin',
    '👨🏽‍⚕' => 'man health worker: medium skin',
    '👨🏾‍⚕' => 'man health worker: medium-dark skin',
    '👨🏿‍⚕' => 'man health worker: dark skin',
    '👩🏻‍⚕' => 'woman health worker: Fair skin',
    '👩🏼‍⚕' => 'woman health worker: medium-fair skin',
    '👩🏽‍⚕' => 'woman health worker: medium skin',
    '👩🏾‍⚕' => 'woman health worker: medium-dark skin',
    '👩🏿‍⚕' => 'woman health worker: dark skin',
    '🧑🏻‍🎓' => 'student: Fair skin',
    '🧑🏼‍🎓' => 'student: medium-fair skin',
    '🧑🏽‍🎓' => 'student: medium skin',
    '🧑🏾‍🎓' => 'student: medium-dark skin',
    '🧑🏿‍🎓' => 'student: dark skin',
    '👨🏻‍🎓' => 'man student: Fair skin',
    '👨🏼‍🎓' => 'man student: medium-fair skin',
    '👨🏽‍🎓' => 'man student: medium skin',
    '👨🏾‍🎓' => 'man student: medium-dark skin',
    '👨🏿‍🎓' => 'man student: dark skin',
    '👩🏻‍🎓' => 'woman student: Fair skin',
    '👩🏼‍🎓' => 'woman student: medium-fair skin',
    '👩🏽‍🎓' => 'woman student: medium skin',
    '👩🏾‍🎓' => 'woman student: medium-dark skin',
    '👩🏿‍🎓' => 'woman student: dark skin',
    '🧑🏻‍🏫' => 'teacher: Fair skin',
    '🧑🏼‍🏫' => 'teacher: medium-fair skin',
    '🧑🏽‍🏫' => 'teacher: medium skin',
    '🧑🏾‍🏫' => 'teacher: medium-dark skin',
    '🧑🏿‍🏫' => 'teacher: dark skin',
    '👨🏻‍🏫' => 'man teacher: Fair skin',
    '👨🏼‍🏫' => 'man teacher: medium-fair skin',
    '👨🏽‍🏫' => 'man teacher: medium skin',
    '👨🏾‍🏫' => 'man teacher: medium-dark skin',
    '👨🏿‍🏫' => 'man teacher: dark skin',
    '👩🏻‍🏫' => 'woman teacher: Fair skin',
    '👩🏼‍🏫' => 'woman teacher: medium-fair skin',
    '👩🏽‍🏫' => 'woman teacher: medium skin',
    '👩🏾‍🏫' => 'woman teacher: medium-dark skin',
    '👩🏿‍🏫' => 'woman teacher: dark skin',
    '🧑🏻‍⚖' => 'judge: Fair skin',
    '🧑🏼‍⚖' => 'judge: medium-fair skin',
    '🧑🏽‍⚖' => 'judge: medium skin',
    '🧑🏾‍⚖' => 'judge: medium-dark skin',
    '🧑🏿‍⚖' => 'judge: dark skin',
    '👨🏻‍⚖' => 'man judge: Fair skin',
    '👨🏼‍⚖' => 'man judge: medium-fair skin',
    '👨🏽‍⚖' => 'man judge: medium skin',
    '👨🏾‍⚖' => 'man judge: medium-dark skin',
    '👨🏿‍⚖' => 'man judge: dark skin',
    '👩🏻‍⚖' => 'woman judge: Fair skin',
    '👩🏼‍⚖' => 'woman judge: medium-fair skin',
    '👩🏽‍⚖' => 'woman judge: medium skin',
    '👩🏾‍⚖' => 'woman judge: medium-dark skin',
    '👩🏿‍⚖' => 'woman judge: dark skin',
    '🧑🏻‍🌾' => 'farmer: Fair skin',
    '🧑🏼‍🌾' => 'farmer: medium-fair skin',
    '🧑🏽‍🌾' => 'farmer: medium skin',
    '🧑🏾‍🌾' => 'farmer: medium-dark skin',
    '🧑🏿‍🌾' => 'farmer: dark skin',
    '👨🏻‍🌾' => 'man farmer: Fair skin',
    '👨🏼‍🌾' => 'man farmer: medium-fair skin',
    '👨🏽‍🌾' => 'man farmer: medium skin',
    '👨🏾‍🌾' => 'man farmer: medium-dark skin',
    '👨🏿‍🌾' => 'man farmer: dark skin',
    '👩🏻‍🌾' => 'woman farmer: Fair skin',
    '👩🏼‍🌾' => 'woman farmer: medium-fair skin',
    '👩🏽‍🌾' => 'woman farmer: medium skin',
    '👩🏾‍🌾' => 'woman farmer: medium-dark skin',
    '👩🏿‍🌾' => 'woman farmer: dark skin',
    '🧑🏻‍🍳' => 'cook: Fair skin',
    '🧑🏼‍🍳' => 'cook: medium-fair skin',
    '🧑🏽‍🍳' => 'cook: medium skin',
    '🧑🏾‍🍳' => 'cook: medium-dark skin',
    '🧑🏿‍🍳' => 'cook: dark skin',
    '👨🏻‍🍳' => 'man cook: Fair skin',
    '👨🏼‍🍳' => 'man cook: medium-fair skin',
    '👨🏽‍🍳' => 'man cook: medium skin',
    '👨🏾‍🍳' => 'man cook: medium-dark skin',
    '👨🏿‍🍳' => 'man cook: dark skin',
    '👩🏻‍🍳' => 'woman cook: Fair skin',
    '👩🏼‍🍳' => 'woman cook: medium-fair skin',
    '👩🏽‍🍳' => 'woman cook: medium skin',
    '👩🏾‍🍳' => 'woman cook: medium-dark skin',
    '👩🏿‍🍳' => 'woman cook: dark skin',
    '🧑🏻‍🔧' => 'mechanic: Fair skin',
    '🧑🏼‍🔧' => 'mechanic: medium-fair skin',
    '🧑🏽‍🔧' => 'mechanic: medium skin',
    '🧑🏾‍🔧' => 'mechanic: medium-dark skin',
    '🧑🏿‍🔧' => 'mechanic: dark skin',
    '👨🏻‍🔧' => 'man mechanic: Fair skin',
    '👨🏼‍🔧' => 'man mechanic: medium-fair skin',
    '👨🏽‍🔧' => 'man mechanic: medium skin',
    '👨🏾‍🔧' => 'man mechanic: medium-dark skin',
    '👨🏿‍🔧' => 'man mechanic: dark skin',
    '👩🏻‍🔧' => 'woman mechanic: Fair skin',
    '👩🏼‍🔧' => 'woman mechanic: medium-fair skin',
    '👩🏽‍🔧' => 'woman mechanic: medium skin',
    '👩🏾‍🔧' => 'woman mechanic: medium-dark skin',
    '👩🏿‍🔧' => 'woman mechanic: dark skin',
    '🧑🏻‍🏭' => 'factory worker: Fair skin',
    '🧑🏼‍🏭' => 'factory worker: medium-fair skin',
    '🧑🏽‍🏭' => 'factory worker: medium skin',
    '🧑🏾‍🏭' => 'factory worker: medium-dark skin',
    '🧑🏿‍🏭' => 'factory worker: dark skin',
    '👨🏻‍🏭' => 'male factory worker: Fair skin',
    '👨🏼‍🏭' => 'male factory worker: medium-fair skin',
    '👨🏽‍🏭' => 'male factory worker: medium skin',
    '👨🏾‍🏭' => 'male factory worker: medium-dark skin',
    '👨🏿‍🏭' => 'male factory worker: dark skin',
    '👩🏻‍🏭' => 'female factory worker: Fair skin',
    '👩🏼‍🏭' => 'female factory worker: medium-fair skin',
    '👩🏽‍🏭' => 'female factory worker: medium skin',
    '👩🏾‍🏭' => 'female factory worker: medium-dark skin',
    '👩🏿‍🏭' => 'female factory worker: dark skin',
    '🧑🏻‍💼' => 'office worker: Fair skin',
    '🧑🏼‍💼' => 'office worker: medium-fair skin',
    '🧑🏽‍💼' => 'office worker: medium skin',
    '🧑🏾‍💼' => 'office worker: medium-dark skin',
    '🧑🏿‍💼' => 'office worker: dark skin',
    '👨🏻‍💼' => 'man office worker: Fair skin',
    '👨🏼‍💼' => 'man office worker: medium-fair skin',
    '👨🏽‍💼' => 'man office worker: medium skin',
    '👨🏾‍💼' => 'man office worker: medium-dark skin',
    '👨🏿‍💼' => 'man office worker: dark skin',
    '👩🏻‍💼' => 'woman office worker: Fair skin',
    '👩🏼‍💼' => 'woman office worker: medium-fair skin',
    '👩🏽‍💼' => 'woman office worker: medium skin',
    '👩🏾‍💼' => 'woman office worker: medium-dark skin',
    '👩🏿‍💼' => 'woman office worker: dark skin',
    '🧑🏻‍🔬' => 'scientist: Fair skin',
    '🧑🏼‍🔬' => 'scientist: medium-fair skin',
    '🧑🏽‍🔬' => 'scientist: medium skin',
    '🧑🏾‍🔬' => 'scientist: medium-dark skin',
    '🧑🏿‍🔬' => 'scientist: dark skin',
    '👨🏻‍🔬' => 'male scientist: Fair skin',
    '👨🏼‍🔬' => 'male scientist: medium-fair skin',
    '👨🏽‍🔬' => 'male scientist: medium skin',
    '👨🏾‍🔬' => 'male scientist: medium-dark skin',
    '👨🏿‍🔬' => 'male scientist: dark skin',
    '👩🏻‍🔬' => 'woman scientist: Fair skin',
    '👩🏼‍🔬' => 'woman scientist: medium-fair skin',
    '👩🏽‍🔬' => 'woman scientist: medium skin',
    '👩🏾‍🔬' => 'woman scientist: medium-dark skin',
    '👩🏿‍🔬' => 'woman scientist: dark skin',
    '🧑🏻‍💻' => 'technologist: Fair skin',
    '🧑🏼‍💻' => 'technologist: medium-fair skin',
    '🧑🏽‍💻' => 'technologist: medium skin',
    '🧑🏾‍💻' => 'technologist: medium-dark skin',
    '🧑🏿‍💻' => 'technologist: dark skin',
    '👨🏻‍💻' => 'male technologist: Fair skin',
    '👨🏼‍💻' => 'male technologist: medium-fair skin',
    '👨🏽‍💻' => 'male technologist: medium skin',
    '👨🏾‍💻' => 'male technologist: medium-dark skin',
    '👨🏿‍💻' => 'male technologist: dark skin',
    '👩🏻‍💻' => 'female technologist: Fair skin',
    '👩🏼‍💻' => 'female technologist: medium-fair skin',
    '👩🏽‍💻' => 'female technologist: medium skin',
    '👩🏾‍💻' => 'female technologist: medium-dark skin',
    '👩🏿‍💻' => 'female technologist: dark skin',
    '🧑🏻‍🎤' => 'singer: Fair skin',
    '🧑🏼‍🎤' => 'singer: medium-fair skin',
    '🧑🏽‍🎤' => 'singer: medium skin',
    '🧑🏾‍🎤' => 'singer: medium-dark skin',
    '🧑🏿‍🎤' => 'singer: dark skin',
    '👨🏻‍🎤' => 'male singer: Fair skin',
    '👨🏼‍🎤' => 'male singer: medium-fair skin',
    '👨🏽‍🎤' => 'male singer: medium skin',
    '👨🏾‍🎤' => 'male singer: medium-dark skin',
    '👨🏿‍🎤' => 'male singer: dark skin',
    '👩🏻‍🎤' => 'female singer: Fair skin',
    '👩🏼‍🎤' => 'female singer: medium-fair skin',
    '👩🏽‍🎤' => 'female singer: medium skin',
    '👩🏾‍🎤' => 'female singer: medium-dark skin',
    '👩🏿‍🎤' => 'female singer: dark skin',
    '🧑🏻‍🎨' => 'artist: Fair skin',
    '🧑🏼‍🎨' => 'artist: medium-fair skin',
    '🧑🏽‍🎨' => 'artist: medium skin',
    '🧑🏾‍🎨' => 'artist: medium-dark skin',
    '🧑🏿‍🎨' => 'artist: dark skin',
    '👨🏻‍🎨' => 'male artist: Fair skin',
    '👨🏼‍🎨' => 'male artist: medium-fair skin',
    '👨🏽‍🎨' => 'male artist: medium skin',
    '👨🏾‍🎨' => 'male artist: medium-dark skin',
    '👨🏿‍🎨' => 'male artist: dark skin',
    '👩🏻‍🎨' => 'female artist: Fair skin',
    '👩🏼‍🎨' => 'female artist: medium-fair skin',
    '👩🏽‍🎨' => 'female artist: medium skin',
    '👩🏾‍🎨' => 'female artist: medium-dark skin',
    '👩🏿‍🎨' => 'female artist: dark skin',
    '🧑🏻‍✈' => 'pilot: Fair skin',
    '🧑🏼‍✈' => 'pilot: medium-fair skin',
    '🧑🏽‍✈' => 'pilot: medium skin',
    '🧑🏾‍✈' => 'pilot: medium-dark skin',
    '🧑🏿‍✈' => 'pilot: dark skin',
    '👨🏻‍✈' => 'male pilot: Fair skin',
    '👨🏼‍✈' => 'male pilot: medium-fair skin',
    '👨🏽‍✈' => 'male pilot: medium skin',
    '👨🏾‍✈' => 'male pilot: medium-dark skin',
    '👨🏿‍✈' => 'male pilot: dark skin',
    '👩🏻‍✈' => 'female pilot: Fair skin',
    '👩🏼‍✈' => 'female pilot: medium-fair skin',
    '👩🏽‍✈' => 'female pilot: medium skin',
    '👩🏾‍✈' => 'female pilot: medium-dark skin',
    '👩🏿‍✈' => 'female pilot: dark skin',
    '🧑🏻‍🚀' => 'astronaut: Fair skin',
    '🧑🏼‍🚀' => 'astronaut: medium-fair skin',
    '🧑🏽‍🚀' => 'astronaut: medium skin',
    '🧑🏾‍🚀' => 'astronaut: medium-dark skin',
    '🧑🏿‍🚀' => 'astronaut: dark skin',
    '👨🏻‍🚀' => 'male astronaut: Fair skin',
    '👨🏼‍🚀' => 'male astronaut: medium-fair skin',
    '👨🏽‍🚀' => 'male astronaut: medium skin',
    '👨🏾‍🚀' => 'male astronaut: medium-dark skin',
    '👨🏿‍🚀' => 'male astronaut: dark skin',
    '👩🏻‍🚀' => 'female astronaut: Fair skin',
    '👩🏼‍🚀' => 'female astronaut: medium-fair skin',
    '👩🏽‍🚀' => 'female astronaut: medium skin',
    '👩🏾‍🚀' => 'female astronaut: medium-dark skin',
    '👩🏿‍🚀' => 'female astronaut: dark skin',
    '🧑🏻‍🚒' => 'firefighter: Fair skin',
    '🧑🏼‍🚒' => 'firefighter: medium-fair skin',
    '🧑🏽‍🚒' => 'firefighter: medium skin',
    '🧑🏾‍🚒' => 'firefighter: medium-dark skin',
    '🧑🏿‍🚒' => 'firefighter: dark skin',
    '👨🏻‍🚒' => 'male firefighter: Fair skin',
    '👨🏼‍🚒' => 'male firefighter: medium-fair skin',
    '👨🏽‍🚒' => 'male firefighter: medium skin',
    '👨🏾‍🚒' => 'male firefighter: medium-dark skin',
    '👨🏿‍🚒' => 'male firefighter: dark skin',
    '👩🏻‍🚒' => 'female firefighter: Fair skin',
    '👩🏼‍🚒' => 'female firefighter: medium-fair skin',
    '👩🏽‍🚒' => 'female firefighter: medium skin',
    '👩🏾‍🚒' => 'female firefighter: medium-dark skin',
    '👩🏿‍🚒' => 'female firefighter: dark skin',
    '👮🏻‍♂' => 'male police officer: Fair skin',
    '👮🏼‍♂' => 'male police officer: medium-fair skin',
    '👮🏽‍♂' => 'male police officer: medium skin',
    '👮🏾‍♂' => 'male police officer: medium-dark skin',
    '👮🏿‍♂' => 'male police officer: dark skin',
    '👮🏻‍♀' => 'female police officer: Fair skin',
    '👮🏼‍♀' => 'female police officer: medium-fair skin',
    '👮🏽‍♀' => 'female police officer: medium skin',
    '👮🏾‍♀' => 'female police officer: medium-dark skin',
    '👮🏿‍♀' => 'female police officer: dark skin',
    '🕵🏻‍♂' => 'male detective: Fair skin',
    '🕵🏼‍♂' => 'male detective: medium-fair skin',
    '🕵🏽‍♂' => 'male detective: medium skin',
    '🕵🏾‍♂' => 'male detective: medium-dark skin',
    '🕵🏿‍♂' => 'male detective: dark skin',
    '🕵🏻‍♀' => 'female detective: Fair skin',
    '🕵🏼‍♀' => 'female detective: medium-fair skin',
    '🕵🏽‍♀' => 'female detective: medium skin',
    '🕵🏾‍♀' => 'female detective: medium-dark skin',
    '🕵🏿‍♀' => 'female detective: dark skin',
    '💂🏻‍♂' => 'male guard: Fair skin',
    '💂🏼‍♂' => 'male guard: medium-fair skin',
    '💂🏽‍♂' => 'male guard: medium skin',
    '💂🏾‍♂' => 'male guard: medium-dark skin',
    '💂🏿‍♂' => 'male guard: dark skin',
    '💂🏻‍♀' => 'female guard: Fair skin',
    '💂🏼‍♀' => 'female guard: medium-fair skin',
    '💂🏽‍♀' => 'female guard: medium skin',
    '💂🏾‍♀' => 'female guard: medium-dark skin',
    '💂🏿‍♀' => 'female guard: dark skin',
    '👷🏻‍♂' => 'male construction worker: Fair skin',
    '👷🏼‍♂' => 'male construction worker: medium-fair skin',
    '👷🏽‍♂' => 'male construction worker: medium skin',
    '👷🏾‍♂' => 'male construction worker: medium-dark skin',
    '👷🏿‍♂' => 'male construction worker: dark skin',
    '👷🏻‍♀' => 'female construction worker: Fair skin',
    '👷🏼‍♀' => 'female construction worker: medium-fair skin',
    '👷🏽‍♀' => 'female construction worker: medium skin',
    '👷🏾‍♀' => 'female construction worker: medium-dark skin',
    '👷🏿‍♀' => 'female construction worker: dark skin',
    '👳🏻‍♂' => 'turban wala aadmi: Fair skin',
    '👳🏼‍♂' => 'turban wala aadmi: medium-fair skin',
    '👳🏽‍♂' => 'turban wala aadmi: medium skin',
    '👳🏾‍♂' => 'turban wala aadmi: medium-dark skin',
    '👳🏿‍♂' => 'turban wala aadmi: dark skin',
    '👳🏻‍♀' => 'turban wali mahila: Fair skin',
    '👳🏼‍♀' => 'turban wali mahila: medium-fair skin',
    '👳🏽‍♀' => 'turban wali mahila: medium skin',
    '👳🏾‍♀' => 'turban wali mahila: medium-dark skin',
    '👳🏿‍♀' => 'turban wali mahila: dark skin',
    '🤵🏻‍♂' => 'suit boot mein aadmi: Fair skin',
    '🤵🏼‍♂' => 'suit boot mein aadmi: medium-fair skin',
    '🤵🏽‍♂' => 'suit boot mein aadmi: medium skin',
    '🤵🏾‍♂' => 'suit boot mein aadmi: medium-dark skin',
    '🤵🏿‍♂' => 'suit boot mein aadmi: dark skin',
    '🤵🏻‍♀' => 'suit boot mein mahila: Fair skin',
    '🤵🏼‍♀' => 'suit boot mein mahila: medium-fair skin',
    '🤵🏽‍♀' => 'suit boot mein mahila: medium skin',
    '🤵🏾‍♀' => 'suit boot mein mahila: medium-dark skin',
    '🤵🏿‍♀' => 'suit boot mein mahila: dark skin',
    '👰🏻‍♂' => 'Ghoonghat mein aadmi: Fair skin',
    '👰🏼‍♂' => 'Ghoonghat mein aadmi: medium-fair skin',
    '👰🏽‍♂' => 'Ghoonghat mein aadmi: medium skin',
    '👰🏾‍♂' => 'Ghoonghat mein aadmi: medium-dark skin',
    '👰🏿‍♂' => 'Ghoonghat mein aadmi: dark skin',
    '👰🏻‍♀' => 'parde mein dulhan: Fair skin',
    '👰🏼‍♀' => 'parde mein dulhan: medium-fair skin',
    '👰🏽‍♀' => 'parde mein dulhan: medium skin',
    '👰🏾‍♀' => 'parde mein dulhan: medium-dark skin',
    '👰🏿‍♀' => 'parde mein dulhan: dark skin',
    '👩🏻‍🍼' => 'baby ko feed karti mahila: Fair skin',
    '👩🏼‍🍼' => 'baby ko feed karti mahila: medium-fair skin',
    '👩🏽‍🍼' => 'baby ko feed karti mahila: medium skin',
    '👩🏾‍🍼' => 'baby ko feed karti mahila: medium-dark skin',
    '👩🏿‍🍼' => 'baby ko feed karti mahila: dark skin',
    '👨🏻‍🍼' => 'baby ko feed karta aadmi: Fair skin',
    '👨🏼‍🍼' => 'baby ko feed karta aadmi: medium-fair skin',
    '👨🏽‍🍼' => 'baby ko feed karta aadmi: medium skin',
    '👨🏾‍🍼' => 'baby ko feed karta aadmi: medium-dark skin',
    '👨🏿‍🍼' => 'baby ko feed karta aadmi: dark skin',
    '🧑🏻‍🍼' => 'baby ko feed karta vyakti: Fair skin',
    '🧑🏼‍🍼' => 'baby ko feed karta vyakti: medium-fair skin',
    '🧑🏽‍🍼' => 'baby ko feed karta vyakti: medium skin',
    '🧑🏾‍🍼' => 'baby ko feed karta vyakti: medium-dark skin',
    '🧑🏿‍🍼' => 'baby ko feed karta vyakti: dark skin',
    '🧑🏻‍🎄' => 'Mx Claus: Fair skin',
    '🧑🏼‍🎄' => 'Mx Claus: medium-fair skin',
    '🧑🏽‍🎄' => 'Mx Claus: medium skin',
    '🧑🏾‍🎄' => 'Mx Claus: medium-dark skin',
    '🧑🏿‍🎄' => 'Mx Claus: dark skin',
    '🦸🏻‍♂' => 'man superhero: Fair skin',
    '🦸🏼‍♂' => 'man superhero: medium-fair skin',
    '🦸🏽‍♂' => 'man superhero: medium skin',
    '🦸🏾‍♂' => 'man superhero: medium-dark skin',
    '🦸🏿‍♂' => 'man superhero: dark skin',
    '🦸🏻‍♀' => 'woman superhero: Fair skin',
    '🦸🏼‍♀' => 'woman superhero: medium-fair skin',
    '🦸🏽‍♀' => 'woman superhero: medium skin',
    '🦸🏾‍♀' => 'woman superhero: medium-dark skin',
    '🦸🏿‍♀' => 'woman superhero: dark skin',
    '🦹🏻‍♂' => 'man supervillain: Fair skin',
    '🦹🏼‍♂' => 'man supervillain: medium-fair skin',
    '🦹🏽‍♂' => 'man supervillain: medium skin',
    '🦹🏾‍♂' => 'man supervillain: medium-dark skin',
    '🦹🏿‍♂' => 'man supervillain: dark skin',
    '🦹🏻‍♀' => 'woman supervillain: Fair skin',
    '🦹🏼‍♀' => 'woman supervillain: medium-fair skin',
    '🦹🏽‍♀' => 'woman supervillain: medium skin',
    '🦹🏾‍♀' => 'woman supervillain: medium-dark skin',
    '🦹🏿‍♀' => 'woman supervillain: dark skin',
    '🧙🏻‍♂' => 'man mage: Fair skin',
    '🧙🏼‍♂' => 'man mage: medium-fair skin',
    '🧙🏽‍♂' => 'man mage: medium skin',
    '🧙🏾‍♂' => 'man mage: medium-dark skin',
    '🧙🏿‍♂' => 'man mage: dark skin',
    '🧙🏻‍♀' => 'woman mage: Fair skin',
    '🧙🏼‍♀' => 'woman mage: medium-fair skin',
    '🧙🏽‍♀' => 'woman mage: medium skin',
    '🧙🏾‍♀' => 'woman mage: medium-dark skin',
    '🧙🏿‍♀' => 'woman mage: dark skin',
    '🧚🏻‍♂' => 'man fairy: Fair skin',
    '🧚🏼‍♂' => 'man fairy: medium-fair skin',
    '🧚🏽‍♂' => 'man fairy: medium skin',
    '🧚🏾‍♂' => 'man fairy: medium-dark skin',
    '🧚🏿‍♂' => 'man fairy: dark skin',
    '🧚🏻‍♀' => 'woman fairy: Fair skin',
    '🧚🏼‍♀' => 'woman fairy: medium-fair skin',
    '🧚🏽‍♀' => 'woman fairy: medium skin',
    '🧚🏾‍♀' => 'woman fairy: medium-dark skin',
    '🧚🏿‍♀' => 'woman fairy: dark skin',
    '🧛🏻‍♂' => 'man vampire: Fair skin',
    '🧛🏼‍♂' => 'man vampire: medium-fair skin',
    '🧛🏽‍♂' => 'man vampire: medium skin',
    '🧛🏾‍♂' => 'man vampire: medium-dark skin',
    '🧛🏿‍♂' => 'man vampire: dark skin',
    '🧛🏻‍♀' => 'woman vampire: Fair skin',
    '🧛🏼‍♀' => 'woman vampire: medium-fair skin',
    '🧛🏽‍♀' => 'woman vampire: medium skin',
    '🧛🏾‍♀' => 'woman vampire: medium-dark skin',
    '🧛🏿‍♀' => 'woman vampire: dark skin',
    '🧜🏻‍♂' => 'merman: Fair skin',
    '🧜🏼‍♂' => 'merman: medium-fair skin',
    '🧜🏽‍♂' => 'merman: medium skin',
    '🧜🏾‍♂' => 'merman: medium-dark skin',
    '🧜🏿‍♂' => 'merman: dark skin',
    '🧜🏻‍♀' => 'mermaid: Fair skin',
    '🧜🏼‍♀' => 'mermaid: medium-fair skin',
    '🧜🏽‍♀' => 'mermaid: medium skin',
    '🧜🏾‍♀' => 'mermaid: medium-dark skin',
    '🧜🏿‍♀' => 'mermaid: dark skin',
    '🧝🏻‍♂' => 'man elf: Fair skin',
    '🧝🏼‍♂' => 'man elf: medium-fair skin',
    '🧝🏽‍♂' => 'man elf: medium skin',
    '🧝🏾‍♂' => 'man elf: medium-dark skin',
    '🧝🏿‍♂' => 'man elf: dark skin',
    '🧝🏻‍♀' => 'woman elf: Fair skin',
    '🧝🏼‍♀' => 'woman elf: medium-fair skin',
    '🧝🏽‍♀' => 'woman elf: medium skin',
    '🧝🏾‍♀' => 'woman elf: medium-dark skin',
    '🧝🏿‍♀' => 'woman elf: dark skin',
    '💆🏻‍♂' => 'massage karwaata aadmi: Fair skin',
    '💆🏼‍♂' => 'massage karwaata aadmi: medium-fair skin',
    '💆🏽‍♂' => 'massage karwaata aadmi: medium skin',
    '💆🏾‍♂' => 'massage karwaata aadmi: medium-dark skin',
    '💆🏿‍♂' => 'massage karwaata aadmi: dark skin',
    '💆🏻‍♀' => 'massage karwaati mahila: Fair skin',
    '💆🏼‍♀' => 'massage karwaati mahila: medium-fair skin',
    '💆🏽‍♀' => 'massage karwaati mahila: medium skin',
    '💆🏾‍♀' => 'massage karwaati mahila: medium-dark skin',
    '💆🏿‍♀' => 'massage karwaati mahila: dark skin',
    '💇🏻‍♂' => 'haircut leta aadmi: Fair skin',
    '💇🏼‍♂' => 'haircut leta aadmi: medium-fair skin',
    '💇🏽‍♂' => 'haircut leta aadmi: medium skin',
    '💇🏾‍♂' => 'haircut leta aadmi: medium-dark skin',
    '💇🏿‍♂' => 'haircut leta aadmi: dark skin',
    '💇🏻‍♀' => 'haircut leti mahila: Fair skin',
    '💇🏼‍♀' => 'haircut leti mahila: medium-fair skin',
    '💇🏽‍♀' => 'haircut leti mahila: medium skin',
    '💇🏾‍♀' => 'haircut leti mahila: medium-dark skin',
    '💇🏿‍♀' => 'haircut leti mahila: dark skin',
    '🚶🏻‍♂' => 'walk karta aadmi: Fair skin',
    '🚶🏼‍♂' => 'walk karta aadmi: medium-fair skin',
    '🚶🏽‍♂' => 'walk karta aadmi: medium skin',
    '🚶🏾‍♂' => 'walk karta aadmi: medium-dark skin',
    '🚶🏿‍♂' => 'walk karta aadmi: dark skin',
    '🚶🏻‍♀' => 'walk karti mahila: Fair skin',
    '🚶🏼‍♀' => 'walk karti mahila: medium-fair skin',
    '🚶🏽‍♀' => 'walk karti mahila: medium skin',
    '🚶🏾‍♀' => 'walk karti mahila: medium-dark skin',
    '🚶🏿‍♀' => 'walk karti mahila: dark skin',
    '🚶🏻‍➡' => 'walk karta vyakti: Fair skin, facing right',
    '🚶🏼‍➡' => 'walk karta vyakti: medium-fair skin, facing right',
    '🚶🏽‍➡' => 'walk karta vyakti: medium skin, facing right',
    '🚶🏾‍➡' => 'walk karta vyakti: medium-dark skin, facing right',
    '🚶🏿‍➡' => 'walk karta vyakti: dark skin, facing right',
    '🧍🏻‍♂' => 'khada aadmi: Fair skin',
    '🧍🏼‍♂' => 'khada aadmi: medium-fair skin',
    '🧍🏽‍♂' => 'khada aadmi: medium skin',
    '🧍🏾‍♂' => 'khada aadmi: medium-dark skin',
    '🧍🏿‍♂' => 'khada aadmi: dark skin',
    '🧍🏻‍♀' => 'khadi aurat: Fair skin',
    '🧍🏼‍♀' => 'khadi aurat: medium-fair skin',
    '🧍🏽‍♀' => 'khadi aurat: medium skin',
    '🧍🏾‍♀' => 'khadi aurat: medium-dark skin',
    '🧍🏿‍♀' => 'khadi aurat: dark skin',
    '🧎🏻‍♂' => 'knees par baitha aadmi: Fair skin',
    '🧎🏼‍♂' => 'knees par baitha aadmi: medium-fair skin',
    '🧎🏽‍♂' => 'knees par baitha aadmi: medium skin',
    '🧎🏾‍♂' => 'knees par baitha aadmi: medium-dark skin',
    '🧎🏿‍♂' => 'knees par baitha aadmi: dark skin',
    '🧎🏻‍♀' => 'knees par baithi mahila: Fair skin',
    '🧎🏼‍♀' => 'knees par baithi mahila: medium-fair skin',
    '🧎🏽‍♀' => 'knees par baithi mahila: medium skin',
    '🧎🏾‍♀' => 'knees par baithi mahila: medium-dark skin',
    '🧎🏿‍♀' => 'knees par baithi mahila: dark skin',
    '🧎🏻‍➡' => 'knees par baitha vyakti: Fair skin, facing right',
    '🧎🏼‍➡' => 'knees par baitha vyakti: medium-fair skin, facing right',
    '🧎🏽‍➡' => 'knees par baitha vyakti: medium skin, facing right',
    '🧎🏾‍➡' => 'knees par baitha vyakti: medium-dark skin, facing right',
    '🧎🏿‍➡' => 'knees par baitha vyakti: dark skin, facing right',
    '🧑🏻‍🦯' => 'white cane pakda hua vyakti: Fair skin',
    '🧑🏼‍🦯' => 'white cane pakda hua vyakti: medium-fair skin',
    '🧑🏽‍🦯' => 'white cane pakda hua vyakti: medium skin',
    '🧑🏾‍🦯' => 'white cane pakda hua vyakti: medium-dark skin',
    '🧑🏿‍🦯' => 'white cane pakda hua vyakti: dark skin',
    '👨🏻‍🦯' => 'white cane pakda hua aadmi: Fair skin',
    '👨🏼‍🦯' => 'white cane pakda hua aadmi: medium-fair skin',
    '👨🏽‍🦯' => 'white cane pakda hua aadmi: medium skin',
    '👨🏾‍🦯' => 'white cane pakda hua aadmi: medium-dark skin',
    '👨🏿‍🦯' => 'white cane pakda hua aadmi: dark skin',
    '👩🏻‍🦯' => 'white cane pakde hui mahila: Fair skin',
    '👩🏼‍🦯' => 'white cane pakde hui mahila: medium-fair skin',
    '👩🏽‍🦯' => 'white cane pakde hui mahila: medium skin',
    '👩🏾‍🦯' => 'white cane pakde hui mahila: medium-dark skin',
    '👩🏿‍🦯' => 'white cane pakde hui mahila: dark skin',
    '🧑🏻‍🦼' => 'motor wheelchair par baitha vyakti: Fair skin',
    '🧑🏼‍🦼' => 'motor wheelchair par baitha vyakti: medium-fair skin',
    '🧑🏽‍🦼' => 'motor wheelchair par baitha vyakti: medium skin',
    '🧑🏾‍🦼' => 'motor wheelchair par baitha vyakti: medium-dark skin',
    '🧑🏿‍🦼' => 'motor wheelchair par baitha vyakti: dark skin',
    '👨🏻‍🦼' => 'motor wheelchair par baitha aadmi: Fair skin',
    '👨🏼‍🦼' => 'motor wheelchair par baitha aadmi: medium-fair skin',
    '👨🏽‍🦼' => 'motor wheelchair par baitha aadmi: medium skin',
    '👨🏾‍🦼' => 'motor wheelchair par baitha aadmi: medium-dark skin',
    '👨🏿‍🦼' => 'motor wheelchair par baitha aadmi: dark skin',
    '👩🏻‍🦼' => 'motor wheelchair par baithi aurat: Fair skin',
    '👩🏼‍🦼' => 'motor wheelchair par baithi aurat: medium-fair skin',
    '👩🏽‍🦼' => 'motor wheelchair par baithi aurat: medium skin',
    '👩🏾‍🦼' => 'motor wheelchair par baithi aurat: medium-dark skin',
    '👩🏿‍🦼' => 'motor wheelchair par baithi aurat: dark skin',
    '🧑🏻‍🦽' => 'manual wheelchair par baitha vyakti: Fair skin',
    '🧑🏼‍🦽' => 'manual wheelchair par baitha vyakti: medium-fair skin',
    '🧑🏽‍🦽' => 'manual wheelchair par baitha vyakti: medium skin',
    '🧑🏾‍🦽' => 'manual wheelchair par baitha vyakti: medium-dark skin',
    '🧑🏿‍🦽' => 'manual wheelchair par baitha vyakti: dark skin',
    '👨🏻‍🦽' => 'manual wheelchair par baitha aadmi: Fair skin',
    '👨🏼‍🦽' => 'manual wheelchair par baitha aadmi: medium-fair skin',
    '👨🏽‍🦽' => 'manual wheelchair par baitha aadmi: medium skin',
    '👨🏾‍🦽' => 'manual wheelchair par baitha aadmi: medium-dark skin',
    '👨🏿‍🦽' => 'manual wheelchair par baitha aadmi: dark skin',
    '👩🏻‍🦽' => 'manual wheelchair par baithi mahila: Fair skin',
    '👩🏼‍🦽' => 'manual wheelchair par baithi mahila: medium-fair skin',
    '👩🏽‍🦽' => 'manual wheelchair par baithi mahila: medium skin',
    '👩🏾‍🦽' => 'manual wheelchair par baithi mahila: medium-dark skin',
    '👩🏿‍🦽' => 'manual wheelchair par baithi mahila: dark skin',
    '🏃🏻‍♂' => 'run karta aadmi: Fair skin',
    '🏃🏼‍♂' => 'run karta aadmi: medium-fair skin',
    '🏃🏽‍♂' => 'run karta aadmi: medium skin',
    '🏃🏾‍♂' => 'run karta aadmi: medium-dark skin',
    '🏃🏿‍♂' => 'run karta aadmi: dark skin',
    '🏃🏻‍♀' => 'run karti mahila: Fair skin',
    '🏃🏼‍♀' => 'run karti mahila: medium-fair skin',
    '🏃🏽‍♀' => 'run karti mahila: medium skin',
    '🏃🏾‍♀' => 'run karti mahila: medium-dark skin',
    '🏃🏿‍♀' => 'run karti mahila: dark skin',
    '🏃🏻‍➡' => 'run karta vyakti: Fair skin, facing right',
    '🏃🏼‍➡' => 'run karta vyakti: medium-fair skin, facing right',
    '🏃🏽‍➡' => 'run karta vyakti: medium skin, facing right',
    '🏃🏾‍➡' => 'run karta vyakti: medium-dark skin, facing right',
    '🏃🏿‍➡' => 'run karta vyakti: dark skin, facing right',
    '👯🏻‍♀' => 'khargosh ke kaan wali mahilaayein: Fair skin',
    '👯🏼‍♀' => 'khargosh ke kaan wali mahilaayein: medium-fair skin',
    '👯🏽‍♀' => 'khargosh ke kaan wali mahilaayein: medium skin',
    '👯🏾‍♀' => 'khargosh ke kaan wali mahilaayein: medium-dark skin',
    '👯🏿‍♀' => 'khargosh ke kaan wali mahilaayein: dark skin',
    '👯🏻‍♂' => 'khargosh ke kaan wale aadmi: Fair skin',
    '👯🏼‍♂' => 'khargosh ke kaan wale aadmi: medium-fair skin',
    '👯🏽‍♂' => 'khargosh ke kaan wale aadmi: medium skin',
    '👯🏾‍♂' => 'khargosh ke kaan wale aadmi: medium-dark skin',
    '👯🏿‍♂' => 'khargosh ke kaan wale aadmi: dark skin',
    '🧖🏻‍♂' => 'steamy room mein aadmi: Fair skin',
    '🧖🏼‍♂' => 'steamy room mein aadmi: medium-fair skin',
    '🧖🏽‍♂' => 'steamy room mein aadmi: medium skin',
    '🧖🏾‍♂' => 'steamy room mein aadmi: medium-dark skin',
    '🧖🏿‍♂' => 'steamy room mein aadmi: dark skin',
    '🧖🏻‍♀' => 'steamy room mein mahila: Fair skin',
    '🧖🏼‍♀' => 'steamy room mein mahila: medium-fair skin',
    '🧖🏽‍♀' => 'steamy room mein mahila: medium skin',
    '🧖🏾‍♀' => 'steamy room mein mahila: medium-dark skin',
    '🧖🏿‍♀' => 'steamy room mein mahila: dark skin',
    '🧗🏻‍♂' => 'climb karta aadmi: Fair skin',
    '🧗🏼‍♂' => 'climb karta aadmi: medium-fair skin',
    '🧗🏽‍♂' => 'climb karta aadmi: medium skin',
    '🧗🏾‍♂' => 'climb karta aadmi: medium-dark skin',
    '🧗🏿‍♂' => 'climb karta aadmi: dark skin',
    '🧗🏻‍♀' => 'climb karti mahila: Fair skin',
    '🧗🏼‍♀' => 'climb karti mahila: medium-fair skin',
    '🧗🏽‍♀' => 'climb karti mahila: medium skin',
    '🧗🏾‍♀' => 'climb karti mahila: medium-dark skin',
    '🧗🏿‍♀' => 'climb karti mahila: dark skin',
    '🏌🏻‍♂' => 'golf khelta aadmi: Fair skin',
    '🏌🏼‍♂' => 'golf khelta aadmi: medium-fair skin',
    '🏌🏽‍♂' => 'golf khelta aadmi: medium skin',
    '🏌🏾‍♂' => 'golf khelta aadmi: medium-dark skin',
    '🏌🏿‍♂' => 'golf khelta aadmi: dark skin',
    '🏌🏻‍♀' => 'golf khelti mahila: Fair skin',
    '🏌🏼‍♀' => 'golf khelti mahila: medium-fair skin',
    '🏌🏽‍♀' => 'golf khelti mahila: medium skin',
    '🏌🏾‍♀' => 'golf khelti mahila: medium-dark skin',
    '🏌🏿‍♀' => 'golf khelti mahila: dark skin',
    '🏄🏻‍♂' => 'surfing karta aadmi: Fair skin',
    '🏄🏼‍♂' => 'surfing karta aadmi: medium-fair skin',
    '🏄🏽‍♂' => 'surfing karta aadmi: medium skin',
    '🏄🏾‍♂' => 'surfing karta aadmi: medium-dark skin',
    '🏄🏿‍♂' => 'surfing karta aadmi: dark skin',
    '🏄🏻‍♀' => 'surfing karti mahila: Fair skin',
    '🏄🏼‍♀' => 'surfing karti mahila: medium-fair skin',
    '🏄🏽‍♀' => 'surfing karti mahila: medium skin',
    '🏄🏾‍♀' => 'surfing karti mahila: medium-dark skin',
    '🏄🏿‍♀' => 'surfing karti mahila: dark skin',
    '🚣🏻‍♂' => 'boat rowing karta aadmi: Fair skin',
    '🚣🏼‍♂' => 'boat rowing karta aadmi: medium-fair skin',
    '🚣🏽‍♂' => 'boat rowing karta aadmi: medium skin',
    '🚣🏾‍♂' => 'boat rowing karta aadmi: medium-dark skin',
    '🚣🏿‍♂' => 'boat rowing karta aadmi: dark skin',
    '🚣🏻‍♀' => 'boat rowing karti karti mahila: Fair skin',
    '🚣🏼‍♀' => 'boat rowing karti karti mahila: medium-fair skin',
    '🚣🏽‍♀' => 'boat rowing karti karti mahila: medium skin',
    '🚣🏾‍♀' => 'boat rowing karti karti mahila: medium-dark skin',
    '🚣🏿‍♀' => 'boat rowing karti karti mahila: dark skin',
    '🏊🏻‍♂' => 'swimming karta aadmi: Fair skin',
    '🏊🏼‍♂' => 'swimming karta aadmi: medium-fair skin',
    '🏊🏽‍♂' => 'swimming karta aadmi: medium skin',
    '🏊🏾‍♂' => 'swimming karta aadmi: medium-dark skin',
    '🏊🏿‍♂' => 'swimming karta aadmi: dark skin',
    '🏊🏻‍♀' => 'swimming karti mahila: Fair skin',
    '🏊🏼‍♀' => 'swimming karti mahila: medium-fair skin',
    '🏊🏽‍♀' => 'swimming karti mahila: medium skin',
    '🏊🏾‍♀' => 'swimming karti mahila: medium-dark skin',
    '🏊🏿‍♀' => 'swimming karti mahila: dark skin',
    '⛹🏻‍♂' => 'ball se khelta aadmi: Fair skin',
    '⛹🏼‍♂' => 'ball se khelta aadmi: medium-fair skin',
    '⛹🏽‍♂' => 'ball se khelta aadmi: medium skin',
    '⛹🏾‍♂' => 'ball se khelta aadmi: medium-dark skin',
    '⛹🏿‍♂' => 'ball se khelta aadmi: dark skin',
    '⛹🏻‍♀' => 'ball se khelti mahila: Fair skin',
    '⛹🏼‍♀' => 'ball se khelti mahila: medium-fair skin',
    '⛹🏽‍♀' => 'ball se khelti mahila: medium skin',
    '⛹🏾‍♀' => 'ball se khelti mahila: medium-dark skin',
    '⛹🏿‍♀' => 'ball se khelti mahila: dark skin',
    '🏋🏻‍♂' => 'weightlifting karta aadmi: Fair skin',
    '🏋🏼‍♂' => 'weightlifting karta aadmi: medium-fair skin',
    '🏋🏽‍♂' => 'weightlifting karta aadmi: medium skin',
    '🏋🏾‍♂' => 'weightlifting karta aadmi: medium-dark skin',
    '🏋🏿‍♂' => 'weightlifting karta aadmi: dark skin',
    '🏋🏻‍♀' => 'weightlifting karti mahila: Fair skin',
    '🏋🏼‍♀' => 'weightlifting karti mahila: medium-fair skin',
    '🏋🏽‍♀' => 'weightlifting karti mahila: medium skin',
    '🏋🏾‍♀' => 'weightlifting karti mahila: medium-dark skin',
    '🏋🏿‍♀' => 'weightlifting karti mahila: dark skin',
    '🚴🏻‍♂' => 'cycle chalaata aadmi: Fair skin',
    '🚴🏼‍♂' => 'cycle chalaata aadmi: medium-fair skin',
    '🚴🏽‍♂' => 'cycle chalaata aadmi: medium skin',
    '🚴🏾‍♂' => 'cycle chalaata aadmi: medium-dark skin',
    '🚴🏿‍♂' => 'cycle chalaata aadmi: dark skin',
    '🚴🏻‍♀' => 'cycle chalaati mahila: Fair skin',
    '🚴🏼‍♀' => 'cycle chalaati mahila: medium-fair skin',
    '🚴🏽‍♀' => 'cycle chalaati mahila: medium skin',
    '🚴🏾‍♀' => 'cycle chalaati mahila: medium-dark skin',
    '🚴🏿‍♀' => 'cycle chalaati mahila: dark skin',
    '🚵🏻‍♂' => 'mountain biking karta aadmi: Fair skin',
    '🚵🏼‍♂' => 'mountain biking karta aadmi: medium-fair skin',
    '🚵🏽‍♂' => 'mountain biking karta aadmi: medium skin',
    '🚵🏾‍♂' => 'mountain biking karta aadmi: medium-dark skin',
    '🚵🏿‍♂' => 'mountain biking karta aadmi: dark skin',
    '🚵🏻‍♀' => 'mountain biking karti mahila: Fair skin',
    '🚵🏼‍♀' => 'mountain biking karti mahila: medium-fair skin',
    '🚵🏽‍♀' => 'mountain biking karti mahila: medium skin',
    '🚵🏾‍♀' => 'mountain biking karti mahila: medium-dark skin',
    '🚵🏿‍♀' => 'mountain biking karti mahila: dark skin',
    '🤸🏻‍♂' => 'cartwheeling karta aadmi: Fair skin',
    '🤸🏼‍♂' => 'cartwheeling karta aadmi: medium-fair skin',
    '🤸🏽‍♂' => 'cartwheeling karta aadmi: medium skin',
    '🤸🏾‍♂' => 'cartwheeling karta aadmi: medium-dark skin',
    '🤸🏿‍♂' => 'cartwheeling karta aadmi: dark skin',
    '🤸🏻‍♀' => 'cartwheeling karti mahila: Fair skin',
    '🤸🏼‍♀' => 'cartwheeling karti mahila: medium-fair skin',
    '🤸🏽‍♀' => 'cartwheeling karti mahila: medium skin',
    '🤸🏾‍♀' => 'cartwheeling karti mahila: medium-dark skin',
    '🤸🏿‍♀' => 'cartwheeling karti mahila: dark skin',
    '🤼🏻‍♀' => 'wrestling karti mahilaayein: Fair skin',
    '🤼🏼‍♀' => 'wrestling karti mahilaayein: medium-fair skin',
    '🤼🏽‍♀' => 'wrestling karti mahilaayein: medium skin',
    '🤼🏾‍♀' => 'wrestling karti mahilaayein: medium-dark skin',
    '🤼🏿‍♀' => 'wrestling karti mahilaayein: dark skin',
    '🤼🏻‍♂' => 'wrestling karte aadmi: Fair skin',
    '🤼🏼‍♂' => 'wrestling karte aadmi: medium-fair skin',
    '🤼🏽‍♂' => 'wrestling karte aadmi: medium skin',
    '🤼🏾‍♂' => 'wrestling karte aadmi: medium-dark skin',
    '🤼🏿‍♂' => 'wrestling karte aadmi: dark skin',
    '🤽🏻‍♂' => 'water polo khelta aadmi: Fair skin',
    '🤽🏼‍♂' => 'water polo khelta aadmi: medium-fair skin',
    '🤽🏽‍♂' => 'water polo khelta aadmi: medium skin',
    '🤽🏾‍♂' => 'water polo khelta aadmi: medium-dark skin',
    '🤽🏿‍♂' => 'water polo khelta aadmi: dark skin',
    '🤽🏻‍♀' => 'water polo khelti mahila: Fair skin',
    '🤽🏼‍♀' => 'water polo khelti mahila: medium-fair skin',
    '🤽🏽‍♀' => 'water polo khelti mahila: medium skin',
    '🤽🏾‍♀' => 'water polo khelti mahila: medium-dark skin',
    '🤽🏿‍♀' => 'water polo khelti mahila: dark skin',
    '🤾🏻‍♂' => 'handball khelta aadmi: Fair skin',
    '🤾🏼‍♂' => 'handball khelta aadmi: medium-fair skin',
    '🤾🏽‍♂' => 'handball khelta aadmi: medium skin',
    '🤾🏾‍♂' => 'handball khelta aadmi: medium-dark skin',
    '🤾🏿‍♂' => 'handball khelta aadmi: dark skin',
    '🤾🏻‍♀' => 'handball khelti mahila: Fair skin',
    '🤾🏼‍♀' => 'handball khelti mahila: medium-fair skin',
    '🤾🏽‍♀' => 'handball khelti mahila: medium skin',
    '🤾🏾‍♀' => 'handball khelti mahila: medium-dark skin',
    '🤾🏿‍♀' => 'handball khelti mahila: dark skin',
    '🤹🏻‍♂' => 'juggling karta aadmi: Fair skin',
    '🤹🏼‍♂' => 'juggling karta aadmi: medium-fair skin',
    '🤹🏽‍♂' => 'juggling karta aadmi: medium skin',
    '🤹🏾‍♂' => 'juggling karta aadmi: medium-dark skin',
    '🤹🏿‍♂' => 'juggling karta aadmi: dark skin',
    '🤹🏻‍♀' => 'juggling karti mahila: Fair skin',
    '🤹🏼‍♀' => 'juggling karti mahila: medium-fair skin',
    '🤹🏽‍♀' => 'juggling karti mahila: medium skin',
    '🤹🏾‍♀' => 'juggling karti mahila: medium-dark skin',
    '🤹🏿‍♀' => 'juggling karti mahila: dark skin',
    '🧘🏻‍♂' => 'padmaasan mein baitha aadmi: Fair skin',
    '🧘🏼‍♂' => 'padmaasan mein baitha aadmi: medium-fair skin',
    '🧘🏽‍♂' => 'padmaasan mein baitha aadmi: medium skin',
    '🧘🏾‍♂' => 'padmaasan mein baitha aadmi: medium-dark skin',
    '🧘🏿‍♂' => 'padmaasan mein baitha aadmi: dark skin',
    '🧘🏻‍♀' => 'padmaasan mein baithi mahila: Fair skin',
    '🧘🏼‍♀' => 'padmaasan mein baithi mahila: medium-fair skin',
    '🧘🏽‍♀' => 'padmaasan mein baithi mahila: medium skin',
    '🧘🏾‍♀' => 'padmaasan mein baithi mahila: medium-dark skin',
    '🧘🏿‍♀' => 'padmaasan mein baithi mahila: dark skin',
    '🧑‍🦰' => 'व्यक्ति: लाल बाल',
    '🧑‍🦱' => 'व्यक्ति: घुँघराले बाल',
    '🧑‍🦳' => 'व्यक्ति: सफ़ेद बाल',
    '🧑‍🦲' => 'व्यक्ति: गंजा',
    '👨‍🦰' => 'पुरुष: लाल बाल',
    '👨‍🦱' => 'पुरुष: घुँघराले बाल',
    '👨‍🦳' => 'पुरुष: सफ़ेद बाल',
    '👨‍🦲' => 'पुरुष: गंजा',
    '👩‍🦰' => 'महिला: लाल बाल',
    '👩‍🦱' => 'महिला: घुँघराले बाल',
    '👩‍🦳' => 'महिला: सफ़ेद बाल',
    '👩‍🦲' => 'महिला: गंजा',
    '🚶‍➡' => 'walk karta vyakti: facing right',
    '🧎‍➡' => 'knees par baitha vyakti: facing right',
    '🏃‍➡' => 'run karta vyakti: facing right',
    '👨‍👦' => 'परिवार: पुरुष, लड़का',
    '👨‍👧' => 'परिवार: पुरुष, लड़की',
    '👩‍👦' => 'परिवार: महिला, लड़का',
    '👩‍👧' => 'परिवार: महिला, लड़की',
    '😶‍🌫' => 'baadlon mein face',
    '😮‍💨' => 'exhale karta face',
    '🙂‍↕' => 'oopar-neeche sir hilaana',
    '😵‍💫' => 'spiral eyes wala face',
    '❤‍🔥' => 'burning heart',
    '❤‍🩹' => 'recovering heart',
    '👁‍🗨' => 'speech bubble mein eye',
    '🧔‍♂' => 'male: beard',
    '👱‍♂' => 'male: blond hair',
    '🧔‍♀' => 'female: beard',
    '👱‍♀' => 'female: blond hair',
    '🙍‍♂' => 'frown karta aadmi',
    '🙍‍♀' => 'frown karti mahila',
    '🙎‍♂' => 'pout banaata aadmi',
    '🙎‍♀' => 'pout banaati mahila',
    '🙅‍♂' => 'NO kaa gesture deta aadmi',
    '🙅‍♀' => 'NO kaa gesture deti mahila',
    '🙆‍♂' => 'OK kaa gesture deta aadmi',
    '🙆‍♀' => 'OK kaa gesture deti mahila',
    '💁‍♂' => 'information desk kaa aadmi',
    '💁‍♀' => 'information desk ki mahila',
    '🙋‍♂' => 'haath uthaata aadmi',
    '🙋‍♀' => 'haath uthaati mahila',
    '🧏‍♂' => 'sun na paane wala aadmi',
    '🧏‍♀' => 'sun na paane wali mahila',
    '🙇‍♂' => 'bow karta aadmi',
    '🙇‍♀' => 'bow karti mahila',
    '🤦‍♂' => 'face par palm rakhe hua aadmi',
    '🤦‍♀' => 'face par palm rakhe huye mahila',
    '🤷‍♂' => 'shrug karta aadmi',
    '🤷‍♀' => 'shrug karti mahila',
    '🧑‍⚕' => 'स्वास्थ्य कार्यकर्ता',
    '👨‍⚕' => 'पुरुष स्वास्थ्य कार्यकर्ता',
    '👩‍⚕' => 'महिला स्वास्थ्य कार्यकर्ता',
    '🧑‍🎓' => 'विद्यार्थी',
    '👨‍🎓' => 'छात्र',
    '👩‍🎓' => 'छात्रा',
    '🧑‍🏫' => 'शिक्षक',
    '👨‍🏫' => 'अध्यापक',
    '👩‍🏫' => 'अध्यापिका',
    '🧑‍⚖' => 'जज',
    '👨‍⚖' => 'न्यायाधीश',
    '👩‍⚖' => 'महिला न्यायाधीश',
    '🧑‍🌾' => 'कृषक',
    '👨‍🌾' => 'किसान',
    '👩‍🌾' => 'महिला किसान',
    '🧑‍🍳' => 'बावर्ची',
    '👨‍🍳' => 'रसोइया',
    '👩‍🍳' => 'महिला रसोइया',
    '🧑‍🔧' => 'मैकेनिक',
    '👨‍🔧' => 'मिस्त्री',
    '👩‍🔧' => 'महिला मिस्त्री',
    '🧑‍🏭' => 'फ़ैक्ट्री मज़दूर',
    '👨‍🏭' => 'male factory worker',
    '👩‍🏭' => 'female factory worker',
    '🧑‍💼' => 'कार्यालय कार्यकर्ता',
    '👨‍💼' => 'पुरुष कार्यालय कार्यकर्ता',
    '👩‍💼' => 'महिला कार्यालय कार्यकर्ता',
    '🧑‍🔬' => 'वैज्ञानिक',
    '👨‍🔬' => 'male scientist',
    '👩‍🔬' => 'महिला वैज्ञानिक',
    '🧑‍💻' => 'टेक्नोलॉजिस्ट',
    '👨‍💻' => 'male technologist',
    '👩‍💻' => 'female technologist',
    '🧑‍🎤' => 'गानेवाला',
    '👨‍🎤' => 'male singer',
    '👩‍🎤' => 'female singer',
    '🧑‍🎨' => 'कलाकार',
    '👨‍🎨' => 'male artist',
    '👩‍🎨' => 'female artist',
    '🧑‍✈' => 'पायलट',
    '👨‍✈' => 'male pilot',
    '👩‍✈' => 'female pilot',
    '🧑‍🚀' => 'अंतरिक्ष यात्री',
    '👨‍🚀' => 'male astronaut',
    '👩‍🚀' => 'female astronaut',
    '🧑‍🚒' => 'अग्निशमक',
    '👨‍🚒' => 'male firefighter',
    '👩‍🚒' => 'female firefighter',
    '👮‍♂' => 'male police officer',
    '👮‍♀' => 'female police officer',
    '🕵‍♂' => 'male detective',
    '🕵‍♀' => 'female detective',
    '💂‍♂' => 'male guard',
    '💂‍♀' => 'female guard',
    '👷‍♂' => 'male construction worker',
    '👷‍♀' => 'female construction worker',
    '👳‍♂' => 'turban wala aadmi',
    '👳‍♀' => 'turban wali mahila',
    '🤵‍♂' => 'suit boot mein aadmi',
    '🤵‍♀' => 'suit boot mein mahila',
    '👰‍♂' => 'Ghoonghat mein aadmi',
    '👰‍♀' => 'parde mein dulhan',
    '👩‍🍼' => 'baby ko feed karti mahila',
    '👨‍🍼' => 'baby ko feed karta aadmi',
    '🧑‍🍼' => 'baby ko feed karta vyakti',
    '🧑‍🎄' => 'एम एक्स क्लाॅॅॅॅज़',
    '🦸‍♂' => 'पुरुष सुपरहीरो',
    '🦸‍♀' => 'महिला सुपरहीरो',
    '🦹‍♂' => 'पुरुष सुपरविलेन',
    '🦹‍♀' => 'महिला सुपरविलेन',
    '🧙‍♂' => 'करामाती पुरुष',
    '🧙‍♀' => 'करामाती महिला',
    '🧚‍♂' => 'देवदूत',
    '🧚‍♀' => 'अप्सरा',
    '🧛‍♂' => 'पुरुष वैम्पायर',
    '🧛‍♀' => 'महिला वैम्पायर',
    '🧜‍♂' => 'मत्स्यपुरुष',
    '🧜‍♀' => 'मत्स्यकन्या',
    '🧝‍♂' => 'जादुई पुरुष',
    '🧝‍♀' => 'जादुई स्त्री',
    '🧞‍♂' => 'पुरुष जिन्न',
    '🧞‍♀' => 'स्त्री जिन्न',
    '🧟‍♂' => 'पुरुष ज़ॉम्बी',
    '🧟‍♀' => 'महिला ज़ॉम्बी',
    '💆‍♂' => 'massage karwaata aadmi',
    '💆‍♀' => 'massage karwaati mahila',
    '💇‍♂' => 'haircut leta aadmi',
    '💇‍♀' => 'haircut leti mahila',
    '🚶‍♂' => 'walk karta aadmi',
    '🚶‍♀' => 'walk karti mahila',
    '🧍‍♂' => 'khada aadmi',
    '🧍‍♀' => 'khadi aurat',
    '🧎‍♂' => 'knees par baitha aadmi',
    '🧎‍♀' => 'knees par baithi mahila',
    '🧑‍🦯' => 'white cane pakda hua vyakti',
    '👨‍🦯' => 'white cane pakda hua aadmi',
    '👩‍🦯' => 'white cane pakde hui mahila',
    '🧑‍🦼' => 'motor wheelchair par baitha vyakti',
    '👨‍🦼' => 'motor wheelchair par baitha aadmi',
    '👩‍🦼' => 'motor wheelchair par baithi aurat',
    '🧑‍🦽' => 'manual wheelchair par baitha vyakti',
    '👨‍🦽' => 'manual wheelchair par baitha aadmi',
    '👩‍🦽' => 'manual wheelchair par baithi mahila',
    '🏃‍♂' => 'run karta aadmi',
    '🏃‍♀' => 'run karti mahila',
    '🧑‍🩰' => 'बैले डांसर',
    '👯‍♂' => 'khargosh ke kaan wale aadmi',
    '👯‍♀' => 'khargosh ke kaan wali mahilaayein',
    '🧖‍♂' => 'steamy room mein aadmi',
    '🧖‍♀' => 'steamy room mein mahila',
    '🧗‍♂' => 'climb karta aadmi',
    '🧗‍♀' => 'climb karti mahila',
    '🏌‍♂' => 'golf khelta aadmi',
    '🏌‍♀' => 'golf khelti mahila',
    '🏄‍♂' => 'surfing karta aadmi',
    '🏄‍♀' => 'surfing karti mahila',
    '🚣‍♂' => 'boat rowing karta aadmi',
    '🚣‍♀' => 'boat rowing karti karti mahila',
    '🏊‍♂' => 'swimming karta aadmi',
    '🏊‍♀' => 'swimming karti mahila',
    '⛹‍♂' => 'ball se khelta aadmi',
    '⛹‍♀' => 'ball se khelti mahila',
    '🏋‍♂' => 'weightlifting karta aadmi',
    '🏋‍♀' => 'weightlifting karti mahila',
    '🚴‍♂' => 'cycle chalaata aadmi',
    '🚴‍♀' => 'cycle chalaati mahila',
    '🚵‍♂' => 'mountain biking karta aadmi',
    '🚵‍♀' => 'mountain biking karti mahila',
    '🤸‍♂' => 'cartwheeling karta aadmi',
    '🤸‍♀' => 'cartwheeling karti mahila',
    '🤼‍♂' => 'wrestling karte aadmi',
    '🤼‍♀' => 'wrestling karti mahilaayein',
    '🤽‍♂' => 'water polo khelta aadmi',
    '🤽‍♀' => 'water polo khelti mahila',
    '🤾‍♂' => 'handball khelta aadmi',
    '🤾‍♀' => 'handball khelti mahila',
    '🤹‍♂' => 'juggling karta aadmi',
    '🤹‍♀' => 'juggling karti mahila',
    '🧘‍♂' => 'padmaasan mein baitha aadmi',
    '🧘‍♀' => 'padmaasan mein baithi mahila',
    '🧑‍🧒' => 'परिवार: वयस्क, बच्चा',
    '🐕‍🦺' => 'दिव्यांग सहायता कुत्ता',
    '🐈‍⬛' => 'काली बिल्ली',
    '🐻‍❄' => 'ध्रुवीय भालू',
    '🐦‍⬛' => 'काली चिड़िया',
    '🐦‍🔥' => 'फ़ीनिक्स',
    '🍋‍🟩' => 'neebu',
    '🍄‍🟫' => 'भूरा मशरूम',
    '⛓‍💥' => 'tooti hui zanjeer',
    '🏳‍🌈' => 'इंद्रधनुषी झंडा',
    '🏳‍⚧' => 'ट्रांसजेंडर झंडा',
    '🏴‍☠' => 'समुद्री दस्यु का झंडा',
    '👋🏻' => 'wave karta haath: Fair skin',
    '👋🏼' => 'wave karta haath: medium-fair skin',
    '👋🏽' => 'wave karta haath: medium skin',
    '👋🏾' => 'wave karta haath: medium-dark skin',
    '👋🏿' => 'wave karta haath: dark skin',
    '🤚🏻' => 'uthe huye haath ki back side: Fair skin',
    '🤚🏼' => 'uthe huye haath ki back side: medium-fair skin',
    '🤚🏽' => 'uthe huye haath ki back side: medium skin',
    '🤚🏾' => 'uthe huye haath ki back side: medium-dark skin',
    '🤚🏿' => 'uthe huye haath ki back side: dark skin',
    '🖐🏻' => 'faili fingers wala haath: Fair skin',
    '🖐🏼' => 'faili fingers wala haath: medium-fair skin',
    '🖐🏽' => 'faili fingers wala haath: medium skin',
    '🖐🏾' => 'faili fingers wala haath: medium-dark skin',
    '🖐🏿' => 'faili fingers wala haath: dark skin',
    '✋🏻' => 'utha hua haath: Fair skin',
    '✋🏼' => 'utha hua haath: medium-fair skin',
    '✋🏽' => 'utha hua haath: medium skin',
    '✋🏾' => 'utha hua haath: medium-dark skin',
    '✋🏿' => 'utha hua haath: dark skin',
    '🖖🏻' => 'vulcan salute: Fair skin',
    '🖖🏼' => 'vulcan salute: medium-fair skin',
    '🖖🏽' => 'vulcan salute: medium skin',
    '🖖🏾' => 'vulcan salute: medium-dark skin',
    '🖖🏿' => 'vulcan salute: dark skin',
    '🫱🏻' => 'rightwards hand: Fair skin',
    '🫱🏼' => 'rightwards hand: medium-fair skin',
    '🫱🏽' => 'rightwards hand: medium skin',
    '🫱🏾' => 'rightwards hand: medium-dark skin',
    '🫱🏿' => 'rightwards hand: dark skin',
    '🫲🏻' => 'leftwards hand: Fair skin',
    '🫲🏼' => 'leftwards hand: medium-fair skin',
    '🫲🏽' => 'leftwards hand: medium skin',
    '🫲🏾' => 'leftwards hand: medium-dark skin',
    '🫲🏿' => 'leftwards hand: dark skin',
    '🫳🏻' => 'palm down hand: Fair skin',
    '🫳🏼' => 'palm down hand: medium-fair skin',
    '🫳🏽' => 'palm down hand: medium skin',
    '🫳🏾' => 'palm down hand: medium-dark skin',
    '🫳🏿' => 'palm down hand: dark skin',
    '🫴🏻' => 'palm up hand: Fair skin',
    '🫴🏼' => 'palm up hand: medium-fair skin',
    '🫴🏽' => 'palm up hand: medium skin',
    '🫴🏾' => 'palm up hand: medium-dark skin',
    '🫴🏿' => 'palm up hand: dark skin',
    '🫷🏻' => 'leftwards pushing hand: Fair skin',
    '🫷🏼' => 'leftwards pushing hand: medium-fair skin',
    '🫷🏽' => 'leftwards pushing hand: medium skin',
    '🫷🏾' => 'leftwards pushing hand: medium-dark skin',
    '🫷🏿' => 'leftwards pushing hand: dark skin',
    '🫸🏻' => 'rightwards pushing hand: Fair skin',
    '🫸🏼' => 'rightwards pushing hand: medium-fair skin',
    '🫸🏽' => 'rightwards pushing hand: medium skin',
    '🫸🏾' => 'rightwards pushing hand: medium-dark skin',
    '🫸🏿' => 'rightwards pushing hand: dark skin',
    '👌🏻' => 'OK kaa symbol: Fair skin',
    '👌🏼' => 'OK kaa symbol: medium-fair skin',
    '👌🏽' => 'OK kaa symbol: medium skin',
    '👌🏾' => 'OK kaa symbol: medium-dark skin',
    '👌🏿' => 'OK kaa symbol: dark skin',
    '🤌🏻' => 'pinched fingers: Fair skin',
    '🤌🏼' => 'pinched fingers: medium-fair skin',
    '🤌🏽' => 'pinched fingers: medium skin',
    '🤌🏾' => 'pinched fingers: medium-dark skin',
    '🤌🏿' => 'pinched fingers: dark skin',
    '🤏🏻' => 'pinch dikhaata haath: Fair skin',
    '🤏🏼' => 'pinch dikhaata haath: medium-fair skin',
    '🤏🏽' => 'pinch dikhaata haath: medium skin',
    '🤏🏾' => 'pinch dikhaata haath: medium-dark skin',
    '🤏🏿' => 'pinch dikhaata haath: dark skin',
    '✌🏻' => 'victory dikhaata haath: Fair skin',
    '✌🏼' => 'victory dikhaata haath: medium-fair skin',
    '✌🏽' => 'victory dikhaata haath: medium skin',
    '✌🏾' => 'victory dikhaata haath: medium-dark skin',
    '✌🏿' => 'victory dikhaata haath: dark skin',
    '🤞🏻' => 'crossed fingers: Fair skin',
    '🤞🏼' => 'crossed fingers: medium-fair skin',
    '🤞🏽' => 'crossed fingers: medium skin',
    '🤞🏾' => 'crossed fingers: medium-dark skin',
    '🤞🏿' => 'crossed fingers: dark skin',
    '🫰🏻' => 'hand with index finger and thumb crossed: Fair skin',
    '🫰🏼' => 'hand with index finger and thumb crossed: medium-fair skin',
    '🫰🏽' => 'hand with index finger and thumb crossed: medium skin',
    '🫰🏾' => 'hand with index finger and thumb crossed: medium-dark skin',
    '🫰🏿' => 'hand with index finger and thumb crossed: dark skin',
    '🤟🏻' => 'love-you gesture: Fair skin',
    '🤟🏼' => 'love-you gesture: medium-fair skin',
    '🤟🏽' => 'love-you gesture: medium skin',
    '🤟🏾' => 'love-you gesture: medium-dark skin',
    '🤟🏿' => 'love-you gesture: dark skin',
    '🤘🏻' => 'horns kaa sign: Fair skin',
    '🤘🏼' => 'horns kaa sign: medium-fair skin',
    '🤘🏽' => 'horns kaa sign: medium skin',
    '🤘🏾' => 'horns kaa sign: medium-dark skin',
    '🤘🏿' => 'horns kaa sign: dark skin',
    '🤙🏻' => 'call me kaa ishaara karne wala haath: Fair skin',
    '🤙🏼' => 'call me kaa ishaara karne wala haath: medium-fair skin',
    '🤙🏽' => 'call me kaa ishaara karne wala haath: medium skin',
    '🤙🏾' => 'call me kaa ishaara karne wala haath: medium-dark skin',
    '🤙🏿' => 'call me kaa ishaara karne wala haath: dark skin',
    '👈🏻' => 'left mein point karti index finger: Fair skin',
    '👈🏼' => 'left mein point karti index finger: medium-fair skin',
    '👈🏽' => 'left mein point karti index finger: medium skin',
    '👈🏾' => 'left mein point karti index finger: medium-dark skin',
    '👈🏿' => 'left mein point karti index finger: dark skin',
    '👉🏻' => 'right mein point karti index finger: Fair skin',
    '👉🏼' => 'right mein point karti index finger: medium-fair skin',
    '👉🏽' => 'right mein point karti index finger: medium skin',
    '👉🏾' => 'right mein point karti index finger: medium-dark skin',
    '👉🏿' => 'right mein point karti index finger: dark skin',
    '👆🏻' => 'oopar ishaara karti index finger: Fair skin',
    '👆🏼' => 'oopar ishaara karti index finger: medium-fair skin',
    '👆🏽' => 'oopar ishaara karti index finger: medium skin',
    '👆🏾' => 'oopar ishaara karti index finger: medium-dark skin',
    '👆🏿' => 'oopar ishaara karti index finger: dark skin',
    '🖕🏻' => 'middle finger: Fair skin',
    '🖕🏼' => 'middle finger: medium-fair skin',
    '🖕🏽' => 'middle finger: medium skin',
    '🖕🏾' => 'middle finger: medium-dark skin',
    '🖕🏿' => 'middle finger: dark skin',
    '👇🏻' => 'neeche ishaara karti index finger: Fair skin',
    '👇🏼' => 'neeche ishaara karti index finger: medium-fair skin',
    '👇🏽' => 'neeche ishaara karti index finger: medium skin',
    '👇🏾' => 'neeche ishaara karti index finger: medium-dark skin',
    '👇🏿' => 'neeche ishaara karti index finger: dark skin',
    '☝🏻' => 'oopar point karti index finger: Fair skin',
    '☝🏼' => 'oopar point karti index finger: medium-fair skin',
    '☝🏽' => 'oopar point karti index finger: medium skin',
    '☝🏾' => 'oopar point karti index finger: medium-dark skin',
    '☝🏿' => 'oopar point karti index finger: dark skin',
    '🫵🏻' => 'viewer ki taraf pont karti index finger: Fair skin',
    '🫵🏼' => 'viewer ki taraf pont karti index finger: medium-fair skin',
    '🫵🏽' => 'viewer ki taraf pont karti index finger: medium skin',
    '🫵🏾' => 'viewer ki taraf pont karti index finger: medium-dark skin',
    '🫵🏿' => 'viewer ki taraf pont karti index finger: dark skin',
    '👍🏻' => 'thumbs up: Fair skin',
    '👍🏼' => 'thumbs up: medium-fair skin',
    '👍🏽' => 'thumbs up: medium skin',
    '👍🏾' => 'thumbs up: medium-dark skin',
    '👍🏿' => 'thumbs up: dark skin',
    '👎🏻' => 'thumbs down: Fair skin',
    '👎🏼' => 'thumbs down: medium-fair skin',
    '👎🏽' => 'thumbs down: medium skin',
    '👎🏾' => 'thumbs down: medium-dark skin',
    '👎🏿' => 'thumbs down: dark skin',
    '✊🏻' => 'raised fist: Fair skin',
    '✊🏼' => 'raised fist: medium-fair skin',
    '✊🏽' => 'raised fist: medium skin',
    '✊🏾' => 'raised fist: medium-dark skin',
    '✊🏿' => 'raised fist: dark skin',
    '👊🏻' => 'oncoming fist: Fair skin',
    '👊🏼' => 'oncoming fist: medium-fair skin',
    '👊🏽' => 'oncoming fist: medium skin',
    '👊🏾' => 'oncoming fist: medium-dark skin',
    '👊🏿' => 'oncoming fist: dark skin',
    '🤛🏻' => 'left-facing fist: Fair skin',
    '🤛🏼' => 'left-facing fist: medium-fair skin',
    '🤛🏽' => 'left-facing fist: medium skin',
    '🤛🏾' => 'left-facing fist: medium-dark skin',
    '🤛🏿' => 'left-facing fist: dark skin',
    '🤜🏻' => 'right-facing fist: Fair skin',
    '🤜🏼' => 'right-facing fist: medium-fair skin',
    '🤜🏽' => 'right-facing fist: medium skin',
    '🤜🏾' => 'right-facing fist: medium-dark skin',
    '🤜🏿' => 'right-facing fist: dark skin',
    '👏🏻' => 'clapping hands: Fair skin',
    '👏🏼' => 'clapping hands: medium-fair skin',
    '👏🏽' => 'clapping hands: medium skin',
    '👏🏾' => 'clapping hands: medium-dark skin',
    '👏🏿' => 'clapping hands: dark skin',
    '🙌🏻' => 'khush hokar dono haath uthaana: Fair skin',
    '🙌🏼' => 'khush hokar dono haath uthaana: medium-fair skin',
    '🙌🏽' => 'khush hokar dono haath uthaana: medium skin',
    '🙌🏾' => 'khush hokar dono haath uthaana: medium-dark skin',
    '🙌🏿' => 'khush hokar dono haath uthaana: dark skin',
    '🫶🏻' => 'haathon se bana heart: Fair skin',
    '🫶🏼' => 'haathon se bana heart: medium-fair skin',
    '🫶🏽' => 'haathon se bana heart: medium skin',
    '🫶🏾' => 'haathon se bana heart: medium-dark skin',
    '🫶🏿' => 'haathon se bana heart: dark skin',
    '👐🏻' => 'open hands: Fair skin',
    '👐🏼' => 'open hands: medium-fair skin',
    '👐🏽' => 'open hands: medium skin',
    '👐🏾' => 'open hands: medium-dark skin',
    '👐🏿' => 'open hands: dark skin',
    '🤲🏻' => 'palms ko eksaath oopar karna: Fair skin',
    '🤲🏼' => 'palms ko eksaath oopar karna: medium-fair skin',
    '🤲🏽' => 'palms ko eksaath oopar karna: medium skin',
    '🤲🏾' => 'palms ko eksaath oopar karna: medium-dark skin',
    '🤲🏿' => 'palms ko eksaath oopar karna: dark skin',
    '🤝🏻' => 'handshake: Fair skin',
    '🤝🏼' => 'handshake: medium-fair skin',
    '🤝🏽' => 'handshake: medium skin',
    '🤝🏾' => 'handshake: medium-dark skin',
    '🤝🏿' => 'handshake: dark skin',
    '🙏🏻' => 'namaste karna: Fair skin',
    '🙏🏼' => 'namaste karna: medium-fair skin',
    '🙏🏽' => 'namaste karna: medium skin',
    '🙏🏾' => 'namaste karna: medium-dark skin',
    '🙏🏿' => 'namaste karna: dark skin',
    '✍🏻' => 'likhta hua haath: Fair skin',
    '✍🏼' => 'likhta hua haath: medium-fair skin',
    '✍🏽' => 'likhta hua haath: medium skin',
    '✍🏾' => 'likhta hua haath: medium-dark skin',
    '✍🏿' => 'likhta hua haath: dark skin',
    '💅🏻' => 'nail polish: Fair skin',
    '💅🏼' => 'nail polish: medium-fair skin',
    '💅🏽' => 'nail polish: medium skin',
    '💅🏾' => 'nail polish: medium-dark skin',
    '💅🏿' => 'nail polish: dark skin',
    '🤳🏻' => 'selfie: Fair skin',
    '🤳🏼' => 'selfie: medium-fair skin',
    '🤳🏽' => 'selfie: medium skin',
    '🤳🏾' => 'selfie: medium-dark skin',
    '🤳🏿' => 'selfie: dark skin',
    '💪🏻' => 'flexed biceps: Fair skin',
    '💪🏼' => 'flexed biceps: medium-fair skin',
    '💪🏽' => 'flexed biceps: medium skin',
    '💪🏾' => 'flexed biceps: medium-dark skin',
    '💪🏿' => 'flexed biceps: dark skin',
    '🦵🏻' => 'leg: Fair skin',
    '🦵🏼' => 'leg: medium-fair skin',
    '🦵🏽' => 'leg: medium skin',
    '🦵🏾' => 'leg: medium-dark skin',
    '🦵🏿' => 'leg: dark skin',
    '🦶🏻' => 'foot: Fair skin',
    '🦶🏼' => 'foot: medium-fair skin',
    '🦶🏽' => 'foot: medium skin',
    '🦶🏾' => 'foot: medium-dark skin',
    '🦶🏿' => 'foot: dark skin',
    '👂🏻' => 'ear: Fair skin',
    '👂🏼' => 'ear: medium-fair skin',
    '👂🏽' => 'ear: medium skin',
    '👂🏾' => 'ear: medium-dark skin',
    '👂🏿' => 'ear: dark skin',
    '🦻🏻' => 'hearing aid laga kaan: Fair skin',
    '🦻🏼' => 'hearing aid laga kaan: medium-fair skin',
    '🦻🏽' => 'hearing aid laga kaan: medium skin',
    '🦻🏾' => 'hearing aid laga kaan: medium-dark skin',
    '🦻🏿' => 'hearing aid laga kaan: dark skin',
    '👃🏻' => 'nose: Fair skin',
    '👃🏼' => 'nose: medium-fair skin',
    '👃🏽' => 'nose: medium skin',
    '👃🏾' => 'nose: medium-dark skin',
    '👃🏿' => 'nose: dark skin',
    '👶🏻' => 'baby: Fair skin',
    '👶🏼' => 'baby: medium-fair skin',
    '👶🏽' => 'baby: medium skin',
    '👶🏾' => 'baby: medium-dark skin',
    '👶🏿' => 'baby: dark skin',
    '🧒🏻' => 'child: Fair skin',
    '🧒🏼' => 'child: medium-fair skin',
    '🧒🏽' => 'child: medium skin',
    '🧒🏾' => 'child: medium-dark skin',
    '🧒🏿' => 'child: dark skin',
    '👦🏻' => 'boy: Fair skin',
    '👦🏼' => 'boy: medium-fair skin',
    '👦🏽' => 'boy: medium skin',
    '👦🏾' => 'boy: medium-dark skin',
    '👦🏿' => 'boy: dark skin',
    '👧🏻' => 'girl: Fair skin',
    '👧🏼' => 'girl: medium-fair skin',
    '👧🏽' => 'girl: medium skin',
    '👧🏾' => 'girl: medium-dark skin',
    '👧🏿' => 'girl: dark skin',
    '🧑🏻' => 'person: Fair skin',
    '🧑🏼' => 'person: medium-fair skin',
    '🧑🏽' => 'person: medium skin',
    '🧑🏾' => 'person: medium-dark skin',
    '🧑🏿' => 'person: dark skin',
    '👱🏻' => 'person: Fair skin, blond hair',
    '👱🏼' => 'person: medium-fair skin, blond hair',
    '👱🏽' => 'person: medium skin, blond hair',
    '👱🏾' => 'person: medium-dark skin, blond hair',
    '👱🏿' => 'person: dark skin, blond hair',
    '👨🏻' => 'man: Fair skin',
    '👨🏼' => 'man: medium-fair skin',
    '👨🏽' => 'man: medium skin',
    '👨🏾' => 'man: medium-dark skin',
    '👨🏿' => 'man: dark skin',
    '🧔🏻' => 'person: Fair skin, beard',
    '🧔🏼' => 'person: medium-fair skin, beard',
    '🧔🏽' => 'person: medium skin, beard',
    '🧔🏾' => 'person: medium-dark skin, beard',
    '🧔🏿' => 'person: dark skin, beard',
    '👩🏻' => 'woman: Fair skin',
    '👩🏼' => 'woman: medium-fair skin',
    '👩🏽' => 'woman: medium skin',
    '👩🏾' => 'woman: medium-dark skin',
    '👩🏿' => 'woman: dark skin',
    '🧓🏻' => 'older person: Fair skin',
    '🧓🏼' => 'older person: medium-fair skin',
    '🧓🏽' => 'older person: medium skin',
    '🧓🏾' => 'older person: medium-dark skin',
    '🧓🏿' => 'older person: dark skin',
    '👴🏻' => 'old man: Fair skin',
    '👴🏼' => 'old man: medium-fair skin',
    '👴🏽' => 'old man: medium skin',
    '👴🏾' => 'old man: medium-dark skin',
    '👴🏿' => 'old man: dark skin',
    '👵🏻' => 'old woman: Fair skin',
    '👵🏼' => 'old woman: medium-fair skin',
    '👵🏽' => 'old woman: medium skin',
    '👵🏾' => 'old woman: medium-dark skin',
    '👵🏿' => 'old woman: dark skin',
    '🙍🏻' => 'frown karta person: Fair skin',
    '🙍🏼' => 'frown karta person: medium-fair skin',
    '🙍🏽' => 'frown karta person: medium skin',
    '🙍🏾' => 'frown karta person: medium-dark skin',
    '🙍🏿' => 'frown karta person: dark skin',
    '🙎🏻' => 'pout banaata vyakti: Fair skin',
    '🙎🏼' => 'pout banaata vyakti: medium-fair skin',
    '🙎🏽' => 'pout banaata vyakti: medium skin',
    '🙎🏾' => 'pout banaata vyakti: medium-dark skin',
    '🙎🏿' => 'pout banaata vyakti: dark skin',
    '🙅🏻' => 'NO kaa gesture deta vyakti: Fair skin',
    '🙅🏼' => 'NO kaa gesture deta vyakti: medium-fair skin',
    '🙅🏽' => 'NO kaa gesture deta vyakti: medium skin',
    '🙅🏾' => 'NO kaa gesture deta vyakti: medium-dark skin',
    '🙅🏿' => 'NO kaa gesture deta vyakti: dark skin',
    '🙆🏻' => 'OK kaa gesture deta vyakti: Fair skin',
    '🙆🏼' => 'OK kaa gesture deta vyakti: medium-fair skin',
    '🙆🏽' => 'OK kaa gesture deta vyakti: medium skin',
    '🙆🏾' => 'OK kaa gesture deta vyakti: medium-dark skin',
    '🙆🏿' => 'OK kaa gesture deta vyakti: dark skin',
    '💁🏻' => 'information desk kaa vyakti: Fair skin',
    '💁🏼' => 'information desk kaa vyakti: medium-fair skin',
    '💁🏽' => 'information desk kaa vyakti: medium skin',
    '💁🏾' => 'information desk kaa vyakti: medium-dark skin',
    '💁🏿' => 'information desk kaa vyakti: dark skin',
    '🙋🏻' => 'haath uthaata vyakti: Fair skin',
    '🙋🏼' => 'haath uthaata vyakti: medium-fair skin',
    '🙋🏽' => 'haath uthaata vyakti: medium skin',
    '🙋🏾' => 'haath uthaata vyakti: medium-dark skin',
    '🙋🏿' => 'haath uthaata vyakti: dark skin',
    '🧏🏻' => 'deaf person: Fair skin',
    '🧏🏼' => 'deaf person: medium-fair skin',
    '🧏🏽' => 'deaf person: medium skin',
    '🧏🏾' => 'deaf person: medium-dark skin',
    '🧏🏿' => 'deaf person: dark skin',
    '🙇🏻' => 'bow karta vyakti: Fair skin',
    '🙇🏼' => 'bow karta vyakti: medium-fair skin',
    '🙇🏽' => 'bow karta vyakti: medium skin',
    '🙇🏾' => 'bow karta vyakti: medium-dark skin',
    '🙇🏿' => 'bow karta vyakti: dark skin',
    '🤦🏻' => 'face par palm rakhe hua vyakti: Fair skin',
    '🤦🏼' => 'face par palm rakhe hua vyakti: medium-fair skin',
    '🤦🏽' => 'face par palm rakhe hua vyakti: medium skin',
    '🤦🏾' => 'face par palm rakhe hua vyakti: medium-dark skin',
    '🤦🏿' => 'face par palm rakhe hua vyakti: dark skin',
    '🤷🏻' => 'shrug karta vyakti: Fair skin',
    '🤷🏼' => 'shrug karta vyakti: medium-fair skin',
    '🤷🏽' => 'shrug karta vyakti: medium skin',
    '🤷🏾' => 'shrug karta vyakti: medium-dark skin',
    '🤷🏿' => 'shrug karta vyakti: dark skin',
    '👮🏻' => 'police officer: Fair skin',
    '👮🏼' => 'police officer: medium-fair skin',
    '👮🏽' => 'police officer: medium skin',
    '👮🏾' => 'police officer: medium-dark skin',
    '👮🏿' => 'police officer: dark skin',
    '🕵🏻' => 'detective: Fair skin',
    '🕵🏼' => 'detective: medium-fair skin',
    '🕵🏽' => 'detective: medium skin',
    '🕵🏾' => 'detective: medium-dark skin',
    '🕵🏿' => 'detective: dark skin',
    '💂🏻' => 'guard: Fair skin',
    '💂🏼' => 'guard: medium-fair skin',
    '💂🏽' => 'guard: medium skin',
    '💂🏾' => 'guard: medium-dark skin',
    '💂🏿' => 'guard: dark skin',
    '🥷🏻' => 'ninja: Fair skin',
    '🥷🏼' => 'ninja: medium-fair skin',
    '🥷🏽' => 'ninja: medium skin',
    '🥷🏾' => 'ninja: medium-dark skin',
    '🥷🏿' => 'ninja: dark skin',
    '👷🏻' => 'construction worker: Fair skin',
    '👷🏼' => 'construction worker: medium-fair skin',
    '👷🏽' => 'construction worker: medium skin',
    '👷🏾' => 'construction worker: medium-dark skin',
    '👷🏿' => 'construction worker: dark skin',
    '🫅🏻' => 'crown wala vyakti: Fair skin',
    '🫅🏼' => 'crown wala vyakti: medium-fair skin',
    '🫅🏽' => 'crown wala vyakti: medium skin',
    '🫅🏾' => 'crown wala vyakti: medium-dark skin',
    '🫅🏿' => 'crown wala vyakti: dark skin',
    '🤴🏻' => 'prince: Fair skin',
    '🤴🏼' => 'prince: medium-fair skin',
    '🤴🏽' => 'prince: medium skin',
    '🤴🏾' => 'prince: medium-dark skin',
    '🤴🏿' => 'prince: dark skin',
    '👸🏻' => 'princess: Fair skin',
    '👸🏼' => 'princess: medium-fair skin',
    '👸🏽' => 'princess: medium skin',
    '👸🏾' => 'princess: medium-dark skin',
    '👸🏿' => 'princess: dark skin',
    '👳🏻' => 'turban wala vyakti: Fair skin',
    '👳🏼' => 'turban wala vyakti: medium-fair skin',
    '👳🏽' => 'turban wala vyakti: medium skin',
    '👳🏾' => 'turban wala vyakti: medium-dark skin',
    '👳🏿' => 'turban wala vyakti: dark skin',
    '👲🏻' => 'skullcap wala aadmi: Fair skin',
    '👲🏼' => 'skullcap wala aadmi: medium-fair skin',
    '👲🏽' => 'skullcap wala aadmi: medium skin',
    '👲🏾' => 'skullcap wala aadmi: medium-dark skin',
    '👲🏿' => 'skullcap wala aadmi: dark skin',
    '🧕🏻' => 'headscarf pahne mahila: Fair skin',
    '🧕🏼' => 'headscarf pahne mahila: medium-fair skin',
    '🧕🏽' => 'headscarf pahne mahila: medium skin',
    '🧕🏾' => 'headscarf pahne mahila: medium-dark skin',
    '🧕🏿' => 'headscarf pahne mahila: dark skin',
    '🤵🏻' => 'suit boot mein vyakti: Fair skin',
    '🤵🏼' => 'suit boot mein vyakti: medium-fair skin',
    '🤵🏽' => 'suit boot mein vyakti: medium skin',
    '🤵🏾' => 'suit boot mein vyakti: medium-dark skin',
    '🤵🏿' => 'suit boot mein vyakti: dark skin',
    '👰🏻' => 'Ghoonghat mein bride: Fair skin',
    '👰🏼' => 'Ghoonghat mein bride: medium-fair skin',
    '👰🏽' => 'Ghoonghat mein bride: medium skin',
    '👰🏾' => 'Ghoonghat mein bride: medium-dark skin',
    '👰🏿' => 'Ghoonghat mein bride: dark skin',
    '🤰🏻' => 'pregnant woman: Fair skin',
    '🤰🏼' => 'pregnant woman: medium-fair skin',
    '🤰🏽' => 'pregnant woman: medium skin',
    '🤰🏾' => 'pregnant woman: medium-dark skin',
    '🤰🏿' => 'pregnant woman: dark skin',
    '🫃🏻' => 'pregnant man: Fair skin',
    '🫃🏼' => 'pregnant man: medium-fair skin',
    '🫃🏽' => 'pregnant man: medium skin',
    '🫃🏾' => 'pregnant man: medium-dark skin',
    '🫃🏿' => 'pregnant man: dark skin',
    '🫄🏻' => 'pregnant person: Fair skin',
    '🫄🏼' => 'pregnant person: medium-fair skin',
    '🫄🏽' => 'pregnant person: medium skin',
    '🫄🏾' => 'pregnant person: medium-dark skin',
    '🫄🏿' => 'pregnant person: dark skin',
    '🤱🏻' => 'breast-feeding: Fair skin',
    '🤱🏼' => 'breast-feeding: medium-fair skin',
    '🤱🏽' => 'breast-feeding: medium skin',
    '🤱🏾' => 'breast-feeding: medium-dark skin',
    '🤱🏿' => 'breast-feeding: dark skin',
    '👼🏻' => 'baby angel: Fair skin',
    '👼🏼' => 'baby angel: medium-fair skin',
    '👼🏽' => 'baby angel: medium skin',
    '👼🏾' => 'baby angel: medium-dark skin',
    '👼🏿' => 'baby angel: dark skin',
    '🎅🏻' => 'Santa Claus: Fair skin',
    '🎅🏼' => 'Santa Claus: medium-fair skin',
    '🎅🏽' => 'Santa Claus: medium skin',
    '🎅🏾' => 'Santa Claus: medium-dark skin',
    '🎅🏿' => 'Santa Claus: dark skin',
    '🤶🏻' => 'Mrs Claus: Fair skin',
    '🤶🏼' => 'Mrs Claus: medium-fair skin',
    '🤶🏽' => 'Mrs Claus: medium skin',
    '🤶🏾' => 'Mrs Claus: medium-dark skin',
    '🤶🏿' => 'Mrs Claus: dark skin',
    '🦸🏻' => 'superhero: Fair skin',
    '🦸🏼' => 'superhero: medium-fair skin',
    '🦸🏽' => 'superhero: medium skin',
    '🦸🏾' => 'superhero: medium-dark skin',
    '🦸🏿' => 'superhero: dark skin',
    '🦹🏻' => 'supervillain: Fair skin',
    '🦹🏼' => 'supervillain: medium-fair skin',
    '🦹🏽' => 'supervillain: medium skin',
    '🦹🏾' => 'supervillain: medium-dark skin',
    '🦹🏿' => 'supervillain: dark skin',
    '🧙🏻' => 'mage: Fair skin',
    '🧙🏼' => 'mage: medium-fair skin',
    '🧙🏽' => 'mage: medium skin',
    '🧙🏾' => 'mage: medium-dark skin',
    '🧙🏿' => 'mage: dark skin',
    '🧚🏻' => 'fairy: Fair skin',
    '🧚🏼' => 'fairy: medium-fair skin',
    '🧚🏽' => 'fairy: medium skin',
    '🧚🏾' => 'fairy: medium-dark skin',
    '🧚🏿' => 'fairy: dark skin',
    '🧛🏻' => 'vampire: Fair skin',
    '🧛🏼' => 'vampire: medium-fair skin',
    '🧛🏽' => 'vampire: medium skin',
    '🧛🏾' => 'vampire: medium-dark skin',
    '🧛🏿' => 'vampire: dark skin',
    '🧜🏻' => 'merperson: Fair skin',
    '🧜🏼' => 'merperson: medium-fair skin',
    '🧜🏽' => 'merperson: medium skin',
    '🧜🏾' => 'merperson: medium-dark skin',
    '🧜🏿' => 'merperson: dark skin',
    '🧝🏻' => 'elf: Fair skin',
    '🧝🏼' => 'elf: medium-fair skin',
    '🧝🏽' => 'elf: medium skin',
    '🧝🏾' => 'elf: medium-dark skin',
    '🧝🏿' => 'elf: dark skin',
    '💆🏻' => 'massage karwaata vyakti: Fair skin',
    '💆🏼' => 'massage karwaata vyakti: medium-fair skin',
    '💆🏽' => 'massage karwaata vyakti: medium skin',
    '💆🏾' => 'massage karwaata vyakti: medium-dark skin',
    '💆🏿' => 'massage karwaata vyakti: dark skin',
    '💇🏻' => 'haircut leta vyakti: Fair skin',
    '💇🏼' => 'haircut leta vyakti: medium-fair skin',
    '💇🏽' => 'haircut leta vyakti: medium skin',
    '💇🏾' => 'haircut leta vyakti: medium-dark skin',
    '💇🏿' => 'haircut leta vyakti: dark skin',
    '🚶🏻' => 'walk karta vyakti: Fair skin',
    '🚶🏼' => 'walk karta vyakti: medium-fair skin',
    '🚶🏽' => 'walk karta vyakti: medium skin',
    '🚶🏾' => 'walk karta vyakti: medium-dark skin',
    '🚶🏿' => 'walk karta vyakti: dark skin',
    '🧍🏻' => 'khada hua vyakti: Fair skin',
    '🧍🏼' => 'khada hua vyakti: medium-fair skin',
    '🧍🏽' => 'khada hua vyakti: medium skin',
    '🧍🏾' => 'khada hua vyakti: medium-dark skin',
    '🧍🏿' => 'khada hua vyakti: dark skin',
    '🧎🏻' => 'knees par baitha vyakti: Fair skin',
    '🧎🏼' => 'knees par baitha vyakti: medium-fair skin',
    '🧎🏽' => 'knees par baitha vyakti: medium skin',
    '🧎🏾' => 'knees par baitha vyakti: medium-dark skin',
    '🧎🏿' => 'knees par baitha vyakti: dark skin',
    '🏃🏻' => 'run karta vyakti: Fair skin',
    '🏃🏼' => 'run karta vyakti: medium-fair skin',
    '🏃🏽' => 'run karta vyakti: medium skin',
    '🏃🏾' => 'run karta vyakti: medium-dark skin',
    '🏃🏿' => 'run karta vyakti: dark skin',
    '💃🏻' => 'dance karti mahila: Fair skin',
    '💃🏼' => 'dance karti mahila: medium-fair skin',
    '💃🏽' => 'dance karti mahila: medium skin',
    '💃🏾' => 'dance karti mahila: medium-dark skin',
    '💃🏿' => 'dance karti mahila: dark skin',
    '🕺🏻' => 'dance karta aadmi: Fair skin',
    '🕺🏼' => 'dance karta aadmi: medium-fair skin',
    '🕺🏽' => 'dance karta aadmi: medium skin',
    '🕺🏾' => 'dance karta aadmi: medium-dark skin',
    '🕺🏿' => 'dance karta aadmi: dark skin',
    '🕴🏻' => 'hawa mein udta suit wala vyakti: Fair skin',
    '🕴🏼' => 'hawa mein udta suit wala vyakti: medium-fair skin',
    '🕴🏽' => 'hawa mein udta suit wala vyakti: medium skin',
    '🕴🏾' => 'hawa mein udta suit wala vyakti: medium-dark skin',
    '🕴🏿' => 'hawa mein udta suit wala vyakti: dark skin',
    '👯🏻' => 'khargosh ke kaan wale log: Fair skin',
    '👯🏼' => 'khargosh ke kaan wale log: medium-fair skin',
    '👯🏽' => 'khargosh ke kaan wale log: medium skin',
    '👯🏾' => 'khargosh ke kaan wale log: medium-dark skin',
    '👯🏿' => 'khargosh ke kaan wale log: dark skin',
    '🧖🏻' => 'steamy room mein vyakti: Fair skin',
    '🧖🏼' => 'steamy room mein vyakti: medium-fair skin',
    '🧖🏽' => 'steamy room mein vyakti: medium skin',
    '🧖🏾' => 'steamy room mein vyakti: medium-dark skin',
    '🧖🏿' => 'steamy room mein vyakti: dark skin',
    '🧗🏻' => 'climb karta vyakti: Fair skin',
    '🧗🏼' => 'climb karta vyakti: medium-fair skin',
    '🧗🏽' => 'climb karta vyakti: medium skin',
    '🧗🏾' => 'climb karta vyakti: medium-dark skin',
    '🧗🏿' => 'climb karta vyakti: dark skin',
    '🏇🏻' => 'horse racing: Fair skin',
    '🏇🏼' => 'horse racing: medium-fair skin',
    '🏇🏽' => 'horse racing: medium skin',
    '🏇🏾' => 'horse racing: medium-dark skin',
    '🏇🏿' => 'horse racing: dark skin',
    '🏂🏻' => 'snowboarder: Fair skin',
    '🏂🏼' => 'snowboarder: medium-fair skin',
    '🏂🏽' => 'snowboarder: medium skin',
    '🏂🏾' => 'snowboarder: medium-dark skin',
    '🏂🏿' => 'snowboarder: dark skin',
    '🏌🏻' => 'golf khelta vyakti: Fair skin',
    '🏌🏼' => 'golf khelta vyakti: medium-fair skin',
    '🏌🏽' => 'golf khelta vyakti: medium skin',
    '🏌🏾' => 'golf khelta vyakti: medium-dark skin',
    '🏌🏿' => 'golf khelta vyakti: dark skin',
    '🏄🏻' => 'surfing karta vyakti: Fair skin',
    '🏄🏼' => 'surfing karta vyakti: medium-fair skin',
    '🏄🏽' => 'surfing karta vyakti: medium skin',
    '🏄🏾' => 'surfing karta vyakti: medium-dark skin',
    '🏄🏿' => 'surfing karta vyakti: dark skin',
    '🚣🏻' => 'boat rowing karta vyakti: Fair skin',
    '🚣🏼' => 'boat rowing karta vyakti: medium-fair skin',
    '🚣🏽' => 'boat rowing karta vyakti: medium skin',
    '🚣🏾' => 'boat rowing karta vyakti: medium-dark skin',
    '🚣🏿' => 'boat rowing karta vyakti: dark skin',
    '🏊🏻' => 'swimming karta vyakti: Fair skin',
    '🏊🏼' => 'swimming karta vyakti: medium-fair skin',
    '🏊🏽' => 'swimming karta vyakti: medium skin',
    '🏊🏾' => 'swimming karta vyakti: medium-dark skin',
    '🏊🏿' => 'swimming karta vyakti: dark skin',
    '⛹🏻' => 'ball se khelta vyakti: Fair skin',
    '⛹🏼' => 'ball se khelta vyakti: medium-fair skin',
    '⛹🏽' => 'ball se khelta vyakti: medium skin',
    '⛹🏾' => 'ball se khelta vyakti: medium-dark skin',
    '⛹🏿' => 'ball se khelta vyakti: dark skin',
    '🏋🏻' => 'weightlifting karta vyakti: Fair skin',
    '🏋🏼' => 'weightlifting karta vyakti: medium-fair skin',
    '🏋🏽' => 'weightlifting karta vyakti: medium skin',
    '🏋🏾' => 'weightlifting karta vyakti: medium-dark skin',
    '🏋🏿' => 'weightlifting karta vyakti: dark skin',
    '🚴🏻' => 'cycle chalaata vyakti: Fair skin',
    '🚴🏼' => 'cycle chalaata vyakti: medium-fair skin',
    '🚴🏽' => 'cycle chalaata vyakti: medium skin',
    '🚴🏾' => 'cycle chalaata vyakti: medium-dark skin',
    '🚴🏿' => 'cycle chalaata vyakti: dark skin',
    '🚵🏻' => 'mountain biking karta vyakti: Fair skin',
    '🚵🏼' => 'mountain biking karta vyakti: medium-fair skin',
    '🚵🏽' => 'mountain biking karta vyakti: medium skin',
    '🚵🏾' => 'mountain biking karta vyakti: medium-dark skin',
    '🚵🏿' => 'mountain biking karta vyakti: dark skin',
    '🤸🏻' => 'cartwheeling karta vyakti: Fair skin',
    '🤸🏼' => 'cartwheeling karta vyakti: medium-fair skin',
    '🤸🏽' => 'cartwheeling karta vyakti: medium skin',
    '🤸🏾' => 'cartwheeling karta vyakti: medium-dark skin',
    '🤸🏿' => 'cartwheeling karta vyakti: dark skin',
    '🤼🏻' => 'wrestling karte log: Fair skin',
    '🤼🏼' => 'wrestling karte log: medium-fair skin',
    '🤼🏽' => 'wrestling karte log: medium skin',
    '🤼🏾' => 'wrestling karte log: medium-dark skin',
    '🤼🏿' => 'wrestling karte log: dark skin',
    '🤽🏻' => 'water polo khelta vyakti: Fair skin',
    '🤽🏼' => 'water polo khelta vyakti: medium-fair skin',
    '🤽🏽' => 'water polo khelta vyakti: medium skin',
    '🤽🏾' => 'water polo khelta vyakti: medium-dark skin',
    '🤽🏿' => 'water polo khelta vyakti: dark skin',
    '🤾🏻' => 'handball khelta vyakti: Fair skin',
    '🤾🏼' => 'handball khelta vyakti: medium-fair skin',
    '🤾🏽' => 'handball khelta vyakti: medium skin',
    '🤾🏾' => 'handball khelta vyakti: medium-dark skin',
    '🤾🏿' => 'handball khelta vyakti: dark skin',
    '🤹🏻' => 'juggling karta vyakti: Fair skin',
    '🤹🏼' => 'juggling karta vyakti: medium-fair skin',
    '🤹🏽' => 'juggling karta vyakti: medium skin',
    '🤹🏾' => 'juggling karta vyakti: medium-dark skin',
    '🤹🏿' => 'juggling karta vyakti: dark skin',
    '🧘🏻' => 'padmaasan mein baitha vyakti: Fair skin',
    '🧘🏼' => 'padmaasan mein baitha vyakti: medium-fair skin',
    '🧘🏽' => 'padmaasan mein baitha vyakti: medium skin',
    '🧘🏾' => 'padmaasan mein baitha vyakti: medium-dark skin',
    '🧘🏿' => 'padmaasan mein baitha vyakti: dark skin',
    '🛀🏻' => 'bath leta vyakti: Fair skin',
    '🛀🏼' => 'bath leta vyakti: medium-fair skin',
    '🛀🏽' => 'bath leta vyakti: medium skin',
    '🛀🏾' => 'bath leta vyakti: medium-dark skin',
    '🛀🏿' => 'bath leta vyakti: dark skin',
    '🛌🏻' => 'bed par sota vyakti: Fair skin',
    '🛌🏼' => 'bed par sota vyakti: medium-fair skin',
    '🛌🏽' => 'bed par sota vyakti: medium skin',
    '🛌🏾' => 'bed par sota vyakti: medium-dark skin',
    '🛌🏿' => 'bed par sota vyakti: dark skin',
    '👭🏻' => 'haath pakde do mahilaayein: Fair skin',
    '👭🏼' => 'haath pakde do mahilaayein: medium-fair skin',
    '👭🏽' => 'haath pakde do mahilaayein: medium skin',
    '👭🏾' => 'haath pakde do mahilaayein: medium-dark skin',
    '👭🏿' => 'haath pakde do mahilaayein: dark skin',
    '👫🏻' => 'haath mein haath liye aurat-aadmi: Fair skin',
    '👫🏼' => 'haath mein haath liye aurat-aadmi: medium-fair skin',
    '👫🏽' => 'haath mein haath liye aurat-aadmi: medium skin',
    '👫🏾' => 'haath mein haath liye aurat-aadmi: medium-dark skin',
    '👫🏿' => 'haath mein haath liye aurat-aadmi: dark skin',
    '👬🏻' => 'haath pakde do aadmi: Fair skin',
    '👬🏼' => 'haath pakde do aadmi: medium-fair skin',
    '👬🏽' => 'haath pakde do aadmi: medium skin',
    '👬🏾' => 'haath pakde do aadmi: medium-dark skin',
    '👬🏿' => 'haath pakde do aadmi: dark skin',
    '💏🏻' => 'kiss: Fair skin',
    '💏🏼' => 'kiss: medium-fair skin',
    '💏🏽' => 'kiss: medium skin',
    '💏🏾' => 'kiss: medium-dark skin',
    '💏🏿' => 'kiss: dark skin',
    '💑🏻' => 'heart symbol ke saath couple: Fair skin',
    '💑🏼' => 'heart symbol ke saath couple: medium-fair skin',
    '💑🏽' => 'heart symbol ke saath couple: medium skin',
    '💑🏾' => 'heart symbol ke saath couple: medium-dark skin',
    '💑🏿' => 'heart symbol ke saath couple: dark skin',
    '🇦🇨' => 'झंडा: असेंशन द्वीप',
    '🇦🇩' => 'झंडा: एंडोरा',
    '🇦🇪' => 'झंडा: संयुक्त अरब अमीरात',
    '🇦🇫' => 'झंडा: अफ़गानिस्तान',
    '🇦🇬' => 'झंडा: एंटिगुआ और बरबुडा',
    '🇦🇮' => 'झंडा: एंग्विला',
    '🇦🇱' => 'झंडा: अल्बानिया',
    '🇦🇲' => 'झंडा: आर्मेनिया',
    '🇦🇴' => 'झंडा: अंगोला',
    '🇦🇶' => 'झंडा: अंटार्कटिका',
    '🇦🇷' => 'झंडा: अर्जेंटीना',
    '🇦🇸' => 'झंडा: अमेरिकी समोआ',
    '🇦🇹' => 'झंडा: ऑस्ट्रिया',
    '🇦🇺' => 'झंडा: ऑस्ट्रेलिया',
    '🇦🇼' => 'झंडा: अरूबा',
    '🇦🇽' => 'flag: Aland Islands',
    '🇦🇿' => 'झंडा: अज़रबैजान',
    '🇧🇦' => 'झंडा: बोस्निया और हर्ज़ेगोविना',
    '🇧🇧' => 'झंडा: बारबाडोस',
    '🇧🇩' => 'झंडा: बांग्लादेश',
    '🇧🇪' => 'झंडा: बेल्जियम',
    '🇧🇫' => 'झंडा: बुर्किना फ़ासो',
    '🇧🇬' => 'झंडा: बुल्गारिया',
    '🇧🇭' => 'झंडा: बहरीन',
    '🇧🇮' => 'झंडा: बुरुंडी',
    '🇧🇯' => 'झंडा: बेनिन',
    '🇧🇱' => 'flag: St. Barthelemy',
    '🇧🇲' => 'झंडा: बरमूडा',
    '🇧🇳' => 'झंडा: ब्रूनेई',
    '🇧🇴' => 'झंडा: बोलीविया',
    '🇧🇶' => 'झंडा: कैरिबियन नीदरलैंड',
    '🇧🇷' => 'झंडा: ब्राज़ील',
    '🇧🇸' => 'झंडा: बहामास',
    '🇧🇹' => 'झंडा: भूटान',
    '🇧🇻' => 'झंडा: बोवेत द्वीप',
    '🇧🇼' => 'झंडा: बोत्स्वाना',
    '🇧🇾' => 'झंडा: बेलारूस',
    '🇧🇿' => 'झंडा: बेलीज़',
    '🇨🇦' => 'झंडा: कनाडा',
    '🇨🇨' => 'झंडा: कोकोस (कीलिंग) द्वीपसमूह',
    '🇨🇩' => 'झंडा: कांगो - किंशासा',
    '🇨🇫' => 'झंडा: मध्य अफ़्रीकी गणराज्य',
    '🇨🇬' => 'झंडा: कांगो – ब्राज़ाविल',
    '🇨🇭' => 'झंडा: स्विट्ज़रलैंड',
    '🇨🇮' => 'flag: Cote d’Ivoire',
    '🇨🇰' => 'झंडा: कुक द्वीपसमूह',
    '🇨🇱' => 'झंडा: चिली',
    '🇨🇲' => 'झंडा: कैमरून',
    '🇨🇳' => 'झंडा: चीन',
    '🇨🇴' => 'झंडा: कोलंबिया',
    '🇨🇵' => 'झंडा: क्लिपर्टन द्वीप',
    '🇨🇶' => 'झंडा: सार्क',
    '🇨🇷' => 'झंडा: कोस्टारिका',
    '🇨🇺' => 'झंडा: क्यूबा',
    '🇨🇻' => 'झंडा: केप वर्ड',
    '🇨🇼' => 'flag: Curacao',
    '🇨🇽' => 'झंडा: क्रिसमस द्वीप',
    '🇨🇾' => 'झंडा: साइप्रस',
    '🇨🇿' => 'झंडा: चेकिया',
    '🇩🇪' => 'झंडा: जर्मनी',
    '🇩🇬' => 'झंडा: डिएगो गार्सिया',
    '🇩🇯' => 'झंडा: जिबूती',
    '🇩🇰' => 'झंडा: डेनमार्क',
    '🇩🇲' => 'झंडा: डोमिनिका',
    '🇩🇴' => 'झंडा: डोमिनिकन गणराज्य',
    '🇩🇿' => 'झंडा: अल्जीरिया',
    '🇪🇦' => 'झंडा: सेउटा और मेलिला',
    '🇪🇨' => 'झंडा: इक्वाडोर',
    '🇪🇪' => 'झंडा: एस्टोनिया',
    '🇪🇬' => 'झंडा: मिस्र',
    '🇪🇭' => 'झंडा: पश्चिमी सहारा',
    '🇪🇷' => 'झंडा: इरिट्रिया',
    '🇪🇸' => 'झंडा: स्पेन',
    '🇪🇹' => 'झंडा: इथियोपिया',
    '🇪🇺' => 'झंडा: यूरोपीय संघ',
    '🇫🇮' => 'झंडा: फ़िनलैंड',
    '🇫🇯' => 'झंडा: फ़िजी',
    '🇫🇰' => 'झंडा: फ़ॉकलैंड द्वीपसमूह',
    '🇫🇲' => 'झंडा: माइक्रोनेशिया',
    '🇫🇴' => 'झंडा: फ़ेरो द्वीपसमूह',
    '🇫🇷' => 'झंडा: फ़्रांस',
    '🇬🇦' => 'झंडा: गैबॉन',
    '🇬🇧' => 'झंडा: यूनाइटेड किंगडम',
    '🇬🇩' => 'झंडा: ग्रेनाडा',
    '🇬🇪' => 'झंडा: जॉर्जिया',
    '🇬🇫' => 'झंडा: फ़्रेंच गुयाना',
    '🇬🇬' => 'झंडा: गर्नसी',
    '🇬🇭' => 'झंडा: घाना',
    '🇬🇮' => 'झंडा: जिब्राल्टर',
    '🇬🇱' => 'झंडा: ग्रीनलैंड',
    '🇬🇲' => 'झंडा: गाम्बिया',
    '🇬🇳' => 'झंडा: गिनी',
    '🇬🇵' => 'झंडा: ग्वाडेलूप',
    '🇬🇶' => 'झंडा: इक्वेटोरियल गिनी',
    '🇬🇷' => 'झंडा: यूनान',
    '🇬🇸' => 'झंडा: दक्षिण जॉर्जिया और दक्षिण सैंडविच द्वीपसमूह',
    '🇬🇹' => 'झंडा: ग्वाटेमाला',
    '🇬🇺' => 'झंडा: गुआम',
    '🇬🇼' => 'झंडा: गिनी-बिसाउ',
    '🇬🇾' => 'झंडा: गुयाना',
    '🇭🇰' => 'झंडा: हाँग काँग (चीन विशेष प्रशासनिक क्षेत्र)',
    '🇭🇲' => 'झंडा: हर्ड द्वीप और मैकडोनॉल्ड द्वीपसमूह',
    '🇭🇳' => 'झंडा: होंडूरास',
    '🇭🇷' => 'झंडा: क्रोएशिया',
    '🇭🇹' => 'झंडा: हैती',
    '🇭🇺' => 'झंडा: हंगरी',
    '🇮🇨' => 'झंडा: कैनेरी द्वीपसमूह',
    '🇮🇩' => 'झंडा: इंडोनेशिया',
    '🇮🇪' => 'झंडा: आयरलैंड',
    '🇮🇱' => 'झंडा: इज़राइल',
    '🇮🇲' => 'झंडा: आइल ऑफ़ मैन',
    '🇮🇳' => 'flag: Bharat',
    '🇮🇴' => 'झंडा: ब्रिटिश हिंद महासागरीय क्षेत्र',
    '🇮🇶' => 'झंडा: इराक',
    '🇮🇷' => 'झंडा: ईरान',
    '🇮🇸' => 'झंडा: आइसलैंड',
    '🇮🇹' => 'झंडा: इटली',
    '🇯🇪' => 'झंडा: जर्सी',
    '🇯🇲' => 'झंडा: जमैका',
    '🇯🇴' => 'झंडा: जॉर्डन',
    '🇯🇵' => 'झंडा: जापान',
    '🇰🇪' => 'झंडा: केन्या',
    '🇰🇬' => 'झंडा: किर्गिज़स्तान',
    '🇰🇭' => 'झंडा: कंबोडिया',
    '🇰🇮' => 'झंडा: किरिबाती',
    '🇰🇲' => 'झंडा: कोमोरोस',
    '🇰🇳' => 'flag: St. Kitts & Nevis',
    '🇰🇵' => 'झंडा: उत्तर कोरिया',
    '🇰🇷' => 'झंडा: दक्षिण कोरिया',
    '🇰🇼' => 'झंडा: कुवैत',
    '🇰🇾' => 'झंडा: कैमेन द्वीपसमूह',
    '🇰🇿' => 'झंडा: कज़ाखस्तान',
    '🇱🇦' => 'झंडा: लाओस',
    '🇱🇧' => 'झंडा: लेबनान',
    '🇱🇨' => 'flag: St. Lucia',
    '🇱🇮' => 'झंडा: लिचेंस्टीन',
    '🇱🇰' => 'झंडा: श्रीलंका',
    '🇱🇷' => 'झंडा: लाइबेरिया',
    '🇱🇸' => 'झंडा: लेसोथो',
    '🇱🇹' => 'झंडा: लिथुआनिया',
    '🇱🇺' => 'झंडा: लग्ज़मबर्ग',
    '🇱🇻' => 'झंडा: लातविया',
    '🇱🇾' => 'झंडा: लीबिया',
    '🇲🇦' => 'झंडा: मोरक्को',
    '🇲🇨' => 'झंडा: मोनाको',
    '🇲🇩' => 'झंडा: मॉल्डोवा',
    '🇲🇪' => 'झंडा: मोंटेनेग्रो',
    '🇲🇫' => 'flag: St. Martin',
    '🇲🇬' => 'झंडा: मेडागास्कर',
    '🇲🇭' => 'झंडा: मार्शल द्वीपसमूह',
    '🇲🇰' => 'झंडा: उत्तरी मकदूनिया',
    '🇲🇱' => 'झंडा: माली',
    '🇲🇲' => 'झंडा: म्यांमार (बर्मा)',
    '🇲🇳' => 'झंडा: मंगोलिया',
    '🇲🇴' => 'झंडा: मकाऊ (विशेष प्रशासनिक क्षेत्र चीन)',
    '🇲🇵' => 'झंडा: उत्तरी मारियाना द्वीपसमूह',
    '🇲🇶' => 'झंडा: मार्टीनिक',
    '🇲🇷' => 'झंडा: मॉरिटानिया',
    '🇲🇸' => 'झंडा: मोंटसेरात',
    '🇲🇹' => 'झंडा: माल्टा',
    '🇲🇺' => 'झंडा: मॉरीशस',
    '🇲🇻' => 'झंडा: मालदीव',
    '🇲🇼' => 'झंडा: मलावी',
    '🇲🇽' => 'झंडा: मैक्सिको',
    '🇲🇾' => 'झंडा: मलेशिया',
    '🇲🇿' => 'झंडा: मोज़ांबिक',
    '🇳🇦' => 'झंडा: नामीबिया',
    '🇳🇨' => 'झंडा: न्यू कैलेडोनिया',
    '🇳🇪' => 'झंडा: नाइजर',
    '🇳🇫' => 'झंडा: नॉरफ़ॉक द्वीप',
    '🇳🇬' => 'झंडा: नाइजीरिया',
    '🇳🇮' => 'झंडा: निकारागुआ',
    '🇳🇱' => 'झंडा: नीदरलैंड',
    '🇳🇴' => 'झंडा: नॉर्वे',
    '🇳🇵' => 'झंडा: नेपाल',
    '🇳🇷' => 'झंडा: नाउरु',
    '🇳🇺' => 'झंडा: नीयू',
    '🇳🇿' => 'झंडा: न्यूज़ीलैंड',
    '🇴🇲' => 'झंडा: ओमान',
    '🇵🇦' => 'झंडा: पनामा',
    '🇵🇪' => 'झंडा: पेरू',
    '🇵🇫' => 'झंडा: फ़्रेंच पोलिनेशिया',
    '🇵🇬' => 'झंडा: पापुआ न्यू गिनी',
    '🇵🇭' => 'झंडा: फ़िलिपींस',
    '🇵🇰' => 'झंडा: पाकिस्तान',
    '🇵🇱' => 'झंडा: पोलैंड',
    '🇵🇲' => 'flag: St. Pierre & Miquelon',
    '🇵🇳' => 'झंडा: पिटकैर्न द्वीपसमूह',
    '🇵🇷' => 'झंडा: पोर्टो रिको',
    '🇵🇸' => 'झंडा: फ़िलिस्तीनी क्षेत्र',
    '🇵🇹' => 'झंडा: पुर्तगाल',
    '🇵🇼' => 'झंडा: पलाऊ',
    '🇵🇾' => 'झंडा: पराग्वे',
    '🇶🇦' => 'झंडा: क़तर',
    '🇷🇪' => 'flag: Reunion',
    '🇷🇴' => 'झंडा: रोमानिया',
    '🇷🇸' => 'झंडा: सर्बिया',
    '🇷🇺' => 'झंडा: रूस',
    '🇷🇼' => 'झंडा: रवांडा',
    '🇸🇦' => 'झंडा: सऊदी अरब',
    '🇸🇧' => 'झंडा: सोलोमन द्वीपसमूह',
    '🇸🇨' => 'झंडा: सेशेल्स',
    '🇸🇩' => 'झंडा: सूडान',
    '🇸🇪' => 'झंडा: स्वीडन',
    '🇸🇬' => 'झंडा: सिंगापुर',
    '🇸🇭' => 'flag: St. Helena',
    '🇸🇮' => 'झंडा: स्लोवेनिया',
    '🇸🇯' => 'झंडा: स्वालबार्ड और जान मायेन',
    '🇸🇰' => 'झंडा: स्लोवाकिया',
    '🇸🇱' => 'झंडा: सिएरा लियोन',
    '🇸🇲' => 'झंडा: सैन मेरीनो',
    '🇸🇳' => 'झंडा: सेनेगल',
    '🇸🇴' => 'झंडा: सोमालिया',
    '🇸🇷' => 'झंडा: सूरीनाम',
    '🇸🇸' => 'झंडा: दक्षिण सूडान',
    '🇸🇹' => 'flag: Sao Tome & Principe',
    '🇸🇻' => 'झंडा: अल सल्वाडोर',
    '🇸🇽' => 'झंडा: सिंट मार्टिन',
    '🇸🇾' => 'झंडा: सीरिया',
    '🇸🇿' => 'झंडा: एस्वाटिनी',
    '🇹🇦' => 'झंडा: ट्रिस्टन दा कुना',
    '🇹🇨' => 'झंडा: तुर्क और कैकोज़ द्वीपसमूह',
    '🇹🇩' => 'झंडा: चाड',
    '🇹🇫' => 'झंडा: फ़्रांसीसी दक्षिणी क्षेत्र',
    '🇹🇬' => 'झंडा: टोगो',
    '🇹🇭' => 'झंडा: थाईलैंड',
    '🇹🇯' => 'झंडा: ताजिकिस्तान',
    '🇹🇰' => 'झंडा: तोकेलाउ',
    '🇹🇱' => 'झंडा: तिमोर-लेस्त',
    '🇹🇲' => 'झंडा: तुर्कमेनिस्तान',
    '🇹🇳' => 'झंडा: ट्यूनीशिया',
    '🇹🇴' => 'झंडा: टोंगा',
    '🇹🇷' => 'flag: Turkiye',
    '🇹🇹' => 'झंडा: त्रिनिदाद और टोबैगो',
    '🇹🇻' => 'झंडा: तुवालू',
    '🇹🇼' => 'झंडा: ताइवान',
    '🇹🇿' => 'झंडा: तंज़ानिया',
    '🇺🇦' => 'झंडा: यूक्रेन',
    '🇺🇬' => 'झंडा: युगांडा',
    '🇺🇲' => 'flag: U.S. Outlying Islands',
    '🇺🇳' => 'झंडा: संयुक्त राष्ट्र',
    '🇺🇸' => 'झंडा: संयुक्त राज्य',
    '🇺🇾' => 'झंडा: उरूग्वे',
    '🇺🇿' => 'झंडा: उज़्बेकिस्तान',
    '🇻🇦' => 'झंडा: वेटिकन सिटी',
    '🇻🇨' => 'flag: St. Vincent & Grenadines',
    '🇻🇪' => 'झंडा: वेनेज़ुएला',
    '🇻🇬' => 'झंडा: ब्रिटिश वर्जिन द्वीपसमूह',
    '🇻🇮' => 'flag: U.S. Virgin Islands',
    '🇻🇳' => 'झंडा: वियतनाम',
    '🇻🇺' => 'झंडा: वनुआतू',
    '🇼🇫' => 'झंडा: वालिस और फ़्यूचूना',
    '🇼🇸' => 'झंडा: समोआ',
    '🇽🇰' => 'झंडा: कोसोवो',
    '🇾🇪' => 'झंडा: यमन',
    '🇾🇹' => 'झंडा: मायोते',
    '🇿🇦' => 'झंडा: दक्षिण अफ़्रीका',
    '🇿🇲' => 'झंडा: ज़ाम्बिया',
    '🇿🇼' => 'झंडा: ज़िम्बाब्वे',
    '🔟' => 'कीकैप: 10',
    '🏻' => 'Fair skin',
    '🏼' => 'medium-fair skin',
    '🏽' => 'medium skin',
    '🏾' => 'medium-dark skin',
    '🏿' => 'dark skin',
    '😀' => 'दाँत दिखाता चेहरा',
    '😃' => 'badi aankhon wala grinning face',
    '😄' => 'smile karti aankhon wala grinning face',
    '😁' => 'smile karti aankhon wala beaming face',
    '😆' => 'बंद आँखों वाला दाँत दिखाता चेहरा',
    '😅' => 'sweating wala grinning face',
    '🤣' => 'हँसते हँसते लोट-पोट होना',
    '😂' => 'face',
    '🙂' => 'हल्की मुस्कान वाला चेहरा',
    '🙃' => 'उल्टा चेहरा',
    '🫠' => 'पिघलता चेहरा',
    '😉' => 'आँख मारता चेहरा',
    '😊' => 'smiling eyes wala smiling face',
    '😇' => 'प्रभामंडल वाली मुस्कान वाला चेहरा',
    '🥰' => 'hearts wala smiling face',
    '😍' => 'heart-eyes wala smiling face',
    '🤩' => 'सितारा आँखें',
    '😘' => 'kiss deta face',
    '😗' => 'चुंबन वाला चेहरा',
    '☺' => 'मुस्काता चेहरा',
    '😚' => 'closed eyes wala kissing face',
    '😙' => 'smiling eyes wala kissing face',
    '🥲' => 'aansoo wala smiling face',
    '😋' => 'food enjoy karta face',
    '😛' => 'tongue dikhaata face',
    '😜' => 'tongue dikhaata winking face',
    '🤪' => 'अजीबोगरीब मज़ाकिया चेहरा',
    '😝' => 'tongue nikaalta squinting face',
    '🤑' => 'धनयुक्त चेहरा',
    '🤗' => 'hug karta smiling face',
    '🤭' => 'mouth par haath wala face',
    '🫢' => 'khuli aankhein aur munh par haath',
    '🫣' => 'fingers ke beech se jhaankta face',
    '🤫' => 'शांत रहने का इशारा करता हुआ चेहरा',
    '🤔' => 'सोचता हुआ चेहरा',
    '🫡' => 'सलामी देता चेहरा',
    '🤐' => 'ज़िपर-मुँह वाला चेहरा',
    '🤨' => 'raised eyebrow wala face',
    '😐' => 'भावहीन चेहरा',
    '😑' => 'अभिव्यक्तिरहित चेहरा',
    '😶' => 'bina mouth wala face',
    '🫥' => 'बिंदीयुक्त रेखांकित चेहरा',
    '😏' => 'बनावटी हँसी वाला चेहरा',
    '😒' => 'अप्रसन्न चेहरा',
    '🙄' => 'rolling eyes wala face',
    '😬' => 'मुंह बनाता चेहरा',
    '🤥' => 'झूठ बोलता चेहरा',
    '🫨' => 'थरथराता चेहरा',
    '😌' => 'चिंतामुक्त चेहरा',
    '😔' => 'निरुत्साहित चेहरा',
    '😪' => 'उनींदा चेहरा',
    '🤤' => 'लार टपकता चेहरा',
    '😴' => 'सोया हुआ चेहरा',
    '🫩' => 'baggy under eyes wala face',
    '😷' => 'medical mask wala face',
    '🤒' => 'thermometer wala face',
    '🤕' => 'head-bandage wala face',
    '🤢' => 'उल्टी करता चेहरा',
    '🤮' => 'उल्टी करता हुआ चेहरा',
    '🤧' => 'छींकता चेहरा',
    '🥵' => 'गर्मी से लाल चेहरा',
    '🥶' => 'ठंड से जमा हुआ चेहरा',
    '🥴' => 'चकराया हुआ चेहरा',
    '😵' => 'crossed-out eyes wala face',
    '🤯' => 'विस्फोट करता हुआ सर',
    '🤠' => 'काउबॉय हैट के साथ चेहरा',
    '🥳' => 'उत्सवी चेहरा',
    '🥸' => 'छिपाया हुआ चेहरा',
    '😎' => 'sunglasses wala face',
    '🤓' => 'मूर्खता के भाव वाला चेहरा',
    '🧐' => 'एक आँख में चश्मा पहने चेहरा',
    '😕' => 'परेशान चेहरा',
    '🫤' => 'diagonal mouth wala face',
    '😟' => 'चिंतित चेहरा',
    '🙁' => 'कम क्रोधित चेहरा',
    '☹' => 'अधिक क्रोधित चेहरा',
    '😮' => 'open mouth wala face',
    '😯' => 'आश्चर्यचकित चेहरा',
    '😲' => 'पूरी तरह स्तंभित चेहरा',
    '😳' => 'विस्मित चेहरा',
    '🫪' => 'विकृत चेहरा',
    '🥺' => 'करुण चेहरा',
    '🥹' => 'Aansoo rokta face',
    '😦' => 'open mouth wala frowning face',
    '😧' => 'dukhi face',
    '😨' => 'डरा हुआ चेहरा',
    '😰' => 'sweating wala anxious face',
    '😥' => 'sad lekin relieved face',
    '😢' => 'रोता चेहरा',
    '😭' => 'loudly rone wala face',
    '😱' => 'dar se scream karta face',
    '😖' => 'Hairaan face',
    '😣' => 'हठी चेहरा',
    '😞' => 'निराश चेहरा',
    '😓' => 'sweating wala udaas face',
    '😩' => 'घबराया चेहरा',
    '😫' => 'थका चेहरा',
    '🥱' => 'उबासी लेता चेहरा',
    '😤' => 'nose se steam nikalti dikhaane wala face',
    '😡' => 'खीझ में लाल चेहरा',
    '😠' => 'गुस्सैल चेहरा',
    '🤬' => 'mouth par symbols wala face',
    '😈' => 'horns wala smiling face',
    '👿' => 'horns wala angry face',
    '💀' => 'खोपड़ी',
    '☠' => 'skull aur crossbones',
    '💩' => 'मल का ढेर',
    '🤡' => 'जोकर चेहरा',
    '👹' => 'जापानी राक्षस',
    '👺' => 'जापानी पिशाच',
    '👻' => 'भूत',
    '👽' => 'परग्रह प्राणी',
    '👾' => 'परग्रह दैत्य',
    '🤖' => 'रोबोट चेहरा',
    '😺' => 'मुस्काती आँखों वाली बिल्ली का चेहरा',
    '😸' => 'smiling eyes wali grinning cat',
    '😹' => 'khushi ke aansoo bahaati cat kaa face',
    '😻' => 'heart-eyes wali smiling cat',
    '😼' => 'Dissapointment ke saath smile karti cat',
    '😽' => 'आँखें बंद करके चूमती बिल्ली का चेहरा',
    '🙀' => 'आश्चर्यचकित बिल्ली का चेहरा',
    '😿' => 'रोती बिल्ली का चेहरा',
    '😾' => 'खीझभरी बिल्ली का चेहरा',
    '🙈' => 'Bura na dekhne wala monkey',
    '🙉' => 'bura na sunne wala monkey',
    '🙊' => 'bura na bolne wala monkey',
    '💌' => 'प्रेमपत्र',
    '💘' => 'arrow wala heart',
    '💝' => 'ribbon wala heart',
    '💖' => 'रोमांचित दिल',
    '💗' => 'grow karta hua heart',
    '💓' => 'धड़कता दिल',
    '💞' => 'घूमते दिल',
    '💕' => 'do hearts',
    '💟' => 'heart ki decoration',
    '❣' => 'exclamation sign wala heart',
    '💔' => 'टूटा दिल',
    '❤' => 'लाल दिल',
    '🩷' => 'गुलाबी दिल',
    '🧡' => 'नारंगी दिल',
    '💛' => 'पीला दिल',
    '💚' => 'हरा दिल',
    '💙' => 'नीला दिल',
    '🩵' => 'हल्का नीला दिल',
    '💜' => 'बैंगनी दिल',
    '🤎' => 'भूरा दिल',
    '🖤' => 'काला दिल',
    '🩶' => 'स्लेटी दिल',
    '🤍' => 'सफ़ेद दिल',
    '💋' => 'चुंबन का निशान',
    '💯' => '100 अंक',
    '💢' => 'गुस्से का चिह्न',
    '🫯' => 'घमासान झगड़े से बना धूल का गुब्बार',
    '💥' => 'टक्कर',
    '💫' => 'तारे दिखना',
    '💦' => 'sweating ke droplets',
    '💨' => 'दौड़ना',
    '🕳' => 'छिद्र',
    '💬' => 'संवाद बुलबुला',
    '🗨' => 'बायाँ स्पीच बबल',
    '🗯' => 'दायाँ गुस्से वाला बबल',
    '💭' => 'विचार बुलबुला',
    '💤' => 'उनींदा',
    '👋' => 'wave karta haath',
    '🤚' => 'uthe huye haath ki back side',
    '🖐' => 'faili fingers wala haath',
    '✋' => 'utha hua haath',
    '🖖' => 'सेल्यूट का एक तरीका',
    '🫱' => 'दाहिनी ओर हाथ',
    '🫲' => 'बाईं ओर हाथ',
    '🫳' => 'नीचे की ओर हथेली',
    '🫴' => 'ऊपर की ओर हथेली',
    '🫷' => 'बाईं तरफ़ धक्का देता हुआ हाथ',
    '🫸' => 'दाईं तरफ़ धक्का देता हुआ हाथ',
    '👌' => 'OK kaa symbol',
    '🤌' => 'सिकोड़ी हुई अंगुलियाँ',
    '🤏' => 'pinch dikhaata haath',
    '✌' => 'victory dikhaata haath',
    '🤞' => 'क्रॉस बनाती अंगुलियाँ',
    '🫰' => 'क्रॉस किए तर्जनी और अंगूठे वाला हाथ',
    '🤟' => 'किसी से प्यार जताने के हावभाव',
    '🤘' => 'horns kaa sign',
    '🤙' => 'call me kaa ishaara karne wala haath',
    '👈' => 'left mein point karti index finger',
    '👉' => 'right mein point karti index finger',
    '👆' => 'oopar ishaara karti index finger',
    '🖕' => 'बीच की अँगुली',
    '👇' => 'neeche ishaara karti index finger',
    '☝' => 'oopar point karti index finger',
    '🫵' => 'viewer ki taraf pont karti index finger',
    '👍' => 'थंब्स अप',
    '👎' => 'थंब्स डाउन',
    '✊' => 'उठी हुई मुट्ठी',
    '👊' => 'भींची मुट्ठी',
    '🤛' => 'बाईं ओर मुठ्ठी',
    '🤜' => 'दाईं ओर मुठ्ठी',
    '👏' => 'हाथ की ताली का चिह्न',
    '🙌' => 'khush hokar dono haath uthaana',
    '🫶' => 'haathon se bana heart',
    '👐' => 'खुले हाथ',
    '🤲' => 'palms ko eksaath oopar karna',
    '🤝' => 'हाथ मिलाना',
    '🙏' => 'namaste karna',
    '✍' => 'likhta hua haath',
    '💅' => 'नेल पॉलिश',
    '🤳' => 'सेल्फ़ी',
    '💪' => 'बाइसेप्स',
    '🦾' => 'यांत्रिक हाथ',
    '🦿' => 'यांत्रिक पैर',
    '🦵' => 'पैर',
    '🦶' => 'पाँव',
    '👂' => 'कान',
    '🦻' => 'hearing aid laga kaan',
    '👃' => 'नाक',
    '🧠' => 'मस्तिष्क, दिमाग',
    '🫀' => 'हृदय अंग',
    '🫁' => 'फेफड़ा',
    '🦷' => 'दाँत',
    '🦴' => 'हड्डी',
    '👀' => 'आँखें',
    '👁' => 'आँख',
    '👅' => 'जीभ',
    '👄' => 'मुँह',
    '🫦' => 'होंठ काटना',
    '👶' => 'शिशु',
    '🧒' => 'बच्चा',
    '👦' => 'लड़का',
    '👧' => 'लड़की',
    '🧑' => 'व्यक्ति',
    '👱' => 'भूरे बालों वाला आदमी',
    '👨' => 'पुरुष',
    '🧔' => 'दाढ़ी वाला आदमी',
    '👩' => 'महिला',
    '🧓' => 'वृद्ध व्यक्ति',
    '👴' => 'बूढ़ा पुरुष',
    '👵' => 'बूढ़ी महिला',
    '🙍' => 'frown karta person',
    '🙎' => 'pout banaata vyakti',
    '🙅' => 'NO kaa gesture deta vyakti',
    '🙆' => 'OK kaa gesture deta vyakti',
    '💁' => 'information desk kaa vyakti',
    '🙋' => 'haath uthaata vyakti',
    '🧏' => 'बहरा व्यक्ति',
    '🙇' => 'bow karta vyakti',
    '🤦' => 'face par palm rakhe hua vyakti',
    '🤷' => 'shrug karta vyakti',
    '👮' => 'पुलिस अधिकारी',
    '🕵' => 'जासूस',
    '💂' => 'गार्ड',
    '🥷' => 'निंजा',
    '👷' => 'निर्माण मजदूर',
    '🫅' => 'crown wala vyakti',
    '🤴' => 'राजकुमार',
    '👸' => 'राजकुमारी',
    '👳' => 'turban wala vyakti',
    '👲' => 'skullcap wala aadmi',
    '🧕' => 'headscarf pahne mahila',
    '🤵' => 'suit boot mein vyakti',
    '👰' => 'Ghoonghat mein bride',
    '🤰' => 'गर्भवती महिला',
    '🫃' => 'गर्भवती पुरुष',
    '🫄' => 'गर्भवती',
    '🤱' => 'स्तनपान',
    '👼' => 'नन्ही परी',
    '🎅' => 'सैंटा क्लॉज़',
    '🤶' => 'मिसेज़ क्लाज',
    '🦸' => 'सुपरहीरो',
    '🦹' => 'सुपरविलेन',
    '🧙' => 'जादूगर, करामाती',
    '🧚' => 'परी',
    '🧛' => 'वैम्पायर',
    '🧜' => 'मत्स्यमानव',
    '🧝' => 'जादुई प्राणी',
    '🧞' => 'जिन्न',
    '🧟' => 'ज़ॉम्बी',
    '🧌' => 'ट्रॉल',
    '🫈' => 'बालों वाला प्राणी',
    '💆' => 'massage karwaata vyakti',
    '💇' => 'haircut leta vyakti',
    '🚶' => 'walk karta vyakti',
    '🧍' => 'khada hua vyakti',
    '🧎' => 'knees par baitha vyakti',
    '🏃' => 'run karta vyakti',
    '💃' => 'dance karti mahila',
    '🕺' => 'dance karta aadmi',
    '🕴' => 'hawa mein udta suit wala vyakti',
    '👯' => 'khargosh ke kaan wale log',
    '🧖' => 'steamy room mein vyakti',
    '🧗' => 'climb karta vyakti',
    '🤺' => 'fencing karta vyakti',
    '🏇' => 'घुड़दौड़',
    '⛷' => 'स्की खिलाड़ी',
    '🏂' => 'स्नोबोर्डर',
    '🏌' => 'golf khelta vyakti',
    '🏄' => 'surfing karta vyakti',
    '🚣' => 'boat rowing karta vyakti',
    '🏊' => 'swimming karta vyakti',
    '⛹' => 'ball se khelta vyakti',
    '🏋' => 'weightlifting karta vyakti',
    '🚴' => 'cycle chalaata vyakti',
    '🚵' => 'mountain biking karta vyakti',
    '🤸' => 'cartwheeling karta vyakti',
    '🤼' => 'wrestling karte log',
    '🤽' => 'water polo khelta vyakti',
    '🤾' => 'handball khelta vyakti',
    '🤹' => 'juggling karta vyakti',
    '🧘' => 'padmaasan mein baitha vyakti',
    '🛀' => 'bath leta vyakti',
    '🛌' => 'bed par sota vyakti',
    '👭' => 'haath pakde do mahilaayein',
    '👫' => 'haath mein haath liye aurat-aadmi',
    '👬' => 'haath pakde do aadmi',
    '💏' => 'चुंबन',
    '💑' => 'heart symbol ke saath couple',
    '🗣' => 'bolta face',
    '👤' => 'body ke upper part ki image',
    '👥' => 'body ke upper part ki images',
    '🫂' => 'hug karte huye log',
    '👪' => 'परिवार',
    '👣' => 'पदचिह्न',
    '🫆' => 'फ़िंगरप्रिंट',
    '🦰' => 'लाल बाल',
    '🦱' => 'घुँघराले बाल',
    '🦳' => 'सफ़ेद बाल',
    '🦲' => 'गंजा',
    '🐵' => 'बंदर का चेहरा',
    '🐒' => 'बंदर',
    '🦍' => 'गोरिल्ला',
    '🦧' => 'वनमानुष',
    '🐶' => 'कुत्ते का चेहरा',
    '🐕' => 'कुत्ता',
    '🦮' => 'मर्गदर्शक कुत्ता',
    '🐩' => 'छोटा कुत्ता',
    '🐺' => 'सियार का चेहरा',
    '🦊' => 'लोमड़ी जैसा चेहरा',
    '🦝' => 'रकून',
    '🐱' => 'बिल्ली का चेहरा',
    '🐈' => 'बिल्ली',
    '🦁' => 'शेर जैसा चेहरा',
    '🐯' => 'शेर का चेहरा',
    '🐅' => 'शेर',
    '🐆' => 'तेंदुआ',
    '🐴' => 'घोड़े का चेहरा',
    '🫎' => 'मूस',
    '🫏' => 'गधा',
    '🐎' => 'घोड़ा',
    '🦄' => 'यूनिकॉर्न',
    '🦓' => 'ज़ेब्रा',
    '🦌' => 'हिरण',
    '🦬' => 'बायसन',
    '🐮' => 'गाय का चेहरा',
    '🐂' => 'बैल',
    '🐃' => 'भैंस',
    '🐄' => 'गाय',
    '🐷' => 'सुअर का चेहरा',
    '🐖' => 'सुअर',
    '🐗' => 'जंगली सुअर',
    '🐽' => 'सुअर की नाक',
    '🐏' => 'नर भेड़',
    '🐑' => 'भेड़',
    '🐐' => 'बकरी',
    '🐪' => 'ऊँट',
    '🐫' => 'do hump wala camel',
    '🦙' => 'लामा',
    '🦒' => 'जिराफ़',
    '🐘' => 'हाथी',
    '🦣' => 'मैमथ',
    '🦏' => 'गैंडा',
    '🦛' => 'दरियाई घोड़ा',
    '🐭' => 'मूषक का चेहरा',
    '🐁' => 'मूषक',
    '🐀' => 'चूहा',
    '🐹' => 'चूहे का चेहरा',
    '🐰' => 'खरगोश का चेहरा',
    '🐇' => 'खरगोश',
    '🐿' => 'गिलहरी',
    '🦫' => 'बीवर',
    '🦔' => 'साही',
    '🦇' => 'चमगादड़',
    '🐻' => 'भालू का चेहरा',
    '🐨' => 'कोआला',
    '🐼' => 'पांडा का चेहरा',
    '🦥' => 'आलस्य',
    '🦦' => 'ऊदबिलाव',
    '🦨' => 'स्कंक',
    '🦘' => 'कंगारू',
    '🦡' => 'बिज्जू',
    '🐾' => 'panje ke prints',
    '🦃' => 'टर्की',
    '🐔' => 'मुर्गी',
    '🐓' => 'मुर्गा',
    '🐣' => 'ande se baahar aata chick',
    '🐤' => 'मुर्गी का बच्चा',
    '🐥' => 'front face karta baby chick',
    '🐦' => 'चिड़िया',
    '🐧' => 'पेंग्विन',
    '🕊' => 'कबूतर',
    '🦅' => 'बाज',
    '🦆' => 'बतख',
    '🦢' => 'हंस',
    '🦉' => 'उल्लू',
    '🦤' => 'डोडो',
    '🪶' => 'पंख',
    '🦩' => 'लाल हंस',
    '🦚' => 'मोर',
    '🦜' => 'तोता',
    '🪽' => 'पर',
    '🪿' => 'बत्तख',
    '🐸' => 'मेंढक का चेहरा',
    '🐊' => 'मगरमच्छ',
    '🐢' => 'कछुआ',
    '🦎' => 'छिपकली',
    '🐍' => 'सांप',
    '🐲' => 'दैत्य का चेहरा',
    '🐉' => 'दैत्य',
    '🦕' => 'सोरोपॉड',
    '🦖' => 'टी-रेक्स',
    '🐳' => 'spout karti whale',
    '🐋' => 'ह्वेल',
    '🐬' => 'डॉल्फ़िन',
    '🫍' => 'ओर्का',
    '🦭' => 'सील',
    '🐟' => 'मछली',
    '🐠' => 'ऊष्णकटिबंधीय मछली',
    '🐡' => 'गुब्बारा मछली',
    '🦈' => 'शार्क',
    '🐙' => 'ऑक्टोपस',
    '🐚' => 'गोल शंख',
    '🪸' => 'कोरल',
    '🪼' => 'जेलीफ़िश',
    '🦀' => 'कर्कट',
    '🦞' => 'झींगा मछली',
    '🦐' => 'झींगा',
    '🦑' => 'स्क्विड',
    '🦪' => 'सीप',
    '🐌' => 'घोंघा',
    '🦋' => 'तितली',
    '🐛' => 'इल्ली',
    '🐜' => 'चींटी',
    '🐝' => 'मधुमक्खी',
    '🪲' => 'बीटल',
    '🐞' => 'लेडीबग',
    '🦗' => 'टिड्डा, झींगुर',
    '🪳' => 'तिलचट्टा',
    '🕷' => 'मकड़ी',
    '🕸' => 'मकड़ी का जाला',
    '🦂' => 'बिच्छू, वृश्चिक राशि',
    '🦟' => 'मच्छर',
    '🪰' => 'मक्खी',
    '🪱' => 'कृमि',
    '🦠' => 'रोगाणु',
    '💐' => 'फूल, फूलगुच्छ',
    '🌸' => 'चैरी ब्लॉसम',
    '💮' => 'फूल की छाप',
    '🪷' => 'कमल',
    '🏵' => 'पुष्प, रिबन का पुष्प',
    '🌹' => 'गुलाब',
    '🥀' => 'murjhaaya hua phool',
    '🌺' => 'गुड़हल, हिबिस्कस',
    '🌻' => 'सूर्यमुखी',
    '🌼' => 'फूल खिलना',
    '🌷' => 'ट्यूलिप',
    '🪻' => 'ह्यचींथ',
    '🌱' => 'अंकुर',
    '🪴' => 'pot mein laga plant',
    '🌲' => 'सदाबहार वृक्ष',
    '🌳' => 'छायादार पेड़',
    '🌴' => 'ताड़ का पेड़',
    '🌵' => 'कैक्टस',
    '🌾' => 'chaawal ki baali',
    '🌿' => 'जड़ी–बूटी, पत्ती',
    '☘' => 'शैमरॉक',
    '🍀' => '4 leaves wali grass',
    '🍁' => 'मैपल की पत्ती',
    '🍂' => 'giri hui leaf',
    '🍃' => 'hawa mein lahraati leaf',
    '🪹' => 'Khaali nest',
    '🪺' => 'eggs wala nest',
    '🍄' => 'मशरूम',
    '🪾' => 'bina leaves kaa tree',
    '🍇' => 'अंगूर, फल',
    '🍈' => 'खरबूजा, फल',
    '🍉' => 'तरबूज़',
    '🍊' => 'संतरा, फल',
    '🍋' => 'नीबू',
    '🍌' => 'केला, फल',
    '🍍' => 'अन्नानास, फल',
    '🥭' => 'आम',
    '🍎' => 'लाल सेब, सेवफल, लाल, फल',
    '🍏' => 'हरा सेब, सेव, हरा, फल',
    '🍐' => 'नाशपाती, फल',
    '🍑' => 'आड़ू',
    '🍒' => 'चेरी',
    '🍓' => 'स्ट्रॉबेरी',
    '🫐' => 'ब्लूबेरी',
    '🥝' => 'कीवी फल',
    '🍅' => 'टमाटर',
    '🫒' => 'जैतून',
    '🥥' => 'नारियल',
    '🥑' => 'अवोकाडो',
    '🍆' => 'बैंगन',
    '🥔' => 'आलू',
    '🥕' => 'गाजर',
    '🌽' => 'भुट्टा, मकई का भुट्टा',
    '🌶' => 'तीखी मिर्च',
    '🫑' => 'शिमला मिर्च',
    '🥒' => 'खीरा',
    '🥬' => 'हरी पत्तेदार',
    '🥦' => 'ब्रोकली',
    '🧄' => 'लहसुन',
    '🧅' => 'प्याज़',
    '🥜' => 'मूँगफली',
    '🫘' => 'लोबिया',
    '🌰' => 'चेस्टनट',
    '🫚' => 'अदरक की जड़',
    '🫛' => 'मटर की फली',
    '🫜' => 'कंद मूल',
    '🍞' => 'ब्रेड',
    '🥐' => 'क्रोइसैन',
    '🥖' => 'बीगट ब्रेड',
    '🫓' => 'फ़्लैटब्रेड',
    '🥨' => 'प्रेटज़ेल',
    '🥯' => 'बैगल',
    '🥞' => 'पैनकेक',
    '🧇' => 'वफ़ल',
    '🧀' => 'पनीर का टुकड़ा',
    '🍖' => 'bone wala meat',
    '🍗' => 'chicken leg',
    '🥩' => 'meat kaa piece',
    '🥓' => 'बेकन',
    '🍔' => 'हैमबर्गर',
    '🍟' => 'फ़्रेंच फ़्राइस',
    '🍕' => 'पिज़्ज़ा स्लाइस',
    '🌭' => 'हॉट डॉग',
    '🥪' => 'सैंडविच',
    '🌮' => 'टैको',
    '🌯' => 'बरिटो',
    '🫔' => 'टमाले',
    '🥙' => 'stuffed paraantha',
    '🧆' => 'फ़लाफ़ेल',
    '🥚' => 'अंडा',
    '🍳' => 'भोजन पकाना',
    '🥘' => 'food ke liye kam deep pan',
    '🍲' => 'food pot',
    '🫕' => 'फ़ॉनडू',
    '🥣' => 'bowl ke saath spoon',
    '🥗' => 'हरा सलाद',
    '🍿' => 'पॉपकॉर्न',
    '🧈' => 'मक्खन',
    '🧂' => 'namak',
    '🥫' => 'डिब्बा बंद खाद्य सामग्री',
    '🍱' => 'बैंटो, बैंटो बॉक्स',
    '🍘' => 'राइस क्रैकर',
    '🍙' => 'राइस बॉल',
    '🍚' => 'पके हुए चावल',
    '🍛' => 'करी–चावल',
    '🍜' => 'भाप वाली बाउल',
    '🍝' => 'स्पैगेटी',
    '🍠' => 'सिके शकरकंद',
    '🍢' => 'ओडेन',
    '🍣' => 'सुशी',
    '🍤' => 'तला झींगा',
    '🍥' => 'swirls wala fish cake',
    '🥮' => 'मून केक',
    '🍡' => 'डैंगो',
    '🥟' => 'भरावनयुक्त मीठी या नमकीन पकौड़ियाँ',
    '🥠' => 'फॉर्चून कुकी',
    '🥡' => 'टेकआउट बॉक्स',
    '🍦' => 'सॉफ़्ट आइसक्रीम',
    '🍧' => 'पीसी बर्फ़',
    '🍨' => 'आइसक्रीम',
    '🍩' => 'डोनट',
    '🍪' => 'कुकी',
    '🎂' => 'जन्मदिन का केक',
    '🍰' => 'शॉर्टकेक',
    '🧁' => 'कपकेक',
    '🥧' => 'पाई',
    '🍫' => 'चॉकलेट बार',
    '🍬' => 'कैंडी',
    '🍭' => 'लॉलीपॉप',
    '🍮' => 'कस्टर्ड',
    '🍯' => 'शहद पात्र',
    '🍼' => 'बच्चे के दूध की बोतल',
    '🥛' => 'doodh kaa glass',
    '☕' => 'कॉफ़ी, भाप वाला गर्म पेय',
    '🫖' => 'चाय की केतली',
    '🍵' => 'bina handle wala teacup',
    '🍶' => 'सेक, सेक बोतल और कप',
    '🍾' => 'cork khulti hui bottle',
    '🍷' => 'शराब का गिलास',
    '🍸' => 'कॉकटेल गिलास',
    '🍹' => 'ट्रॉपिकल पेय',
    '🍺' => 'बियर, बियर मग',
    '🍻' => 'cheers karte beer mugs',
    '🥂' => 'cheers karte glasses',
    '🥃' => 'गिलास',
    '🫗' => 'पेय छलकना',
    '🥤' => 'cup ke saath straw',
    '🧋' => 'बुलबुला चाय',
    '🧃' => 'जूस का डब्बा',
    '🧉' => 'mate',
    '🧊' => 'आइस क्यूब',
    '🥢' => 'चॉपस्टिक',
    '🍽' => 'plate ke saath knife aur fork',
    '🍴' => 'fork aur knife',
    '🥄' => 'चम्मच',
    '🔪' => 'खाना बनाने का चाकू',
    '🫙' => 'मर्तबान',
    '🏺' => 'शराब का कंटेनर, जग',
    '🌍' => 'Europe-Africa dikhaata globe',
    '🌎' => 'Americas dikhaata globe',
    '🌏' => 'Asia-Australia dikhaata globe',
    '🌐' => 'meridians dikhaata globe',
    '🗺' => 'विश्व मानचित्र, विश्व',
    '🗾' => 'Japan kaa map',
    '🧭' => 'दिशासूचक',
    '🏔' => 'बर्फीले शिखर वाला पर्वत, बर्फ',
    '⛰' => 'पहाड़',
    '🛘' => 'भूस्खलन',
    '🌋' => 'ज्वालामुखी',
    '🗻' => 'mount fuji',
    '🏕' => 'तंबू, तंबू लगाना',
    '🏖' => 'beach par umbrella',
    '🏜' => 'रेगिस्तान, मरुस्थल',
    '🏝' => 'रेगिस्तान में द्वीप, द्वीप',
    '🏞' => 'राष्ट्रीय उद्यान',
    '🏟' => 'स्टेडियम',
    '🏛' => 'उत्कृष्ट इमारत',
    '🏗' => 'भवन निर्माण',
    '🧱' => 'ईंट',
    '🪨' => 'चट्टान',
    '🪵' => 'लकड़ी',
    '🛖' => 'झोपड़ी',
    '🏘' => 'घर की इमारतें, भवन',
    '🏚' => 'वीरान घर का भवन, अकेली इमारत',
    '🏠' => 'घर, भवन',
    '🏡' => 'garden wala house',
    '🏢' => 'कार्यालय का भवन, कार्यालय',
    '🏣' => 'जापानी डाकघर, डाक भवन',
    '🏤' => 'डाकघर, यूरोपीय डाकघर',
    '🏥' => 'अस्पताल',
    '🏦' => 'बैंक, भवन',
    '🏨' => 'होटल, भवन',
    '🏩' => 'प्रेम होटल',
    '🏪' => 'सुविधा स्टोर',
    '🏫' => 'स्कूल',
    '🏬' => 'किराना दुकान',
    '🏭' => 'फ़ैक्टरी, कारखाना',
    '🏯' => 'जापानी क़िला',
    '🏰' => 'यूरोपीय क़िला',
    '💒' => 'विवाह धर्मस्थल',
    '🗼' => 'टोक्यो टॉवर',
    '🗽' => 'स्टेच्यू ऑफ़ लिबर्टी',
    '⛪' => 'चर्च, भवन',
    '🕌' => 'मस्जिद, इस्लाम धर्म',
    '🛕' => 'hindu temple',
    '🕍' => 'यहूदी प्रार्थनागृह',
    '⛩' => 'शिंटो श्राइन, जापानी धर्म स्थल',
    '🕋' => 'kaaba',
    '⛲' => 'फ़व्वारा',
    '⛺' => 'टेंट, कैंपिंग',
    '🌁' => 'कुहासा, कोहरा',
    '🌃' => 'stars wali night',
    '🏙' => 'शहर का दृश्य',
    '🌄' => 'पहाड़ के ऊपर सूर्योदय',
    '🌅' => 'सूर्योदय, सुबह का सूरज',
    '🌆' => 'shaam ke time kaa cityscape',
    '🌇' => 'सूर्यास्त',
    '🌉' => 'night mein bridge kaa view',
    '♨' => 'गरम सोता',
    '🎠' => 'घोड़े वाला झूला',
    '🛝' => 'फिसल पट्टी',
    '🎡' => 'फ़ेरीज झूला',
    '🎢' => 'रोलर कोस्टर',
    '💈' => 'बार्बर पोल',
    '🎪' => 'सर्कस टेंट',
    '🚂' => 'भाप इंजन, लोकोमोटिव',
    '🚃' => 'ट्रेन, बिजली वाली ट्रेन',
    '🚄' => 'तेज़ गति वाली ट्रेन, शिंकानसेन',
    '🚅' => 'बुलेट नोज़ के साथ शिंकानसेन, ट्रेन',
    '🚆' => 'ट्रेन',
    '🚇' => 'सबवे, मेट्रो',
    '🚈' => 'लाइट रेल',
    '🚉' => 'स्टेशन',
    '🚊' => 'ट्राम',
    '🚝' => 'मोनोरेल',
    '🚞' => 'माउंटेन रेलवे',
    '🚋' => 'ट्राम कार',
    '🚌' => 'बस',
    '🚍' => 'aati hui bus',
    '🚎' => 'ट्रॉलीबस',
    '🚐' => 'मिनीबस',
    '🚑' => 'एंबुलेंस',
    '🚒' => 'अग्निशामक, दमकल',
    '🚓' => 'पुलिस कार',
    '🚔' => 'aati hui police car',
    '🚕' => 'टैक्सी',
    '🚖' => 'aati hui taxi',
    '🚗' => 'ऑटोमोबाइल, कार',
    '🚘' => 'aati hui car',
    '🚙' => 'स्पोर्ट यूटिलिटी वाहन',
    '🛻' => 'पिकअप ट्रक',
    '🚚' => 'डिलीवरी ट्रक',
    '🚛' => 'लॉरी, आर्टिक्यूलेटेड लॉरी',
    '🚜' => 'ट्रैक्टर',
    '🏎' => 'रेसिंग कार',
    '🏍' => 'मोटर साइकिल',
    '🛵' => 'मोटर स्कूटर',
    '🦽' => 'हस्तचालित व्हीलचेयर',
    '🦼' => 'motorized wheelchair',
    '🛺' => 'ऑटो रिक्शा',
    '🚲' => 'बाइक, साइकिल',
    '🛴' => 'किक स्कूटर',
    '🛹' => 'स्केटबोर्ड',
    '🛼' => 'पहिये वाला जूता',
    '🚏' => 'बस स्टॉप',
    '🛣' => 'मोटरवे',
    '🛤' => 'रेल की पटरी, ट्रेन',
    '🛢' => 'तेल की टंकी, तेल',
    '⛽' => 'गैस स्टेशन, पेट्रोल पंप',
    '🛞' => 'पहिया',
    '🚨' => 'police car ki light',
    '🚥' => 'ट्रैफ़िक लाइट, क्षैतिज यातायात संकेत',
    '🚦' => 'ट्रैफ़िक लाइट, उर्ध्वाधर यातायात संकेत',
    '🛑' => 'रुकने का संकेत',
    '🚧' => 'निर्माण चालू, निर्माण का संकेत',
    '⚓' => 'एंकर, चिह्न',
    '🛟' => 'पानी पर तैरने वाला टायर',
    '⛵' => 'सेलबोट, नाव',
    '🛶' => 'डोंगी',
    '🚤' => 'स्पीडबोट, नाव',
    '🛳' => 'यात्री जहाज',
    '⛴' => 'नौका',
    '🛥' => 'मोटर बोट',
    '🚢' => 'जहाज़, वाहन',
    '✈' => 'हवाई जहाज़',
    '🛩' => 'छोटा हवाई जहाज़',
    '🛫' => 'हवाई जहाज़ प्रस्थान',
    '🛬' => 'हवाई जहाज़ आगमन',
    '🪂' => 'पैराशूट',
    '💺' => 'सीट, कुर्सी',
    '🚁' => 'हेलीकॉप्टर, वाहन',
    '🚟' => 'सस्पेंशन रेलवे, रेलवे',
    '🚠' => 'माउंटेन केबलवे, पहाड़ी केबल कार',
    '🚡' => 'केबल कार, एरियल ट्रामवे',
    '🛰' => 'उपग्रह, अंतरिक्ष',
    '🚀' => 'रॉकेट, वाहन',
    '🛸' => 'उड़न तश्तरी',
    '🛎' => 'बेलहॉप घंटी, होटल',
    '🧳' => 'सामान',
    '⌛' => 'रेतघड़ी, समय',
    '⏳' => 'बहती रेत के साथ रेतघड़ी, समय',
    '⌚' => 'घड़ी, समय',
    '⏰' => 'अलार्म घड़ी, समय',
    '⏱' => 'स्टॉपवॉच',
    '⏲' => 'टाइमर घड़ी',
    '🕰' => 'मेंटलपीस घड़ी',
    '🕛' => 'twelve o’ clock',
    '🕧' => 'साढ़े बारह, घड़ी, 12:30',
    '🕐' => '1 बजे, घड़ी, एक, 1:00',
    '🕜' => 'डेढ़, घड़ी, 1:30',
    '🕑' => '2 बजे, घड़ी, दो, 2:00',
    '🕝' => 'ढाई, घड़ी, 2:30',
    '🕒' => '3 बजे, घड़ी, तीन, 3:00',
    '🕞' => 'साढ़े तीन, घड़ी, 3:30',
    '🕓' => '4 बजे, घड़ी, चार, 4:00',
    '🕟' => 'साढ़े चार, घड़ी, 4:30',
    '🕔' => '5 बजे, घड़ी, पांच, 5:00',
    '🕠' => 'साढ़े पाँच, घड़ी, 5:30',
    '🕕' => '6 बजे, घड़ी, छह, 6:00',
    '🕡' => 'साढ़े छह, घड़ी, 6:30',
    '🕖' => '7 बजे, घड़ी, सात, 7:00',
    '🕢' => 'साढ़े सात, घड़ी, 7:30',
    '🕗' => '8 बजे, घड़ी, आठ, 8:00',
    '🕣' => 'साढ़े आठ, घड़ी, 8:30',
    '🕘' => '9 बजे, घड़ी, नौ, 9:00',
    '🕤' => 'साढ़े नौ, घड़ी, 9:30',
    '🕙' => '10 बजे, घड़ी, दस, 10:00',
    '🕥' => 'साढ़े दस, घड़ी, 10:30',
    '🕚' => '11 बजे, घड़ी, ग्यारह, 11:00',
    '🕦' => 'साढ़े ग्यारह, घड़ी, 11:30',
    '🌑' => 'नया चाँद',
    '🌒' => 'दूज का चाँद',
    '🌓' => 'कृष्ण पक्ष अर्धचंद्र',
    '🌔' => 'उभरा हुआ उदीयमान चाँद',
    '🌕' => 'पूरा चाँद',
    '🌖' => 'घटता चाँद',
    '🌗' => 'शुक्ल पक्ष अर्धचंद्र',
    '🌘' => 'दूज का अस्तमान चाँद',
    '🌙' => 'चापाकार चंद्र',
    '🌚' => 'नए चाँद वाला चेहरा',
    '🌛' => 'चौथाई माह के चाँद वाला दाईं ओर चेहरा',
    '🌜' => 'चौथाई माह के चाँद वाला बाईं ओर चेहरा',
    '🌡' => 'थर्मामीटर',
    '☀' => 'सूर्य',
    '🌝' => 'full moon wala face',
    '🌞' => 'face wala sun',
    '🪐' => 'ring wala planet',
    '⭐' => 'मध्यम सफ़ेद तारा',
    '🌟' => 'chamakta star',
    '🌠' => 'उल्का',
    '🌌' => 'आकाशगंगा',
    '☁' => 'बादल',
    '⛅' => 'baadlon ke peeche sun',
    '⛈' => 'lightning aur baarish waale baadal',
    '🌤' => 'chhote baadlon ke peeche chhupa sun',
    '🌥' => 'bade baadlon ke peeche chhupa sun',
    '🌦' => 'baarish wale baadlon ke peeche chhupa sun',
    '🌧' => 'baarish ke saath baadal',
    '🌨' => 'barf ke saath baadal',
    '🌩' => 'lightning wale baadal',
    '🌪' => 'तूफ़ान',
    '🌫' => 'कोहरा',
    '🌬' => 'तिरछा चेहरा',
    '🌀' => 'चक्रवात, तूफ़ान',
    '🌈' => 'इंद्रधनुष',
    '🌂' => 'band umbrella',
    '☂' => 'छाता',
    '☔' => 'rain drops wala umbrella',
    '⛱' => 'zameen par umbrella',
    '⚡' => 'उच्च वोल्टेज',
    '❄' => 'शीत, बर्फ़',
    '☃' => 'स्नोमैन',
    '⛄' => 'bina barf wala snowman',
    '☄' => 'धूमकेतु, अंतरिक्ष',
    '🔥' => 'आग',
    '💧' => 'ठंडा पसीना',
    '🌊' => 'समुद्र की लहर',
    '🎃' => 'जैक–ओ–लैंटर्न, कंदील',
    '🎄' => 'क्रिसमस ट्री',
    '🎆' => 'आतिशबाजी, समारोह',
    '🎇' => 'फुलझड़ी, आतिशबाजी',
    '🧨' => 'पटाखे',
    '✨' => 'चमकदार तारे',
    '🎈' => 'गुब्बारा',
    '🎉' => 'पार्टी पॉपर',
    '🎊' => 'कॉनफ़ेटी बॉल',
    '🎋' => 'टानाबाटा का पेड़',
    '🎍' => 'पाइन सजावट, नववर्ष',
    '🎎' => 'जापानी गुड़िया',
    '🎏' => 'कार्प स्ट्रीमर',
    '🎐' => 'विंड चाइम, घंटी',
    '🎑' => 'moon dekhne ki ceremony',
    '🧧' => 'लाल लिफ़ाफ़ा',
    '🎀' => 'फ़ीता',
    '🎁' => 'उपहार, पैक किया हुआ उपहार',
    '🎗' => 'रिमाइंडर रिबन',
    '🎟' => 'प्रवेश टिकट, टिकट',
    '🎫' => 'टिकट',
    '🎖' => 'सेना का पदक, पदक',
    '🏆' => 'ट्रॉफ़ी, पुरस्कार',
    '🏅' => 'खेल का पदक',
    '🥇' => 'स्वर्ण पदक',
    '🥈' => 'रजत पदक',
    '🥉' => 'कांस्य पदक',
    '⚽' => 'फ़ुटबॉल',
    '⚾' => 'बेसबॉल',
    '🥎' => 'सॉफ़्टबॉल',
    '🏀' => 'बास्केटबॉल, बास्केटबॉल गेंद',
    '🏐' => 'वॉलीबॉल',
    '🏈' => 'अमेरिकी फ़ुटबॉल',
    '🏉' => 'रग्बी गेंद',
    '🎾' => 'टेनिस',
    '🥏' => 'फ़्लाइंग डिस्क',
    '🎳' => 'बाउलिंग',
    '🏏' => 'क्रिकेट',
    '🏑' => 'फ़ील्ड हॉकी',
    '🏒' => 'आइस हॉकी स्टिक और पक',
    '🥍' => 'लाक्रोस',
    '🏓' => 'टेबल टेनिस',
    '🏸' => 'बैडमिंटन, रैकेट',
    '🥊' => 'मुक्केबाज़ी के दस्ताने',
    '🥋' => 'मार्शल आर्ट की वर्दी',
    '🥅' => 'गोल नेट',
    '⛳' => 'hole mein flag',
    '⛸' => 'आइस स्केट, स्केट',
    '🎣' => 'मछली पकड़ने की रॉड और मछली',
    '🤿' => 'ग़ोताख़ोरी वाला मास्क',
    '🎽' => 'रनिंग शर्ट',
    '🎿' => 'स्की, स्की और बूट',
    '🛷' => 'बर्फ़गाड़ी',
    '🥌' => 'कर्लिंग स्टोन',
    '🎯' => 'लक्ष्य पर निशाना',
    '🪀' => 'यो-यो',
    '🪁' => 'पतंग',
    '🔫' => 'paani ki pistol',
    '🎱' => 'बिलियर्ड',
    '🔮' => 'क्रिस्टल बॉल, भविष्य देखना',
    '🪄' => 'jaadoo ki chhadi',
    '🎮' => 'वीडियो गेम, कंट्रोलर',
    '🕹' => 'जॉयस्टिक, गेम, वीडियो गेम',
    '🎰' => 'स्लॉट मशीन',
    '🎲' => 'पासे, डाइस',
    '🧩' => 'puzzle game',
    '🧸' => 'टेडी बेअर',
    '🪅' => 'pinata',
    '🪩' => 'मिरर बॉल',
    '🪆' => 'nesting dolls',
    '♠' => 'हुकुम का पत्ता',
    '♥' => 'पान का पत्ता',
    '♦' => 'ईंट का पत्ता',
    '♣' => 'चिड़िया का पत्ता',
    '♟' => 'शतरंज का प्यादा',
    '🃏' => 'जोकर कार्ड',
    '🀄' => 'माहजोंग लाल दैत्य',
    '🎴' => 'फूल वाला पत्ता',
    '🎭' => 'प्रदर्शन कला, मुखौटे',
    '🖼' => 'frame ki gai picture',
    '🎨' => 'रंग पट्टिका, कलाकार पैलेट',
    '🧵' => 'धागा',
    '🪡' => 'सूई',
    '🧶' => 'सूत',
    '🪢' => 'गांठ',
    '👓' => 'चश्मा',
    '🕶' => 'धूप का चश्मा',
    '🥽' => 'गॉगल',
    '🥼' => 'लैब कोट',
    '🦺' => 'रक्षा जैकेट',
    '👔' => 'necktie',
    '👕' => 'टी–शर्ट',
    '👖' => 'जींस',
    '🧣' => 'स्कार्फ़',
    '🧤' => 'दस्ताने',
    '🧥' => 'कोट',
    '🧦' => 'मोज़े',
    '👗' => 'पोषाक',
    '👘' => 'किमोनो',
    '🥻' => 'साड़ी',
    '🩱' => 'वन-पीस स्विमसूट',
    '🩲' => 'अंडरवियर',
    '🩳' => 'शॉर्ट्स',
    '👙' => 'बिकनी',
    '👚' => 'महिला के कपड़े',
    '🪭' => 'मोड़ा जा सकने वाला हाथ का पंखा',
    '👛' => 'पर्स',
    '👜' => 'हैंडबैग',
    '👝' => 'पाउच',
    '🛍' => 'शॉपिंग बैग',
    '🎒' => 'स्कूल का बस्ता',
    '🩴' => 'thong sandal',
    '👞' => 'पुरुषों का जूता',
    '👟' => 'एथलेटिक जूता',
    '🥾' => 'हाइकिंग बूट',
    '🥿' => 'फ़्लैट जूती',
    '👠' => 'high-heel kaa shoe',
    '👡' => 'mahilaaon ki sandal',
    '🩰' => 'बैलेट जूते',
    '👢' => 'mahilaaon kaa boot',
    '🪮' => 'बाल संवारने के लिए कंघी',
    '👑' => 'मुकुट',
    '👒' => 'mahilaaon ki hat',
    '🎩' => 'सरटोप',
    '🎓' => 'स्नातक टोप',
    '🧢' => 'बिल कैप',
    '🪖' => 'मिलिट्री हैलमेट',
    '⛑' => 'rescue worker kaa helmet',
    '📿' => 'pooja ki maala ke manke',
    '💄' => 'लिपस्टिक',
    '💍' => 'अंगूठी',
    '💎' => 'रत्न',
    '🔇' => 'mute kiya speaker',
    '🔈' => 'speaker kaa low volume',
    '🔉' => 'speaker kaa medium volume',
    '🔊' => 'speaker kaa high volume',
    '📢' => 'लाउडस्पीकर',
    '📣' => 'मेगाफ़ोन',
    '📯' => 'postal horn',
    '🔔' => 'घंटी',
    '🔕' => 'slash ke saath bell',
    '🎼' => 'संगीत स्कोर',
    '🎵' => 'संगीत का स्वर',
    '🎶' => 'संगीत के स्वर',
    '🎙' => 'स्टूडियो माइक्रोफ़ोन',
    '🎚' => 'लेवल स्लाइडर',
    '🎛' => 'कंट्रोल नॉब',
    '🎤' => 'माइक्रोफ़ोन',
    '🎧' => 'हेडफ़ोन',
    '📻' => 'रेडियो',
    '🎷' => 'सैक्सोफ़ोन',
    '🎺' => 'तुरही',
    '🪗' => 'अकॉर्डियन',
    '🎸' => 'गिटार',
    '🎹' => 'संगीत कीबोर्ड',
    '🎻' => 'वायलिन',
    '🪕' => 'बैंजो',
    '🥁' => 'ड्रम',
    '🪘' => 'long drum',
    '🪇' => 'मराकस',
    '🪈' => 'बांसुरी',
    '🪉' => 'हार्प',
    '📱' => 'मोबाइल फ़ोन',
    '📲' => 'arrow ke saath mobile phone',
    '☎' => 'टेलीफ़ोन',
    '📞' => 'टेलीफ़ोन रिसीवर',
    '📟' => 'पेजर',
    '📠' => 'फ़ैक्स मशीन',
    '🔋' => 'बैटरी',
    '🪫' => 'कम बैटरी',
    '🔌' => 'बिजली का प्लग',
    '💻' => 'लैपटॉप',
    '🖥' => 'डेस्कटॉप',
    '🖨' => 'प्रिंटर',
    '⌨' => 'कीबोर्ड',
    '🖱' => 'माउस',
    '🖲' => 'ट्रैकबॉल',
    '💽' => 'कंप्यूटर डिस्क',
    '💾' => 'फ़्लॉपी डिस्क',
    '💿' => 'ऑप्टिकल डिस्क',
    '📀' => 'डीवीडी',
    '🧮' => 'अबैकस',
    '🎥' => 'मूवी कैमरा',
    '🎞' => 'फ़िल्म फ़्रेम',
    '📽' => 'फ़िल्म प्रोजेक्टर',
    '🎬' => 'क्लैपर बोर्ड',
    '📺' => 'टेलीविज़न',
    '📷' => 'कैमरा',
    '📸' => 'flash wala camera',
    '📹' => 'वीडियो कैमरा',
    '📼' => 'वीडियो कैसेट',
    '🔍' => 'left ki taraf tilted magnifying glass',
    '🔎' => 'right ki taraf tilted magnifying glass',
    '🕯' => 'मोमबत्ती',
    '💡' => 'लाइट बल्ब, विचार',
    '🔦' => 'टॉर्च',
    '🏮' => 'red paper wala lantern',
    '🪔' => 'दीपक',
    '📔' => 'decorative cover wali notebook',
    '📕' => 'बंद किताब',
    '📖' => 'खुली किताब',
    '📗' => 'हरी किताब',
    '📘' => 'नीली किताब',
    '📙' => 'नारंगी किताब',
    '📚' => 'किताबें',
    '📓' => 'नोटबुक',
    '📒' => 'लेजर, नोटबुक',
    '📃' => 'muda hua page',
    '📜' => 'स्क्रॉल, पेपर स्क्रॉल',
    '📄' => 'ऊपरी पृष्ठ',
    '📰' => 'समाचारपत्र',
    '🗞' => 'roll kiya hua newspaper',
    '📑' => 'बुकमार्क टैब',
    '🔖' => 'बुकमार्क',
    '🏷' => 'लेबल',
    '🪙' => 'सिक्का',
    '💰' => 'paise wala bag',
    '🪎' => 'खज़ाने का संदूक',
    '💴' => 'येन नोट',
    '💵' => 'डॉलर नोट, बैंकनोट',
    '💶' => 'यूरो नोट',
    '💷' => 'पाउंड नोट',
    '💸' => 'paise kharch karna',
    '💳' => 'क्रेडिट कार्ड',
    '🧾' => 'रसीद',
    '💹' => 'yen ki badhat dikhaane wala chart',
    '✉' => 'लिफ़ाफ़ा',
    '📧' => 'ईमेल',
    '📨' => 'इनकमिंग लिफ़ाफ़ा',
    '📩' => 'arrow wala envelope',
    '📤' => 'आउटबॉक्स ट्रे',
    '📥' => 'इनबॉक्स ट्रे',
    '📦' => 'पैकेज',
    '📫' => 'lahraate flag wala band mailbox',
    '📪' => 'jhuke flag wala band mailbox',
    '📬' => 'lahraate flag wala khula mailbox',
    '📭' => 'jhuke flag wala khula mailbox',
    '📮' => 'पोस्ट बॉक्स',
    '🗳' => 'ballot ke saath ballot box',
    '✏' => 'पेंसिल',
    '✒' => 'काली निब',
    '🖋' => 'फ़ाउंटन पेन',
    '🖊' => 'बॉलपेन',
    '🖌' => 'पेंटब्रश',
    '🖍' => 'क्रेयॉन',
    '📝' => 'मेमो',
    '💼' => 'ब्रीफ़केस',
    '📁' => 'फ़ाइल फ़ोल्डर',
    '📂' => 'खुला फ़ाइल फ़ोल्डर',
    '🗂' => 'कार्ड इंडेक्स डिवाइडर',
    '📅' => 'कैलेंडर',
    '📆' => 'फ़ाड़ने वाला कैलेंडर',
    '🗒' => 'स्पाइरल नोटपैड',
    '🗓' => 'स्पाइरल कैलेंडर',
    '📇' => 'कार्ड इंडेक्स',
    '📈' => 'Badhat dikhaata chart',
    '📉' => 'Kami dikhaata chart',
    '📊' => 'बार चार्ट',
    '📋' => 'क्लिपबोर्ड',
    '📌' => 'पुशपिन',
    '📍' => 'गोल पुशपिन',
    '📎' => 'पेपरक्लिप',
    '🖇' => 'link kiye gaye paperclips',
    '📏' => 'स्ट्रेट रूलर',
    '📐' => 'त्रिकोणीय रूलर',
    '✂' => 'कैंची',
    '🗃' => 'कार्ड फ़ाइल बॉक्स',
    '🗄' => 'फ़ाइल कैबिनेट',
    '🗑' => 'कचरा पेटी',
    '🔒' => 'बंद ताला',
    '🔓' => 'खुला ताला',
    '🔏' => 'pen ke saath lock',
    '🔐' => 'key se lock kiya gaya',
    '🔑' => 'चाबी',
    '🗝' => 'puraani key',
    '🔨' => 'hathouda',
    '🪓' => 'kulhaadi',
    '⛏' => 'kudaali',
    '⚒' => 'hathouda aur kudaali',
    '🛠' => 'hathouda aur wrench',
    '🗡' => 'kataar',
    '⚔' => 'क्रॉस बनाती तलवारें',
    '💣' => 'बम',
    '🪃' => 'बूमरैंग',
    '🏹' => 'teer aur kamaan',
    '🛡' => 'ढाल',
    '🪚' => 'carpenter ki aari',
    '🔧' => 'पाना',
    '🪛' => 'स्क्रूड्राइवर',
    '🔩' => 'nut aur bolt',
    '⚙' => 'गियर',
    '🗜' => 'क्लैंप',
    '⚖' => 'taraazu',
    '🦯' => 'white cane',
    '🔗' => 'कड़ी',
    '⛓' => 'ज़ंजीर',
    '🪝' => 'हुक',
    '🧰' => 'टूलबॉक्स',
    '🧲' => 'चुंबक',
    '🪜' => 'सीढ़ी',
    '🪏' => 'फावड़ा',
    '⚗' => 'रासायनिक उपकरण',
    '🧪' => 'टेस्ट ट्यूब',
    '🧫' => 'पेट्री डिश',
    '🧬' => 'डीएनए',
    '🔬' => 'माइक्रोस्कोप',
    '🔭' => 'दूरबीन',
    '📡' => 'सैटेलाइट एंटेना',
    '💉' => 'सिरींज, सूई',
    '🩸' => 'blood ki drop',
    '💊' => 'गोली',
    '🩹' => 'chipkaane wali bandage',
    '🩼' => 'बैसाखी',
    '🩺' => 'स्टेथोस्कोप',
    '🩻' => 'एक्स-रे',
    '🚪' => 'दरवाज़ा',
    '🛗' => 'elevator',
    '🪞' => 'आईना',
    '🪟' => 'खिड़की',
    '🛏' => 'बिस्तर',
    '🛋' => 'sofa aur lamp',
    '🪑' => 'कुर्सी',
    '🚽' => 'शौचालय',
    '🪠' => 'पिस्टन',
    '🚿' => 'स्नान',
    '🛁' => 'bathtub',
    '🪤' => 'mouse trap',
    '🪒' => 'उस्तरा',
    '🧴' => 'लोशन की बोतल',
    '🧷' => 'सेफ़्टी पिन',
    '🧹' => 'झाड़ू',
    '🧺' => 'बास्केट',
    '🧻' => 'paper kaa roll',
    '🪣' => 'बाल्टी',
    '🧼' => 'साबुन',
    '🫧' => 'बुलबुले',
    '🪥' => 'टूथब्रश',
    '🧽' => 'स्पंज',
    '🧯' => 'अग्निशामक',
    '🛒' => 'शॉपिंग कार्ट',
    '🚬' => 'धूम्रपान',
    '⚰' => 'ताबूत',
    '🪦' => 'हेडस्टोन',
    '⚱' => 'अस्थि कलश',
    '🧿' => 'nazar ki taabeez',
    '🪬' => 'हम्सा',
    '🗿' => 'मोए',
    '🪧' => 'घोषणा पत्र',
    '🪪' => 'पहचान पत्र',
    '🏧' => 'ATM का चिह्न',
    '🚮' => 'bin mein garbage daalne kaa sign',
    '🚰' => 'peene kaa paani',
    '♿' => 'ह्वीलचेयर का प्रतीक',
    '🚹' => 'पुरुष कक्ष',
    '🚺' => 'महिला कक्ष',
    '🚻' => 'सुविधाघर',
    '🚼' => 'गाड़ी में शिशु है',
    '🚾' => 'वॉटर क्लोसेट',
    '🛂' => 'पासपोर्ट नियंत्रण',
    '🛃' => 'कस्टम',
    '🛄' => 'सामान वापसी',
    '🛅' => 'chhuta hua luggage',
    '⚠' => 'चेतावनी',
    '🚸' => 'bachche cross kar rahe hain',
    '⛔' => 'प्रवेश निषेध',
    '🚫' => 'निषिद्ध',
    '🚳' => 'साइकल नहीं',
    '🚭' => 'धूम्रपान निषेध',
    '🚯' => 'गंदगी न फैलाएँ',
    '🚱' => 'peene laayak paani nahi',
    '🚷' => 'paidal chalne ki permission nahi',
    '📵' => 'mobile phones ki permission nahi',
    '🔞' => 'under 18 ko permission nahi',
    '☢' => 'रेडियो सक्रिय',
    '☣' => 'जैवसंकट',
    '⬆' => 'उर्ध्वमुखी तीर',
    '↗' => 'ऊपर-दायाँ तीर',
    '➡' => 'दायाँ तीर',
    '↘' => 'नीचे-दायाँ तीर',
    '⬇' => 'नीचे तीर',
    '↙' => 'left-down arrow',
    '⬅' => 'बायाँ तीर',
    '↖' => 'ऊपर-बायाँ तीर',
    '↕' => 'ऊपर-नीचे तीर',
    '↔' => 'बाएँ-दाएँ तीर',
    '↩' => 'left side muda hua right arrow',
    '↪' => 'right side muda hua left arrow',
    '⤴' => 'oopar ki taraf muda hua right arrow',
    '⤵' => 'neeche ki taraf muda hua right arrow',
    '🔃' => 'घड़ी की दिशा में लंबवत तीर',
    '🔄' => 'घड़ी की उल्टी दिशा में तीर',
    '🔙' => 'वापस तीर',
    '🔚' => 'END के साथ तीर',
    '🔛' => 'on! तीर',
    '🔜' => 'SOON तीर',
    '🔝' => 'TOP तीर',
    '🛐' => 'pooja karne ki jagah',
    '⚛' => 'अणु चिह्न',
    '🕉' => 'ॐ',
    '✡' => 'star of David',
    '☸' => 'dharma chakra',
    '☯' => 'यिंग यांग',
    '✝' => 'latin cross',
    '☦' => 'orthodox cross',
    '☪' => 'star aur crescent',
    '☮' => 'शांति का प्रतीक',
    '🕎' => 'मेनोरा',
    '🔯' => '6 point wala dotted star',
    '🪯' => 'खंडा',
    '♈' => 'मेष',
    '♉' => 'वृषभ',
    '♊' => 'मिथुन',
    '♋' => 'कर्क',
    '♌' => 'सिंह',
    '♍' => 'कन्या',
    '♎' => 'तुला',
    '♏' => 'वृश्चिक',
    '♐' => 'धनु',
    '♑' => 'मकर',
    '♒' => 'कुंभ',
    '♓' => 'मीन, राशि',
    '⛎' => 'सर्प',
    '🔀' => 'शफ़ल ट्रैक बटन',
    '🔁' => 'घड़ी की दिशा में तीर',
    '🔂' => 'एक बार दोहराएँ बटन',
    '▶' => 'प्ले बटन',
    '⏩' => 'फ़ास्ट फ़ॉर्वर्ड बटन',
    '⏭' => 'अगला ट्रैक बटन',
    '⏯' => 'play aur pause button',
    '◀' => 'पीछे जाएँ बटन',
    '⏪' => 'फ़ास्ट रिवर्स बटन',
    '⏮' => 'पिछला ट्रैक बटन',
    '🔼' => 'ऊपर त्रिभुज बटन',
    '⏫' => 'तेज़ ऊपर बटन',
    '🔽' => 'नीचे त्रिभुज बटन',
    '⏬' => 'फ़ास्ट डाउन बटन',
    '⏸' => 'पॉज़ बटन',
    '⏹' => 'रोकें बटन',
    '⏺' => 'रिकॉर्ड बटन',
    '⏏' => 'इजेक्ट बटन',
    '🎦' => 'सिनेमा',
    '🔅' => 'मंद चमक',
    '🔆' => 'अधिक चमक',
    '📶' => 'एंटेना संकेत',
    '🛜' => 'वायरलेस',
    '📳' => 'वाइब्रेशन मोड',
    '📴' => 'मोबाइल फ़ोन बंद',
    '♀' => 'मादा चिह्न',
    '♂' => 'नर चिह्न',
    '⚧' => 'ट्रांसजेंडर चिह्न',
    '✖' => 'गुणा',
    '➕' => 'धन चिह्न',
    '➖' => 'ऋण',
    '➗' => 'भाग',
    '🟰' => 'मोटा बराबर चिह्न',
    '♾' => 'अनंत',
    '‼' => 'दोहरा विस्मयादिबोधक चिह्न',
    '⁉' => 'विस्मयादिबोधक प्रश्न चिह्न',
    '❓' => 'प्रश्न चिह्न',
    '❔' => 'सफ़ेद प्रश्न चिह्न',
    '❕' => 'सफ़ेद विस्मयादिबोधक चिह्न',
    '❗' => 'लाल विस्मयादिबोधक चिह्न',
    '〰' => 'लहरिल डैश',
    '💱' => 'मुद्रा विनिमय',
    '💲' => 'डॉलर का चिह्न',
    '⚕' => 'चिकित्सा प्रतीक',
    '♻' => 'पुनर्चक्रीकरण प्रतीक, रीसाइक्लिंग, वैश्विक, चिह्न',
    '⚜' => 'lily flower',
    '🔱' => 'त्रिशूल का चिह्न',
    '📛' => 'नाम बैज, बैज',
    '🔰' => 'beginner ke liye Japanese symbol',
    '⭕' => 'hole wala big red circle',
    '✅' => 'check mark button',
    '☑' => 'check mark wala check box',
    '✔' => 'check mark',
    '❌' => 'क्रॉस चिह्न',
    '❎' => 'क्रॉस चिह्न बटन',
    '➰' => 'लहरदार फंदा',
    '➿' => 'दोहरा कर्ली लूप',
    '〽' => 'भाग परिवर्तन चिह्न',
    '✳' => '8 spoke wala asterisk',
    '✴' => '8 point wala star',
    '❇' => 'जगमगाहट',
    '™' => 'ट्रेड मार्क चिह्न',
    '🫟' => 'छींटे',
    '🔠' => 'इनपुट लैटिन अपरकेस',
    '🔡' => 'इनपुट लैटिन लोअरकेस अक्षर',
    '🔢' => 'अंक डालें',
    '🔣' => 'इनपुट चिह्न',
    '🔤' => 'इनपुट लैटिन अक्षर',
    '🅰' => 'A बटन (खून का प्रकार)',
    '🆎' => 'AB बटन (खून का प्रकार)',
    '🅱' => 'B बटन (रक्त प्रकार)',
    '🆑' => 'साफ़, क्लीयर, साफ़ चिह्न, CL',
    '🆒' => 'ठंडा, ठंडा चिह्न',
    '🆓' => 'निशुल्क चिह्न, शुल्क मुक्त',
    'ℹ' => 'सूचना',
    '🆔' => 'आईडी चिह्न, पहचान',
    'Ⓜ' => 'Circle kiya hua M',
    '🆕' => 'चौकोर में नया चिह्न',
    '🆖' => 'चौकोर में ठीक नहीं चिह्न',
    '🅾' => 'O बटन (खून का प्रकार)',
    '🆗' => 'ठीक बटन',
    '🅿' => 'चौकोर में पी बटन, पार्किंग',
    '🆘' => 'चौकोर में SOS चिह्न',
    '🆙' => 'चौकोर में नई जानकारी, अपडेट चिह्न',
    '🆚' => 'चौकोर में विरुद्ध चिह्न',
    '🈁' => 'चौकोर में यहां के लिए जापानी चिह्न',
    '🈂' => 'जापानी सर्विस चार्ज बटन',
    '🈷' => 'जापानी “मासिक शुल्क” बटन',
    '🈶' => 'जापानी “मुफ़्त नहीं” बटन',
    '🈯' => 'जापानी “आरक्षित” बटन',
    '🉐' => 'जापानी “तोल-मोल” बटन',
    '🈹' => 'जापानी “छूट” बटन',
    '🈚' => 'जापानी “मुफ़्त” बटन',
    '🈲' => 'जापानी “निषेध” बटन',
    '🉑' => 'जापानी “स्वीकार्य” बटन',
    '🈸' => 'जापानी “ऐप्लिकेशन” बटन',
    '🈴' => 'जापानी “पासिंग ग्रेड” बटन',
    '🈳' => 'जापानी “नौकरी उपलब्ध है” बटन',
    '㊗' => 'जापानी “बधाई” बटन',
    '㊙' => 'जापानी “गुप्त” बटन',
    '🈺' => 'जापानी “व्यापार के लिए खुला” बटन',
    '🈵' => 'जापानी “कोई नौकरी नहीं” बटन',
    '🔴' => 'लाल वृत्त',
    '🟠' => 'नारंगी रंग का वृत्त',
    '🟡' => 'पीला वृत्त',
    '🟢' => 'हरा वृत्त',
    '🔵' => 'नीला वृत्त',
    '🟣' => 'बैंगनी वृत्त',
    '🟤' => 'भूरा वृत्त',
    '⚫' => 'काला वृत्त',
    '⚪' => 'सफ़ेद वृत्त',
    '🟥' => 'लाल वर्ग',
    '🟧' => 'नारंगी रंग का वर्ग',
    '🟨' => 'पीला वर्ग',
    '🟩' => 'हरा वर्ग',
    '🟦' => 'नीला वर्ग',
    '🟪' => 'बैंगनी वर्ग',
    '🟫' => 'भूरा वर्ग',
    '⬛' => 'काला बड़ा वर्ग',
    '⬜' => 'बड़ा सफ़ेद वर्ग',
    '◼' => 'काला मध्यम वर्ग',
    '◻' => 'सफ़ेद मध्यम वर्ग',
    '◾' => 'काला मध्यम-छोटा वर्ग',
    '◽' => 'सफ़ेद मध्यम-छोटा वर्ग',
    '▪' => 'काला छोटा वर्ग',
    '▫' => 'सफ़ेद छोटा वर्ग',
    '🔶' => 'बड़ा नारंगी हीरा',
    '🔷' => 'बड़ा नीला हीरा',
    '🔸' => 'छोटा नारंगी हीरा',
    '🔹' => 'छोटा नीला हीरा',
    '🔺' => 'Oopar point karta red triangle',
    '🔻' => 'Neeche point karta red triangle',
    '💠' => 'dot wala diamond',
    '🔘' => 'रेडियो बटन',
    '🔳' => 'सफ़ेद वर्ग बटन',
    '🔲' => 'काला वर्ग बटन',
    '🏁' => 'chess board wala flag',
    '🚩' => 'तिकोना झंडा',
    '🎌' => 'क्रॉस झंडे',
    '🏴' => 'काला झंडा',
    '🏳' => 'सफेद झंडा',
];
